/***********************************************************************/
/***********************************************************************/
/**                                                                   **/
/** Copyright (C) PR electronics A/S (2004). All Rights Reserved      **/
/**                                                                   **/
/** Device        : PRetop 5350 Revision 2                            **/
/** Communication : PROFIBUS PA                                       **/
/** Description   : PROFIBUS PA EDDL for 5350                         **/
/** Date          : 4 Aug 2004 12:00:00                               **/
/**                                                                   **/
/***********************************************************************/
/***********************************************************************/

/***********************************************************************/
/*    General       												   */
/***********************************************************************/
MANUFACTURER	0x00006D,	// 24-bit
DEVICE_TYPE		0x5350,	    // 16-bit
DEVICE_REVISION 0x02,		//  8-bit
DD_REVISION		0x01		//  8-bit

/***********************************************************************/
/*    Includes       												   */
/***********************************************************************/
#include "SI_HlpM.inc"
#include "SI_FileM.inc"
#include "SI_OptM.inc"

/***********************************************************************/
/*    Defines        												   */
/***********************************************************************/
#define MAIN_LABEL                  "PR electronics 5350 - Temperature Meter"

#define	BLOCK_MODE_AUTO				0x08
#define	BLOCK_MODE_MAN				0x10
#define	BLOCK_MODE_OOS				0x80

#define degK                        1000
#define degC                        1001
#define degF                        1002
#define degR                        1003
#define mA                          1211
#define Volt                        1240
#define mV                          1243
#define uV                          1244
#define ohm                         1281
#define kOhm                        1284
#define pcnt						1342

#define ext_message1_0				0x01000000 
#define ext_message1_1				0x02000000 
#define ext_message1_2				0x04000000 
#define ext_message1_3				0x08000000 
#define ext_message1_4				0x10000000 
#define ext_message1_5				0x20000000 
#define ext_message1_6				0x40000000 
#define ext_message1_7				0x80000000 
#define ext_message2_0				0x00010000 
#define ext_message2_1				0x00020000 
#define ext_message2_2				0x00040000 
#define ext_message2_3				0x00080000 
#define ext_message2_4				0x00100000 
#define ext_message2_5				0x00200000 
#define ext_message2_6				0x00400000 
#define ext_message2_7				0x00800000 
#define ext_message3_0				0x00000100 
#define ext_message3_1				0x00000200 
#define ext_message3_2				0x00000400 
#define ext_message3_3				0x00000800 
#define ext_message3_4				0x00001000 
#define ext_message3_5				0x00002000 
#define ext_message3_6				0x00004000 
#define ext_message3_7				0x00008000 
#define ext_message4_0				0x00000001 
#define ext_message4_1				0x00000002 
#define ext_message4_2				0x00000004 
#define ext_message4_3				0x00000008 
#define ext_message4_4				0x00000010 
#define ext_message4_5				0x00000020 
#define ext_message4_6				0x00000040 
#define ext_message4_7				0x00000080 

#define DIA_OK                      0x00000000
#define DIA_HW_ELECTR				0x00000001  //Bit 0
#define DIA_HW_MECH					0x00000002  //Bit 1
#define DIA_TEMP_MOTOR				0x00000004  //Bit 2
#define DIA_TEMP_ELECTR				0x00000008  //Bit 3
#define DIA_MEM_CHKSUM				0x00000010  //Bit 4
#define DIA_MEASUREMENT				0x00000020  //Bit 5
#define DIA_NOT_INIT				0x00000040  //Bit 6
#define DIA_INIT_ERR				0x00000080  //Bit 7
#define DIA_ZERO_ERR				0x00000100  //Bit 8
#define DIA_SUPPLY					0x00000200  //Bit 9
#define DIA_CONF_INVAL				0x00000400  //Bit 10
#define DIA_WARMSTART				0x00000800  //Bit 11
#define DIA_COLDSTART				0x00001000  //Bit 12
#define DIA_MAINTENANCE				0x00002000  //Bit 13
#define DIA_CHARACT					0x00004000  //Bit 14
#define EXTENSION_AVAILABLE			0x80000000  //Bit 15

#define FUNC_STORING_LAST_SETPOINT	1
#define FUNC_FAIL_SAFE_POSITION		2

/***********************************************************************/
/*    Enumerators      												   */
/***********************************************************************/
#define LIST_NO_DEGREE	        \
{   0,  "No Linearization"    },\
{   1,  "Linearization table" }

#define LIST_RTD            	   \
{ 100,	[RTD_Pt10]				 },\
{ 101,	[RTD_Pt50]				 },\
{ 102,	[RTD_Pt100]				 },\
{ 103,	[RTD_Pt200]				 },\
{ 104,	[RTD_Pt500]				 },\
{ 105,	[RTD_Pt1000]			 },\
{ 106,	[RTD_Pt10_JIS]			 },\
{ 107,	[RTD_Pt50_JIS]			 },\
{ 108,	[RTD_Pt100_JIS]			 },\
{ 122,	[RTD_Ni50]				 },\
{ 123,	[RTD_Ni100]				 },\
{ 124,	[RTD_Ni120]				 },\
{ 125,	[RTD_Ni1000]			 },\
{ 126,	[RTD_Cu10]				 },\
{ 127,	[RTD_Cu100]				 }

#define LIST_TC					   \
{ 128,	[TC_type_B]				 },\
{ 129,	[TC_type_C]				 },\
{ 130,	[TC_type_D]				 },\
{ 133,	[TC_type_J]				 },\
{ 134,	[TC_type_K]				 },\
{ 135,	[TC_type_N]				 },\
{ 136,	[TC_type_R]				 },\
{ 137,	[TC_type_S]				 },\
{ 138,	[TC_type_T]				 },\
{ 139,	[TC_type_L]				 },\
{ 140,	[TC_type_U]				 }

#define LIST_CUSTOM_TC		   \
{ 240,  "Custom defined TC" }

#define LIST_CUSTOM_RTD		   \
{ 241,  "Custom defined RTD"}

#define LIST_RTDX							\
{ 242,	"PtX (X factor of PtX) (IEC)"	},	\
{ 243,	"NiX (X factor of NiX) (DIN)"	},	\
{ 244,	"CuX (X factor of CuX)"			},	\
{ 245,	"PtX (X factor of PtX) (JIS)"	}

#define WIRE_CONNECTION_2	{0,	[trans_temp_sensor_connection_2_WIRE]} 
#define WIRE_CONNECTION_3	{1,	[trans_temp_sensor_connection_3_WIRE]}	
#define WIRE_CONNECTION_4	{2,	[trans_temp_sensor_connection_4_WIRE]}	

#define UNIT_LIST								\
{ degK,	[unit_1000],	[unit_1000_help]	},	\
{ degC,	[unit_1001],	[unit_1001_help]	},	\
{ degF,	[unit_1002],	[unit_1002_help]	},	\
{ degR,	[unit_1003],	[unit_1003_help]	},	\
{ 1004,	[unit_1004],	[unit_1004_help]	},	\
{ 1005,	[unit_1005],	[unit_1005_help]	},	\
{ 1006,	[unit_1006],	[unit_1006_help]	},	\
{ 1007,	[unit_1007],	[unit_1007_help]	},	\
{ 1008,	[unit_1008],	[unit_1008_help]	},	\
{ 1009,	[unit_1009],	[unit_1009_help]	},	\
{ 1010,	[unit_1010],	[unit_1010_help]	},	\
{ 1011,	[unit_1011],	[unit_1011_help]	},	\
{ 1012,	[unit_1012],	[unit_1012_help]	},	\
{ 1013,	[unit_1013],	[unit_1013_help]	},	\
{ 1014,	[unit_1014],	[unit_1014_help]	},	\
{ 1015,	[unit_1015],	[unit_1015_help]	},	\
{ 1016,	[unit_1016],	[unit_1016_help]	},	\
{ 1017,	[unit_1017],	[unit_1017_help]	},	\
{ 1018,	[unit_1018],	[unit_1018_help]	},	\
{ 1019,	[unit_1019],	[unit_1019_help]	},	\
{ 1020,	[unit_1020],	[unit_1020_help]	},	\
{ 1021,	[unit_1021],	[unit_1021_help]	},	\
{ 1022,	[unit_1022],	[unit_1022_help]	},	\
{ 1023,	[unit_1023],	[unit_1023_help]	},	\
{ 1024,	[unit_1024],	[unit_1024_help]	},	\
{ 1025,	[unit_1025],	[unit_1025_help]	},	\
{ 1026,	[unit_1026],	[unit_1026_help]	},	\
{ 1027,	[unit_1027],	[unit_1027_help]	},	\
{ 1028,	[unit_1028],	[unit_1028_help]	},	\
{ 1029,	[unit_1029],	[unit_1029_help]	},	\
{ 1030,	[unit_1030],	[unit_1030_help]	},	\
{ 1031,	[unit_1031],	[unit_1031_help]	},	\
{ 1032,	[unit_1032],	[unit_1032_help]	},	\
{ 1033,	[unit_1033],	[unit_1033_help]	},	\
{ 1034,	[unit_1034],	[unit_1034_help]	},	\
{ 1035,	[unit_1035],	[unit_1035_help]	},	\
{ 1036,	[unit_1036],	[unit_1036_help]	},	\
{ 1037,	[unit_1037],	[unit_1037_help]	},	\
{ 1038,	[unit_1038],	[unit_1038_help]	},	\
{ 1039,	[unit_1039],	[unit_1039_help]	},	\
{ 1040,	[unit_1040],	[unit_1040_help]	},	\
{ 1041,	[unit_1041],	[unit_1041_help]	},	\
{ 1042,	[unit_1042],	[unit_1042_help]	},	\
{ 1043,	[unit_1043],	[unit_1043_help]	},	\
{ 1044,	[unit_1044],	[unit_1044_help]	},	\
{ 1045,	[unit_1045],	[unit_1045_help]	},	\
{ 1046,	[unit_1046],	[unit_1046_help]	},	\
{ 1047,	[unit_1047],	[unit_1047_help]	},	\
{ 1048,	[unit_1048],	[unit_1048_help]	},	\
{ 1049,	[unit_1049],	[unit_1049_help]	},	\
{ 1050,	[unit_1050],	[unit_1050_help]	},	\
{ 1051,	[unit_1051],	[unit_1051_help]	},	\
{ 1052,	[unit_1052],	[unit_1052_help]	},	\
{ 1053,	[unit_1053],	[unit_1053_help]	},	\
{ 1054,	[unit_1054],	[unit_1054_help]	},	\
{ 1055,	[unit_1055],	[unit_1055_help]	},	\
{ 1056,	[unit_1056],	[unit_1056_help]	},	\
{ 1057,	[unit_1057],	[unit_1057_help]	},	\
{ 1058,	[unit_1058],	[unit_1058_help]	},	\
{ 1059,	[unit_1059],	[unit_1059_help]	},	\
{ 1060,	[unit_1060],	[unit_1060_help]	},	\
{ 1061,	[unit_1061],	[unit_1061_help]	},	\
{ 1062,	[unit_1062],	[unit_1062_help]	},	\
{ 1063,	[unit_1063],	[unit_1063_help]	},	\
{ 1064,	[unit_1064],	[unit_1064_help]	},	\
{ 1065,	[unit_1065],	[unit_1065_help]	},	\
{ 1066,	[unit_1066],	[unit_1066_help]	},	\
{ 1067,	[unit_1067],	[unit_1067_help]	},	\
{ 1068,	[unit_1068],	[unit_1068_help]	},	\
{ 1069,	[unit_1069],	[unit_1069_help]	},	\
{ 1070,	[unit_1070],	[unit_1070_help]	},	\
{ 1071,	[unit_1071],	[unit_1071_help]	},	\
{ 1072,	[unit_1072],	[unit_1072_help]	},	\
{ 1073,	[unit_1073],	[unit_1073_help]	},	\
{ 1074,	[unit_1074],	[unit_1074_help]	},	\
{ 1075,	[unit_1075],	[unit_1075_help]	},	\
{ 1076,	[unit_1076],	[unit_1076_help]	},	\
{ 1077,	[unit_1077],	[unit_1077_help]	},	\
{ 1078,	[unit_1078],	[unit_1078_help]	},	\
{ 1079,	[unit_1079],	[unit_1079_help]	},	\
{ 1080,	[unit_1080],	[unit_1080_help]	},	\
{ 1081,	[unit_1081],	[unit_1081_help]	},	\
{ 1082,	[unit_1082],	[unit_1082_help]	},	\
{ 1083,	[unit_1083],	[unit_1083_help]	},	\
{ 1084,	[unit_1084],	[unit_1084_help]	},	\
{ 1085,	[unit_1085],	[unit_1085_help]	},	\
{ 1086,	[unit_1086],	[unit_1086_help]	},	\
{ 1087,	[unit_1087],	[unit_1087_help]	},	\
{ 1088,	[unit_1088],	[unit_1088_help]	},	\
{ 1089,	[unit_1089],	[unit_1089_help]	},	\
{ 1090,	[unit_1090],	[unit_1090_help]	},	\
{ 1091,	[unit_1091],	[unit_1091_help]	},	\
{ 1092,	[unit_1092],	[unit_1092_help]	},	\
{ 1093,	[unit_1093],	[unit_1093_help]	},	\
{ 1094,	[unit_1094],	[unit_1094_help]	},	\
{ 1095,	[unit_1095],	[unit_1095_help]	},	\
{ 1096,	[unit_1096],	[unit_1096_help]	},	\
{ 1097,	[unit_1097],	[unit_1097_help]	},	\
{ 1098,	[unit_1098],	[unit_1098_help]	},	\
{ 1099,	[unit_1099],	[unit_1099_help]	},	\
{ 1100,	[unit_1100],	[unit_1100_help]	},	\
{ 1101,	[unit_1101],	[unit_1101_help]	},	\
{ 1102,	[unit_1102],	[unit_1102_help]	},	\
{ 1103,	[unit_1103],	[unit_1103_help]	},	\
{ 1104,	[unit_1104],	[unit_1104_help]	},	\
{ 1105,	[unit_1105],	[unit_1105_help]	},	\
{ 1106,	[unit_1106],	[unit_1106_help]	},	\
{ 1107,	[unit_1107],	[unit_1107_help]	},	\
{ 1108,	[unit_1108],	[unit_1108_help]	},	\
{ 1109,	[unit_1109],	[unit_1109_help]	},	\
{ 1110,	[unit_1110],	[unit_1110_help]	},	\
{ 1111,	[unit_1111],	[unit_1111_help]	},	\
{ 1112,	[unit_1112],	[unit_1112_help]	},	\
{ 1113,	[unit_1113],	[unit_1113_help]	},	\
{ 1114,	[unit_1114],	[unit_1114_help]	},	\
{ 1115,	[unit_1115],	[unit_1115_help]	},	\
{ 1116,	[unit_1116],	[unit_1116_help]	},	\
{ 1117,	[unit_1117],	[unit_1117_help]	},	\
{ 1118,	[unit_1118],	[unit_1118_help]	},	\
{ 1119,	[unit_1119],	[unit_1119_help]	},	\
{ 1120,	[unit_1120],	[unit_1120_help]	},	\
{ 1121,	[unit_1121],	[unit_1121_help]	},	\
{ 1122,	[unit_1122],	[unit_1122_help]	},	\
{ 1123,	[unit_1123],	[unit_1123_help]	},	\
{ 1124,	[unit_1124],	[unit_1124_help]	},	\
{ 1125,	[unit_1125],	[unit_1125_help]	},	\
{ 1126,	[unit_1126],	[unit_1126_help]	},	\
{ 1127,	[unit_1127],	[unit_1127_help]	},	\
{ 1128,	[unit_1128],	[unit_1128_help]	},	\
{ 1129,	[unit_1129],	[unit_1129_help]	},	\
{ 1130,	[unit_1130],	[unit_1130_help]	},	\
{ 1131,	[unit_1131],	[unit_1131_help]	},	\
{ 1132,	[unit_1132],	[unit_1132_help]	},	\
{ 1133,	[unit_1133],	[unit_1133_help]	},	\
{ 1134,	[unit_1134],	[unit_1134_help]	},	\
{ 1135,	[unit_1135],	[unit_1135_help]	},	\
{ 1136,	[unit_1136],	[unit_1136_help]	},	\
{ 1137,	[unit_1137],	[unit_1137_help]	},	\
{ 1138,	[unit_1138],	[unit_1138_help]	},	\
{ 1139,	[unit_1139],	[unit_1139_help]	},	\
{ 1140,	[unit_1140],	[unit_1140_help]	},	\
{ 1141,	[unit_1141],	[unit_1141_help]	},	\
{ 1142,	[unit_1142],	[unit_1142_help]	},	\
{ 1143,	[unit_1143],	[unit_1143_help]	},	\
{ 1144,	[unit_1144],	[unit_1144_help]	},	\
{ 1145,	[unit_1145],	[unit_1145_help]	},	\
{ 1146,	[unit_1146],	[unit_1146_help]	},	\
{ 1147,	[unit_1147],	[unit_1147_help]	},	\
{ 1148,	[unit_1148],	[unit_1148_help]	},	\
{ 1149,	[unit_1149],	[unit_1149_help]	},	\
{ 1150,	[unit_1150],	[unit_1150_help]	},	\
{ 1151,	[unit_1151],	[unit_1151_help]	},	\
{ 1152,	[unit_1152],	[unit_1152_help]	},	\
{ 1153,	[unit_1153],	[unit_1153_help]	},	\
{ 1154,	[unit_1154],	[unit_1154_help]	},	\
{ 1155,	[unit_1155],	[unit_1155_help]	},	\
{ 1156,	[unit_1156],	[unit_1156_help]	},	\
{ 1157,	[unit_1157],	[unit_1157_help]	},	\
{ 1158,	[unit_1158],	[unit_1158_help]	},	\
{ 1159,	[unit_1159],	[unit_1159_help]	},	\
{ 1160,	[unit_1160],	[unit_1160_help]	},	\
{ 1161,	[unit_1161],	[unit_1161_help]	},	\
{ 1162,	[unit_1162],	[unit_1162_help]	},	\
{ 1163,	[unit_1163],	[unit_1163_help]	},	\
{ 1164,	[unit_1164],	[unit_1164_help]	},	\
{ 1165,	[unit_1165],	[unit_1165_help]	},	\
{ 1166,	[unit_1166],	[unit_1166_help]	},	\
{ 1167,	[unit_1167],	[unit_1167_help]	},	\
{ 1168,	[unit_1168],	[unit_1168_help]	},	\
{ 1169,	[unit_1169],	[unit_1169_help]	},	\
{ 1170,	[unit_1170],	[unit_1170_help]	},	\
{ 1171,	[unit_1171],	[unit_1171_help]	},	\
{ 1172,	[unit_1172],	[unit_1172_help]	},	\
{ 1173,	[unit_1173],	[unit_1173_help]	},	\
{ 1174,	[unit_1174],	[unit_1174_help]	},	\
{ 1175,	[unit_1175],	[unit_1175_help]	},	\
{ 1176,	[unit_1176],	[unit_1176_help]	},	\
{ 1177,	[unit_1177],	[unit_1177_help]	},	\
{ 1178,	[unit_1178],	[unit_1178_help]	},	\
{ 1179,	[unit_1179],	[unit_1179_help]	},	\
{ 1180,	[unit_1180],	[unit_1180_help]	},	\
{ 1181,	[unit_1181],	[unit_1181_help]	},	\
{ 1182,	[unit_1182],	[unit_1182_help]	},	\
{ 1183,	[unit_1183],	[unit_1183_help]	},	\
{ 1184,	[unit_1184],	[unit_1184_help]	},	\
{ 1185,	[unit_1185],	[unit_1185_help]	},	\
{ 1186,	[unit_1186],	[unit_1186_help]	},	\
{ 1187,	[unit_1187],	[unit_1187_help]	},	\
{ 1188,	[unit_1188],	[unit_1188_help]	},	\
{ 1189,	[unit_1189],	[unit_1189_help]	},	\
{ 1190,	[unit_1190],	[unit_1190_help]	},	\
{ 1191,	[unit_1191],	[unit_1191_help]	},	\
{ 1192,	[unit_1192],	[unit_1192_help]	},	\
{ 1193,	[unit_1193],	[unit_1193_help]	},	\
{ 1194,	[unit_1194],	[unit_1194_help]	},	\
{ 1195,	[unit_1195],	[unit_1195_help]	},	\
{ 1196,	[unit_1196],	[unit_1196_help]	},	\
{ 1197,	[unit_1197],	[unit_1197_help]	},	\
{ 1198,	[unit_1198],	[unit_1198_help]	},	\
{ 1199,	[unit_1199],	[unit_1199_help]	},	\
{ 1200,	[unit_1200],	[unit_1200_help]	},	\
{ 1201,	[unit_1201],	[unit_1201_help]	},	\
{ 1202,	[unit_1202],	[unit_1202_help]	},	\
{ 1203,	[unit_1203],	[unit_1203_help]	},	\
{ 1204,	[unit_1204],	[unit_1204_help]	},	\
{ 1205,	[unit_1205],	[unit_1205_help]	},	\
{ 1206,	[unit_1206],	[unit_1206_help]	},	\
{ 1207,	[unit_1207],	[unit_1207_help]	},	\
{ 1208,	[unit_1208],	[unit_1208_help]	},	\
{ 1209,	[unit_1209],	[unit_1209_help]	},	\
{ 1210,	[unit_1210],	[unit_1210_help]	},	\
{ 1211,	[unit_1211],	[unit_1211_help]	},	\
{ 1212,	[unit_1212],	[unit_1212_help]	},	\
{ 1213,	[unit_1213],	[unit_1213_help]	},	\
{ 1214,	[unit_1214],	[unit_1214_help]	},	\
{ 1215,	[unit_1215],	[unit_1215_help]	},	\
{ 1216,	[unit_1216],	[unit_1216_help]	},	\
{ 1217,	[unit_1217],	[unit_1217_help]	},	\
{ 1218,	[unit_1218],	[unit_1218_help]	},	\
{ 1219,	[unit_1219],	[unit_1219_help]	},	\
{ 1220,	[unit_1220],	[unit_1220_help]	},	\
{ 1221,	[unit_1221],	[unit_1221_help]	},	\
{ 1222,	[unit_1222],	[unit_1222_help]	},	\
{ 1223,	[unit_1223],	[unit_1223_help]	},	\
{ 1224,	[unit_1224],	[unit_1224_help]	},	\
{ 1225,	[unit_1225],	[unit_1225_help]	},	\
{ 1226,	[unit_1226],	[unit_1226_help]	},	\
{ 1227,	[unit_1227],	[unit_1227_help]	},	\
{ 1228,	[unit_1228],	[unit_1228_help]	},	\
{ 1229,	[unit_1229],	[unit_1229_help]	},	\
{ 1230,	[unit_1230],	[unit_1230_help]	},	\
{ 1231,	[unit_1231],	[unit_1231_help]	},	\
{ 1232,	[unit_1232],	[unit_1232_help]	},	\
{ 1233,	[unit_1233],	[unit_1233_help]	},	\
{ 1234,	[unit_1234],	[unit_1234_help]	},	\
{ 1235,	[unit_1235],	[unit_1235_help]	},	\
{ 1236,	[unit_1236],	[unit_1236_help]	},	\
{ 1237,	[unit_1237],	[unit_1237_help]	},	\
{ 1238,	[unit_1238],	[unit_1238_help]	},	\
{ 1239,	[unit_1239],	[unit_1239_help]	},	\
{ Volt,	[unit_1240],	[unit_1240_help]	},	\
{ 1241,	[unit_1241],	[unit_1241_help]	},	\
{ 1242,	[unit_1242],	[unit_1242_help]	},	\
{ mV,	[unit_1243],	[unit_1243_help]	},	\
{ uV,	[unit_1244],	[unit_1244_help]	},	\
{ 1245,	[unit_1245],	[unit_1245_help]	},	\
{ 1246,	[unit_1246],	[unit_1246_help]	},	\
{ 1247,	[unit_1247],	[unit_1247_help]	},	\
{ 1248,	[unit_1248],	[unit_1248_help]	},	\
{ 1249,	[unit_1249],	[unit_1249_help]	},	\
{ 1250,	[unit_1250],	[unit_1250_help]	},	\
{ 1251,	[unit_1251],	[unit_1251_help]	},	\
{ 1252,	[unit_1252],	[unit_1252_help]	},	\
{ 1253,	[unit_1253],	[unit_1253_help]	},	\
{ 1254,	[unit_1254],	[unit_1254_help]	},	\
{ 1255,	[unit_1255],	[unit_1255_help]	},	\
{ 1256,	[unit_1256],	[unit_1256_help]	},	\
{ 1257,	[unit_1257],	[unit_1257_help]	},	\
{ 1258,	[unit_1258],	[unit_1258_help]	},	\
{ 1259,	[unit_1259],	[unit_1259_help]	},	\
{ 1260,	[unit_1260],	[unit_1260_help]	},	\
{ 1261,	[unit_1261],	[unit_1261_help]	},	\
{ 1262,	[unit_1262],	[unit_1262_help]	},	\
{ 1263,	[unit_1263],	[unit_1263_help]	},	\
{ 1264,	[unit_1264],	[unit_1264_help]	},	\
{ 1265,	[unit_1265],	[unit_1265_help]	},	\
{ 1266,	[unit_1266],	[unit_1266_help]	},	\
{ 1267,	[unit_1267],	[unit_1267_help]	},	\
{ 1268,	[unit_1268],	[unit_1268_help]	},	\
{ 1269,	[unit_1269],	[unit_1269_help]	},	\
{ 1270,	[unit_1270],	[unit_1270_help]	},	\
{ 1271,	[unit_1271],	[unit_1271_help]	},	\
{ 1272,	[unit_1272],	[unit_1272_help]	},	\
{ 1273,	[unit_1273],	[unit_1273_help]	},	\
{ 1274,	[unit_1274],	[unit_1274_help]	},	\
{ 1275,	[unit_1275],	[unit_1275_help]	},	\
{ 1276,	[unit_1276],	[unit_1276_help]	},	\
{ 1277,	[unit_1277],	[unit_1277_help]	},	\
{ 1278,	[unit_1278],	[unit_1278_help]	},	\
{ 1279,	[unit_1279],	[unit_1279_help]	},	\
{ 1280,	[unit_1280],	[unit_1280_help]	},	\
{ ohm,	[unit_1281],	[unit_1281_help]	},	\
{ 1282,	[unit_1282],	[unit_1282_help]	},	\
{ 1283,	[unit_1283],	[unit_1283_help]	},	\
{ kOhm,	[unit_1284],	[unit_1284_help]	},	\
{ 1285,	[unit_1285],	[unit_1285_help]	},	\
{ 1286,	[unit_1286],	[unit_1286_help]	},	\
{ 1287,	[unit_1287],	[unit_1287_help]	},	\
{ 1288,	[unit_1288],	[unit_1288_help]	},	\
{ 1289,	[unit_1289],	[unit_1289_help]	},	\
{ 1290,	[unit_1290],	[unit_1290_help]	},	\
{ 1291,	[unit_1291],	[unit_1291_help]	},	\
{ 1292,	[unit_1292],	[unit_1292_help]	},	\
{ 1293,	[unit_1293],	[unit_1293_help]	},	\
{ 1294,	[unit_1294],	[unit_1294_help]	},	\
{ 1295,	[unit_1295],	[unit_1295_help]	},	\
{ 1296,	[unit_1296],	[unit_1296_help]	},	\
{ 1297,	[unit_1297],	[unit_1297_help]	},	\
{ 1298,	[unit_1298],	[unit_1298_help]	},	\
{ 1299,	[unit_1299],	[unit_1299_help]	},	\
{ 1300,	[unit_1300],	[unit_1300_help]	},	\
{ 1301,	[unit_1301],	[unit_1301_help]	},	\
{ 1302,	[unit_1302],	[unit_1302_help]	},	\
{ 1303,	[unit_1303],	[unit_1303_help]	},	\
{ 1304,	[unit_1304],	[unit_1304_help]	},	\
{ 1305,	[unit_1305],	[unit_1305_help]	},	\
{ 1306,	[unit_1306],	[unit_1306_help]	},	\
{ 1307,	[unit_1307],	[unit_1307_help]	},	\
{ 1308,	[unit_1308],	[unit_1308_help]	},	\
{ 1309,	[unit_1309],	[unit_1309_help]	},	\
{ 1310,	[unit_1310],	[unit_1310_help]	},	\
{ 1311,	[unit_1311],	[unit_1311_help]	},	\
{ 1312,	[unit_1312],	[unit_1312_help]	},	\
{ 1313,	[unit_1313],	[unit_1313_help]	},	\
{ 1314,	[unit_1314],	[unit_1314_help]	},	\
{ 1315,	[unit_1315],	[unit_1315_help]	},	\
{ 1316,	[unit_1316],	[unit_1316_help]	},	\
{ 1317,	[unit_1317],	[unit_1317_help]	},	\
{ 1318,	[unit_1318],	[unit_1318_help]	},	\
{ 1319,	[unit_1319],	[unit_1319_help]	},	\
{ 1320,	[unit_1320],	[unit_1320_help]	},	\
{ 1321,	[unit_1321],	[unit_1321_help]	},	\
{ 1322,	[unit_1322],	[unit_1322_help]	},	\
{ 1323,	[unit_1323],	[unit_1323_help]	},	\
{ 1324,	[unit_1324],	[unit_1324_help]	},	\
{ 1325,	[unit_1325],	[unit_1325_help]	},	\
{ 1326,	[unit_1326],	[unit_1326_help]	},	\
{ 1327,	[unit_1327],	[unit_1327_help]	},	\
{ 1328,	[unit_1328],	[unit_1328_help]	},	\
{ 1329,	[unit_1329],	[unit_1329_help]	},	\
{ 1330,	[unit_1330],	[unit_1330_help]	},	\
{ 1331,	[unit_1331],	[unit_1331_help]	},	\
{ 1332,	[unit_1332],	[unit_1332_help]	},	\
{ 1333,	[unit_1333],	[unit_1333_help]	},	\
{ 1334,	[unit_1334],	[unit_1334_help]	},	\
{ 1335,	[unit_1335],	[unit_1335_help]	},	\
{ 1336,	[unit_1336],	[unit_1336_help]	},	\
{ 1337,	[unit_1337],	[unit_1337_help]	},	\
{ 1338,	[unit_1338],	[unit_1338_help]	},	\
{ 1339,	[unit_1339],	[unit_1339_help]	},	\
{ 1340,	[unit_1340],	[unit_1340_help]	},	\
{ 1341,	[unit_1341],	[unit_1341_help]	},	\
{ pcnt,	[unit_1342],	[unit_1342_help]	},	\
{ 1343,	[unit_1343],	[unit_1343_help]	},	\
{ 1344,	[unit_1344],	[unit_1344_help]	},	\
{ 1345,	[unit_1345],	[unit_1345_help]	},	\
{ 1346,	[unit_1346],	[unit_1346_help]	},	\
{ 1347,	[unit_1347],	[unit_1347_help]	},	\
{ 1348,	[unit_1348],	[unit_1348_help]	},	\
{ 1349,	[unit_1349],	[unit_1349_help]	},	\
{ 1350,	[unit_1350],	[unit_1350_help]	},	\
{ 1351,	[unit_1351],	[unit_1351_help]	},	\
{ 1352,	[unit_1352],	[unit_1352_help]	},	\
{ 1353,	[unit_1353],	[unit_1353_help]	},	\
{ 1354,	[unit_1354],	[unit_1354_help]	},	\
{ 1355,	[unit_1355],	[unit_1355_help]	},	\
{ 1356,	[unit_1356],	[unit_1356_help]	},	\
{ 1357,	[unit_1357],	[unit_1357_help]	},	\
{ 1358,	[unit_1358],	[unit_1358_help]	},	\
{ 1359,	[unit_1359],	[unit_1359_help]	},	\
{ 1360,	[unit_1360],	[unit_1360_help]	},	\
{ 1361,	[unit_1361],	[unit_1361_help]	},	\
{ 1362,	[unit_1362],	[unit_1362_help]	},	\
{ 1363,	[unit_1363],	[unit_1363_help]	},	\
{ 1364,	[unit_1364],	[unit_1364_help]	},	\
{ 1365,	[unit_1365],	[unit_1365_help]	},	\
{ 1366,	[unit_1366],	[unit_1366_help]	},	\
{ 1367,	[unit_1367],	[unit_1367_help]	},	\
{ 1368,	[unit_1368],	[unit_1368_help]	},	\
{ 1369,	[unit_1369],	[unit_1369_help]	},	\
{ 1370,	[unit_1370],	[unit_1370_help]	},	\
{ 1371,	[unit_1371],	[unit_1371_help]	},	\
{ 1372,	[unit_1372],	[unit_1372_help]	},	\
{ 1373,	[unit_1373],	[unit_1373_help]	},	\
{ 1374,	[unit_1374],	[unit_1374_help]	},	\
{ 1375,	[unit_1375],	[unit_1375_help]	},	\
{ 1376,	[unit_1376],	[unit_1376_help]	},	\
{ 1377,	[unit_1377],	[unit_1377_help]	},	\
{ 1378,	[unit_1378],	[unit_1378_help]	},	\
{ 1379,	[unit_1379],	[unit_1379_help]	},	\
{ 1380,	[unit_1380],	[unit_1380_help]	},	\
{ 1381,	[unit_1381],	[unit_1381_help]	},	\
{ 1382,	[unit_1382],	[unit_1382_help]	},	\
{ 1383,	[unit_1383],	[unit_1383_help]	},	\
{ 1384,	[unit_1384],	[unit_1384_help]	},	\
{ 1385,	[unit_1385],	[unit_1385_help]	},	\
{ 1386,	[unit_1386],	[unit_1386_help]	},	\
{ 1387,	[unit_1387],	[unit_1387_help]	},	\
{ 1388,	[unit_1388],	[unit_1388_help]	},	\
{ 1389,	[unit_1389],	[unit_1389_help]	},	\
{ 1390,	[unit_1390],	[unit_1390_help]	},	\
{ 1391,	[unit_1391],	[unit_1391_help]	},	\
{ 1392,	[unit_1392],	[unit_1392_help]	},	\
{ 1393,	[unit_1393],	[unit_1393_help]	},	\
{ 1394,	[unit_1394],	[unit_1394_help]	},	\
{ 1395,	[unit_1395],	[unit_1395_help]	},	\
{ 1396,	[unit_1396],	[unit_1396_help]	},	\
{ 1397,	[unit_1397],	[unit_1397_help]	},	\
{ 1398,	[unit_1398],	[unit_1398_help]	},	\
{ 1399,	[unit_1399],	[unit_1399_help]	},	\
{ 1400,	[unit_1400],	[unit_1400_help]	},	\
{ 1401,	[unit_1401],	[unit_1401_help]	},	\
{ 1402,	[unit_1402],	[unit_1402_help]	},	\
{ 1403,	[unit_1403],	[unit_1403_help]	},	\
{ 1404,	[unit_1404],	[unit_1404_help]	},	\
{ 1405,	[unit_1405],	[unit_1405_help]	},	\
{ 1406,	[unit_1406],	[unit_1406_help]	},	\
{ 1407,	[unit_1407],	[unit_1407_help]	},	\
{ 1408,	[unit_1408],	[unit_1408_help]	},	\
{ 1409,	[unit_1409],	[unit_1409_help]	},	\
{ 1410,	[unit_1410],	[unit_1410_help]	},	\
{ 1411,	[unit_1411],	[unit_1411_help]	},	\
{ 1412,	[unit_1412],	[unit_1412_help]	},	\
{ 1413,	[unit_1413],	[unit_1413_help]	},	\
{ 1414,	[unit_1414],	[unit_1414_help]	},	\
{ 1415,	[unit_1415],	[unit_1415_help]	},	\
{ 1416,	[unit_1416],	[unit_1416_help]	},	\
{ 1417,	[unit_1417], ""	/*[unit_1417_help]*/	},	\
{ 1418,	[unit_1418], ""	/*[unit_1418_help]*/	},	\
{ 1419,	[unit_1419],	[unit_1419_help]	},	\
{ 1420,	[unit_1420],	[unit_1420_help]	},	\
{ 1421,	[unit_1421],	[unit_1421_help]	},	\
{ 1422,	[unit_1422],	[unit_1422_help]	},	\
{ 1423,	[unit_1423],	[unit_1423_help]	},	\
{ 1424,	[unit_1424],	[unit_1424_help]	},	\
{ 1425,	[unit_1425],	[unit_1425_help]	},	\
{ 1426,	[unit_1426],	[unit_1426_help]	},	\
{ 1427,	[unit_1427],	[unit_1427_help]	},	\
{ 1428,	[unit_1428],	[unit_1428_help]	},	\
{ 1429,	[unit_1429],	[unit_1429_help]	},	\
{ 1430,	[unit_1430],	[unit_1430_help]	},	\
{ 1431,	[unit_1431],	[unit_1431_help]	},	\
{ 1432,	[unit_1432],	[unit_1432_help]	},	\
{ 1433,	[unit_1433],	[unit_1433_help]	},	\
{ 1434,	[unit_1434],	[unit_1434_help]	},	\
{ 1435,	[unit_1435],	[unit_1435_help]	},	\
{ 1436,	[unit_1436],	[unit_1436_help]	},	\
{ 1437,	[unit_1437],	[unit_1437_help]	},	\
{ 1438,	[unit_1438],	[unit_1438_help]	},	\
{ 1439,	[unit_1439],	[unit_1439_help]	},	\
{ 1440,	[unit_1440],	[unit_1440_help]	},	\
{ 1441,	[unit_1441],	[unit_1441_help]	},	\
{ 1442,	[unit_1442],	[unit_1442_help]	},	\
{ 1443,	[unit_1443],	[unit_1443_help]	},	\
{ 1444,	[unit_1444],	[unit_1444_help]	},	\
{ 1445,	[unit_1445],	[unit_1445_help]	},	\
{ 1446,	[unit_1446],	[unit_1446_help]	},	\
{ 1447,	[unit_1447],	[unit_1447_help]	},	\
{ 1448,	[unit_1448],	[unit_1448_help]	},	\
{ 1449,	[unit_1449],	[unit_1449_help]	},	\
{ 1450,	[unit_1450],	[unit_1450_help]	},	\
{ 1451,	[unit_1451],	[unit_1451_help]	},	\
{ 1452,	[unit_1452],	[unit_1452_help]	},	\
{ 1453,	[unit_1453],	[unit_1453_help]	},	\
{ 1454,	[unit_1454],	[unit_1454_help]	},	\
{ 1455,	[unit_1455],	[unit_1455_help]	},	\
{ 1456,	[unit_1456],	[unit_1456_help]	},	\
{ 1457,	[unit_1457],	[unit_1457_help]	},	\
{ 1458,	[unit_1458],	[unit_1458_help]	},	\
{ 1459,	[unit_1459],	[unit_1459_help]	},	\
{ 1460,	[unit_1460],	[unit_1460_help]	},	\
{ 1461,	[unit_1461],	[unit_1461_help]	},	\
{ 1462,	[unit_1462],	[unit_1462_help]	},	\
{ 1463,	[unit_1463],	[unit_1463_help]	},	\
{ 1464,	[unit_1464],	[unit_1464_help]	},	\
{ 1465,	[unit_1465],	[unit_1465_help]	},	\
{ 1466,	[unit_1466],	[unit_1466_help]	},	\
{ 1467,	[unit_1467],	[unit_1467_help]	},	\
{ 1468,	[unit_1468],	[unit_1468_help]	},	\
{ 1469,	[unit_1469],	[unit_1469_help]	},	\
{ 1470,	[unit_1470],	[unit_1470_help]	},	\
{ 1471,	[unit_1471],	[unit_1471_help]	},	\
{ 1472,	[unit_1472],	[unit_1472_help]	},	\
{ 1473,	[unit_1473],	[unit_1473_help]	},	\
{ 1474,	[unit_1474],	[unit_1474_help]	},	\
{ 1475,	[unit_1475],	[unit_1475_help]	},	\
{ 1476,	[unit_1476],	[unit_1476_help]	},	\
{ 1477,	[unit_1477],	[unit_1477_help]	},	\
{ 1478,	[unit_1478],	[unit_1478_help]	},	\
{ 1479,	[unit_1479],	[unit_1479_help]	},	\
{ 1480,	[unit_1480],	[unit_1480_help]	},	\
{ 1481,	[unit_1481],	[unit_1481_help]	},	\
{ 1482,	[unit_1482],	[unit_1482_help]	},	\
{ 1483,	[unit_1483],	[unit_1483_help]	},	\
{ 1484,	[unit_1484],	[unit_1484_help]	},	\
{ 1485,	[unit_1485],	[unit_1485_help]	},	\
{ 1486,	[unit_1486],	[unit_1486_help]	},	\
{ 1487,	[unit_1487],	[unit_1487_help]	},	\
{ 1488,	[unit_1488],	[unit_1488_help]	},	\
{ 1489,	[unit_1489],	[unit_1489_help]	},	\
{ 1490,	[unit_1490],	[unit_1490_help]	},	\
{ 1491,	[unit_1491],	[unit_1491_help]	},	\
{ 1492,	[unit_1492],	[unit_1492_help]	},	\
{ 1493,	[unit_1493],	[unit_1493_help]	},	\
{ 1494,	[unit_1494],	[unit_1494_help]	},	\
{ 1495,	[unit_1495],	[unit_1495_help]	},	\
{ 1496,	[unit_1496],	[unit_1496_help]	},	\
{ 1497,	[unit_1497],	[unit_1497_help]	},	\
{ 1498,	[unit_1498],	[unit_1498_help]	},	\
{ 1499,	[unit_1499],	[unit_1499_help]	},	\
{ 1500,	[unit_1500],	[unit_1500_help]	},	\
{ 1501,	[unit_1501],	[unit_1501_help]	},	\
{ 1502,	[unit_1502],	[unit_1502_help]	},	\
{ 1503,	[unit_1503],	[unit_1503_help]	},	\
{ 1504,	[unit_1504],	[unit_1504_help]	},	\
{ 1505,	[unit_1505],	[unit_1505_help]	},	\
{ 1506,	[unit_1506],	[unit_1506_help]	},	\
{ 1507,	[unit_1507],	[unit_1507_help]	},	\
{ 1508,	[unit_1508],	[unit_1508_help]	},	\
{ 1509,	[unit_1509],	[unit_1509_help]	},	\
{ 1510,	[unit_1510],	[unit_1510_help]	},	\
{ 1511,	[unit_1511],	[unit_1511_help]	},	\
{ 1512,	[unit_1512],	[unit_1512_help]	},	\
{ 1513,	[unit_1513],	[unit_1513_help]	},	\
{ 1514,	[unit_1514],	[unit_1514_help]	},	\
{ 1515,	[unit_1515],	[unit_1515_help]	},	\
{ 1516,	[unit_1516],	[unit_1516_help]	},	\
{ 1517,	[unit_1517],	[unit_1517_help]	},	\
{ 1518,	[unit_1518],	[unit_1518_help]	},	\
{ 1519,	[unit_1519],	[unit_1519_help]	},	\
{ 1520,	[unit_1520],	[unit_1520_help]	}

#define STATUS_INPUT		\
{	0,	[bad_0]			},	\
{	1,	[bad_1]			},	\
{	2,	[bad_2]			},	\
{	3,	[bad_3]			},	\
{	4,	[bad_4]			},	\
{	5,	[bad_5]			},	\
{	6,	[bad_6]			},	\
{	7,	[bad_7]			},	\
{	8,	[bad_8]			},	\
{	9,	[bad_9]			},	\
{	10,	[bad_10]		},	\
{	11,	[bad_11]		},	\
{	12,	[bad_12]		},	\
{	13,	[bad_13]		},	\
{	14,	[bad_14]		},	\
{	15,	[bad_15]		},	\
{	16,	[bad_16]		},	\
{	17,	[bad_17]		},	\
{	18,	[bad_18]		},	\
{	19,	[bad_19]		},	\
{	20,	[bad_20]		},	\
{	21,	[bad_21]		},	\
{	22,	[bad_22]		},	\
{	23,	[bad_23]		},	\
{	24,	[bad_24]		},	\
{	25,	[bad_25]		},	\
{	26,	[bad_26]		},	\
{	27,	[bad_27]		},	\
{	28,	[bad_28]		},	\
{	29,	[bad_29]		},	\
{	30,	[bad_30]		},	\
{	31,	[bad_31]		},	\
{	32,	[bad_32]		},	\
{	33,	[bad_33]		},	\
{	34,	[bad_34]		},	\
{	35,	[bad_35]		},	\
{	64,	[uncertain_64]	},	\
{	65,	[uncertain_65]	},	\
{	66,	[uncertain_66]	},	\
{	67,	[uncertain_67]	},	\
{	68,	[uncertain_68]	},	\
{	69,	[uncertain_69]	},	\
{	70,	[uncertain_70]	},	\
{	71,	[uncertain_71]	},	\
{	72,	[uncertain_72]	},	\
{	73,	[uncertain_73]	},	\
{	74,	[uncertain_74]	},	\
{	75,	[uncertain_75]	},	\
{	76,	[uncertain_76]	},	\
{	77,	[uncertain_77]	},	\
{	78,	[uncertain_78]	},	\
{	79,	[uncertain_79]	},	\
{	80,	[uncertain_80]	},	\
{	81,	[uncertain_81]	},	\
{	82,	[uncertain_82]	},	\
{	83,	[uncertain_83]	},	\
{	84,	[uncertain_84]	},	\
{	85,	[uncertain_85]	},	\
{	86,	[uncertain_86]	},	\
{	87,	[uncertain_87]	},	\
{	88,	[uncertain_88]	},	\
{	89,	[uncertain_89]	},	\
{	90,	[uncertain_90]	},	\
{	91,	[uncertain_91]	},	\
{	92,	[uncertain_92]	},	\
{	93,	[uncertain_93]	},	\
{	94,	[uncertain_94]	},	\
{	95,	[uncertain_95]	},	\
{	128,[good_128]		},	\
{	129,[good_129]		},	\
{	130,[good_130]		},	\
{	131,[good_131]		},	\
{	132,[good_132]		},	\
{	133,[good_133]		},	\
{	134,[good_134]		},	\
{	135,[good_135]		},	\
{	136,[good_136]		},	\
{	137,[good_137]		},	\
{	138,[good_138]		},	\
{	139,[good_139]		},	\
{	140,[good_140]		},	\
{	141,[good_141]		},	\
{	142,[good_142]		},	\
{	143,[good_143]		},	\
{	144,[good_144]		},	\
{	145,[good_145]		},	\
{	146,[good_146]		},	\
{	147,[good_147]		},	\
{	148,[good_148]		},	\
{	149,[good_149]		},	\
{	150,[good_150]		},	\
{	151,[good_151]		},	\
{	152,[good_152]		},	\
{	153,[good_153]		},	\
{	154,[good_154]		},	\
{	155,[good_155]		},	\
{	160,[good_160]		},	\
{	161,[good_161]		},	\
{	162,[good_162]		},	\
{	163,[good_163]		}

#define STATUS_INPUT_NO_RCAS		\
{ 0x20,	[status_GOOD_00]		},	\
{ 0x21,	[status_GOOD_01]		},	\
{ 0x22,	[status_GOOD_02]		},	\
{ 0x23,	[status_GOOD_03]		},	\
{ 0x24,	[status_GOOD_04]		},	\
{ 0x25,	[status_GOOD_05]		},	\
{ 0x26,	[status_GOOD_06]		},	\
{ 0x28,	[status_GOOD_08]		},	\
{ 0x10,	[status_UNCERTAIN_00]	},	\
{ 0x11,	[status_UNCERTAIN_01]	},	\
{ 0x12,	[status_UNCERTAIN_02]	},	\
{ 0x13,	[status_UNCERTAIN_03]	},	\
{ 0x14,	[status_UNCERTAIN_04]	},	\
{ 0x15,	[status_UNCERTAIN_05]	},	\
{ 0x16,	[status_UNCERTAIN_06]	},	\
{ 0x17,	[status_UNCERTAIN_07]	},	\
{ 0x00,	[status_BAD_00]			},	\
{ 0x01,	[status_BAD_01]			},	\
{ 0x03,	[status_BAD_03]			},	\
{ 0x04,	[status_BAD_04]			},	\
{ 0x06,	[status_BAD_06]			},	\
{ 0x07,	[status_BAD_07]			}

#define STATUS_OUTPUT_NO_RCAS		\
{ 0x20,	[status_GOOD_00]		},	\
{ 0x21,	[status_GOOD_01]		},	\
{ 0x22,	[status_GOOD_02]		},	\
{ 0x23,	[status_GOOD_03]		},	\
{ 0x24,	[status_GOOD_04]		},	\
{ 0x25,	[status_GOOD_05]		},	\
{ 0x26,	[status_GOOD_06]		}	\
{ 0x28,	[status_GOOD_08]		},	\
{ 0x10,	[status_UNCERTAIN_00]	},	\
{ 0x11,	[status_UNCERTAIN_01]	},	\
{ 0x12,	[status_UNCERTAIN_02]	},	\
{ 0x13,	[status_UNCERTAIN_03]	},	\
{ 0x14,	[status_UNCERTAIN_04]	},	\
{ 0x15,	[status_UNCERTAIN_05]	},	\
{ 0x16,	[status_UNCERTAIN_06]	},	\
{ 0x17,	[status_UNCERTAIN_07]	},	\
{ 0x00,	[status_BAD_00]			},	\
{ 0x01,	[status_BAD_01]			},	\
{ 0x02,	[status_BAD_02]			},	\
{ 0x03,	[status_BAD_03]			},	\
{ 0x04,	[status_BAD_04]			},	\
{ 0x05,	[status_BAD_05]			},	\
{ 0x06,	[status_BAD_06]			},	\
{ 0x07,	[status_BAD_07]			}

/***********************************************************************/
/*    Functions       												   */
/***********************************************************************/
#define CELSIUS_TO_CURRENT_UNIT(a)				\
switch(ivar_value(trans1_PRIMARY_VALUE_UNIT))	\
{												\
	case Volt : a = a / 1000; break;			\
	case uV   : a = a * 1000; break;			\
	case kOhm : a = a / 1000; break;			\
	case degC : a = a; break;					\
	case degK : a = a + 273.15; break;			\
	case degF : a = a * 1.8 + 32; break;		\
	case degR : a = a * 1.8 + 491.67; break;	\
}

#define CURRENT_UNIT_TO_CELSIUS(a)				\
switch(ivar_value(trans1_PRIMARY_VALUE_UNIT))	\
{												\
	case Volt : a = a * 1000; break;			\
	case uV   : a = a / 1000; break;			\
	case kOhm : a = a * 1000; break;			\
	case degC : a = a; break;					\
	case degK : a = a - 273.15; break;			\
	case degF : a = (a - 32) / 1.8; break;		\
	case degR : a = (a - 491.15) / 1.8; break;\
}

/***********************************************************************/
/*    Helper	      												   */
/***********************************************************************/
#define IS_SINGLE       IF(trans1_SENSOR_MEAS_TYPE == 220)
#define IS_RTD(a)		IF((a >= 100 && a <= 127) || (a >= 241 && a < 245))
#define IS_TC(a)		IF((a >= 128 && a <= 140) || a == 240)
#define IS_RTDX(a)		IF(a >= 242 && a <= 245)
#define IS_NOTEMP(a)	IF(a == 0 || a == 1)
#define IS_OHM			IF(trans1_PRIMARY_VALUE_UNIT == ohm || trans1_PRIMARY_VALUE_UNIT == kOhm)
#define IS_DEGREE       IF(trans1_PRIMARY_VALUE_UNIT >= degK && trans1_PRIMARY_VALUE_UNIT <= degR)
#define IS_VOLT			IF(trans1_PRIMARY_VALUE_UNIT >= Volt && trans1_PRIMARY_VALUE_UNIT <= uV)

/***********************************************************************/
/*    Validations      												   */
/***********************************************************************/
#define VALID_TABLE					\
IF(trans1_LIN_TYPE_1 == 1 ||		\
   trans1_LIN_TYPE_2 == 1)			\
{									\
	TRUE;							\
}									\
ELSE								\
{									\
	FALSE;							\
}

#define VALID_POINT(a)				\
IF(trans1_LIN_TYPE_1 == 1 ||		\
   trans1_LIN_TYPE_2 == 1)			\
{									\
	IF(a<=trans2_TAB_ACTUAL_NUMBER)	\
	{								\
		TRUE;						\
	}								\
	ELSE							\
	{								\
		FALSE;						\
	}								\
}									\
ELSE								\
{									\
	FALSE;							\
}


#define VALID_SENSOR_2				\
IF(trans1_SENSOR_MEAS_TYPE != 220)	\
{									\
	TRUE;							\
}									\
ELSE								\
{									\
	FALSE;							\
}

#define HANDLING_CAL_1					\
IF(trans1_SENSOR_CAL_METHOD_1 == 103)	\
{										\
	READ & WRITE;						\
}										\
ELSE									\
{										\
	READ;								\
}

#define HANDLING_CAL_2					\
IF(trans1_SENSOR_CAL_METHOD_2 == 103)	\
{										\
	READ & WRITE;						\
}										\
ELSE									\
{										\
	READ;								\
}

#define VALID_EXTERNAL_RJ_VALUE		\
IF(trans1_RJ_TYPE == 2)				\
{									\
	TRUE;							\
}									\
ELSE								\
{									\
	FALSE;							\
}

#define VALID_RJ_TYPE				\
IS_TC(trans1_LIN_TYPE_1)			\
{									\
	TRUE;							\
}									\
ELSE								\
{									\
	FALSE;							\
}

#define VALID_RJ_COMP_WIRE			\
IF(trans1_RJ_TYPE == 3)				\
{									\
	TRUE;							\
}									\
ELSE								\
{									\
	FALSE;							\
}

#define VALID_SENSOR_WIRE_CHECK_RJ	\
IF(trans1_RJ_TYPE == 3 ||			\
   trans1_RJ_TYPE == 4 )			\
{									\
	TRUE;							\
}									\
ELSE								\
{									\
	FALSE;							\
}

#define VALID_SENSOR_CONNECTION_1	\
IS_RTD(trans1_LIN_TYPE_1)			\
{									\
	TRUE;							\
}									\
ELSE								\
{									\
IF(trans1_PRIMARY_VALUE_UNIT==pcnt||\
   trans1_PRIMARY_VALUE_UNIT==ohm ||\
   trans1_PRIMARY_VALUE_UNIT==kOhm) \
{									\
	TRUE;							\
}									\
ELSE								\
{									\
	FALSE;							\
}									\
}

#define VALID_SENSOR_CONNECTION_2	\
IS_SINGLE							\
{									\
	FALSE;							\
}									\
ELSE								\
{									\
	IS_TC(trans1_LIN_TYPE_2)		\
	{								\
		FALSE;						\
	}								\
	ELSE							\
	{								\
		IS_VOLT						\
		{							\
			FALSE;					\
		}							\
		ELSE						\
		{							\
			TRUE;					\
		}							\
	}								\
}

#define VALID_RTDX_FACTOR_1			\
IS_RTDX(trans1_LIN_TYPE_1)			\
{									\
	TRUE;							\
}									\
ELSE								\
{									\
	FALSE;							\
}

#define VALID_RTDX_FACTOR_2			\
IS_RTDX(trans1_LIN_TYPE_2)			\
{									\
	IF(trans1_SENSOR_MEAS_TYPE!=220)\
	{								\
		TRUE;						\
	}								\
	ELSE							\
	{								\
		FALSE;						\
	}								\
}									\
ELSE								\
{									\
	FALSE;							\
}

#define VALID_POLY					\
IF (trans1_LIN_TYPE_1 == 240 ||		\
    trans1_LIN_TYPE_2 == 240)		\
{									\
	TRUE;							\
}									\
ELSE								\
{									\
	IF (trans1_LIN_TYPE_1 == 241 ||	\
		trans1_LIN_TYPE_2 == 241)	\
	{								\
		TRUE;						\
	}								\
	ELSE							\
	{								\
		FALSE;						\
	}								\
}

#define VALID_TC_POLY(part)					\
IF (trans1_LIN_TYPE_1 == 240 ||				\
    trans1_LIN_TYPE_2 == 240)				\
{											\
	IF(trans2_CUSTOM_TC_POLY_COUNT >= part)	\
	{										\
		TRUE;								\
	}										\
	ELSE									\
	{										\
		FALSE;								\
	}										\
}											\
ELSE										\
{											\
	FALSE;									\
}

#define VALID_RTD_POLY(part)				\
IF (trans1_LIN_TYPE_1 == 241 ||				\
    trans1_LIN_TYPE_2 == 241)				\
{											\
	IF(trans2_CUSTOM_RTD_POLY_COUNT >= part)\
	{										\
		TRUE;								\
	}										\
	ELSE									\
	{										\
		FALSE;								\
	}										\
}											\
ELSE										\
{											\
	FALSE;									\
}

#define VALID_COMP_WIRE_1								\
IS_TC(trans1_LIN_TYPE_1)								\
{														\
	FALSE;												\
}														\
ELSE													\
{														\
	SELECT(trans1_SENSOR_CONNECTION_1)					\
	{													\
		CASE 0  :										\
			IS_OHM										\
			{											\
				TRUE;									\
			}											\
			ELSE										\
			{											\
				IS_RTD(trans1_LIN_TYPE_1)				\
				{										\
					TRUE;								\
				}										\
				ELSE									\
				{										\
					FALSE;								\
				}										\
			}											\
		CASE 1  :										\
			IF(trans1_PRIMARY_VALUE_UNIT == pcnt)		\
			{											\
				TRUE;									\
			}											\
			ELSE										\
			{											\
				FALSE;									\
			}											\
		DEFAULT :										\
			FALSE;										\
	}													\
}

#define VALID_COMP_WIRE_2								\
IS_SINGLE												\
{														\
	FALSE;												\
}														\
ELSE													\
{														\
	IS_TC(trans1_LIN_TYPE_2)							\
	{													\
		FALSE;											\
	}													\
	ELSE												\
	{													\
		SELECT(trans1_SENSOR_CONNECTION_2)				\
		{												\
			CASE 0  :									\
				IS_OHM									\
				{										\
					TRUE;								\
				}										\
				ELSE									\
				{										\
					IS_RTD(trans1_LIN_TYPE_2)			\
					{									\
						TRUE;							\
					}									\
					ELSE								\
					{									\
						FALSE;							\
					}									\
				}										\
			CASE 1  :									\
				IF(trans1_PRIMARY_VALUE_UNIT == pcnt)	\
				{										\
					TRUE;								\
				}										\
				ELSE									\
				{										\
					FALSE;								\
				}										\
			DEFAULT :									\
				FALSE;									\
		}												\
	}													\
}

#define VALID_SENSOR_CONNECTION_2						\
IS_SINGLE												\
{														\
	FALSE;												\
}														\
ELSE													\
{														\
	IS_RTD(trans1_LIN_TYPE_2)							\
	{													\
		TRUE;											\
	}													\
	ELSE												\
	{													\
		IF(trans1_PRIMARY_VALUE_UNIT==pcnt||			\
		   trans1_PRIMARY_VALUE_UNIT==ohm ||			\
		   trans1_PRIMARY_VALUE_UNIT==kOhm)				\
		{												\
			TRUE;										\
		}												\
		ELSE											\
		{												\
			FALSE;										\
		}												\
	}													\
}

/*******************************************************************************/
/*****	SPECIAL VARIABLES FOR RECORDS ******************************************/
/*******************************************************************************/
VARIABLE trans2_CUSTOM_POLY_TC1_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	30000;
	}
	HANDLING		READ & WRITE;
	CONSTANT_UNIT	[unit_1244];
	VALIDITY		VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_TC2_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	60000;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	[unit_1244];
	VALIDITY	VALID_TC_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_TC3_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	90000;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	[unit_1244];
	VALIDITY	VALID_TC_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_TC4_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	120000;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	[unit_1244];
	VALIDITY	VALID_TC_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_TC5_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	150000;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	[unit_1244];
	VALIDITY	VALID_TC_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_TC1_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_TC2_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_TC3_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_TC4_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_TC5_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_TC1_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_TC2_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_TC3_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_TC4_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_TC5_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_TC_RJ_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_TC1_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_TC2_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_TC3_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_TC4_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_TC5_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_TC_RJ_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_TC1_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_TC2_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_TC3_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_TC4_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_TC5_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_TC_RJ_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_TC1_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_TC2_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_TC3_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_TC4_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_TC5_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_TC_RJ_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_TC_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_RTD1_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	2000;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	[unit_1281];
	VALIDITY	VALID_RTD_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_RTD2_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	4000;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	[unit_1281];
	VALIDITY	VALID_RTD_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_RTD3_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	6000;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	[unit_1281];
	VALIDITY	VALID_RTD_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_RTD4_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	8000;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	[unit_1281];
	VALIDITY	VALID_RTD_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_RTD5_OHM
{
	LABEL		"Max input";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	10000;
	}
	HANDLING	READ & WRITE;
	CONSTANT_UNIT	[unit_1281];
	VALIDITY	VALID_RTD_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_RTD1_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_RTD2_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_RTD3_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_RTD4_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_RTD5_A4
{
	LABEL		"a4";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_RTD1_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_RTD2_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_RTD3_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_RTD4_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_RTD5_A3
{
	LABEL		"a3";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_RTD1_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_RTD2_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_RTD3_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_RTD4_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_RTD5_A2
{
	LABEL		"a2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_RTD1_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_RTD2_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_RTD3_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_RTD4_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_RTD5_A1
{
	LABEL		"a1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	1;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(5)
}

VARIABLE trans2_CUSTOM_POLY_RTD1_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(1)
}

VARIABLE trans2_CUSTOM_POLY_RTD2_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(2)
}

VARIABLE trans2_CUSTOM_POLY_RTD3_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(3)
}

VARIABLE trans2_CUSTOM_POLY_RTD4_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(4)
}

VARIABLE trans2_CUSTOM_POLY_RTD5_A0
{
	LABEL		"a0";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTD_POLY(5)
}

VARIABLE trans1_SENSOR1_CAL_DATE_INDEX1
{
	LABEL		"Milisecond";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
		MAX_VALUE      59999;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_SENSOR1_CAL_DATE_INDEX2
{
	LABEL		"Minute";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		MAX_VALUE      59;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_SENSOR1_CAL_DATE_INDEX3
{
	LABEL		"Hour";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	0;
		MAX_VALUE      23;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_SENSOR1_CAL_DATE_INDEX4
{
	LABEL		"Month";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	1;
		MAX_VALUE      12;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_SENSOR1_CAL_DATE_INDEX5
{
	LABEL		"Day";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	1;
		MAX_VALUE      31;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_SENSOR1_CAL_DATE_INDEX6
{
	LABEL		"Year (since 1900)";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	103;
		MIN_VALUE		103;
		MAX_VALUE		204;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_SENSOR2_CAL_DATE_INDEX1
{
	LABEL		"Milisecond";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
		MAX_VALUE		59999;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SENSOR2_CAL_DATE_INDEX2
{
	LABEL		"Minute";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	0;
		MAX_VALUE		59;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SENSOR2_CAL_DATE_INDEX3
{
	LABEL		"Hour";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	0;
		MAX_VALUE		23;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SENSOR2_CAL_DATE_INDEX4
{
	LABEL		"Month";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	1;
		MAX_VALUE		12;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SENSOR2_CAL_DATE_INDEX5
{
	LABEL		"Day";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	1;
		MAX_VALUE		31;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SENSOR2_CAL_DATE_INDEX6
{
	LABEL		"Year (since 1900)";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	103;
		MIN_VALUE		103;
		MAX_VALUE		204;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

/*******************************************************************************/
/*****	BLOCK  definitions *****************************************************/
/*******************************************************************************/
/* RESOURCE BLOCK*/
BLOCK phys_BLOCK
{
	TYPE	PHYSICAL;
	NUMBER	1;
}

/* TRANSDUCER BLOCK*/
BLOCK trans1_BLOCK
{
	TYPE	TRANSDUCER;
	NUMBER	1;
}

/* LINEARIZATION BLOCK*/
BLOCK trans2_BLOCK
{
	TYPE	TRANSDUCER;
	NUMBER	2;
}

/* ANALOG INPUT 1 BLOCK*/
BLOCK func1_BLOCK
{
	TYPE	FUNCTION;
	NUMBER	1;
}

/* ANALOG INPUT 2 BLOCK*/
BLOCK func2_BLOCK
{
	TYPE	FUNCTION;
	NUMBER	2;
}

/* End block summary */

/***********************************************************************/
/*    Physical Block												   */
/***********************************************************************/
VARIABLE phys_BLK_RESERVE
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
  	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_OBJECT
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{	1,	[blk_block_object_PHYSICAL]	}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_PARENT_CLASS
{
	LABEL		[blk_parent_class];
	HELP		[phys_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	1;
		{	1,	[phys_blk_parent_class_TRANSMITTER]	}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_CLASS
{
	LABEL		[blk_class];
	HELP		[phys_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_DD_REFRENCE
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE phys_BLK_DD_REV
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE phys_BLK_PROFILE
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x4002;
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_PROFILE_REV
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0300;
		{	0x0300,	"3.0"	}
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_EXECUTION_TIME
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE phys_BLK_NUM_PARAMETERS
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE phys_BLK_INDEX_VIEW_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE phys_BLK_NUM_VIEW_LISTS
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE phys_STATIC_REVISION
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE phys_TAG_DESCRIPTION
{
	LABEL		[tag_desc];		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "PR Electronics";
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_STRATEGY
{
	LABEL		[strategy];		
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE phys_ALERT_KEY
{
	LABEL		[alert_key];		
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE phys_TARGET_MODE
{
	LABEL	  	[target_mode];		
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	   DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				}	//,
//		{	0x10,	[mode_MAN]				},
//		{	0x80,	[mode_OUT_OF_SERVICE]	}

	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_ACTUAL_MODE
{
	LABEL		[actual_mode];		
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0x08 ;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
//		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE phys_PERMITTED_MODE
{
	LABEL		[permitted_mode];		
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
//		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE phys_NORMAL_MODE
{
	LABEL		[normal_mode];		
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE phys_CURRENT_STATE_ALARM_SUM
{
	LABEL		[current_state_alarm_sum];		
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_UNACKNOWLEDGED_STATE_ALARM_SUM
{
	LABEL		[unacknowledged_state_alarm_sum];		
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_UNREPORTED_STATE_ALARM_SUM
{
	LABEL		[unreported_state_alarm_sum];		
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_DISABLED_STATE_ALARM_SUM
{
	LABEL		[disabled_state_alarm_sum];		
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_SOFTWARE_REVISION
{
	LABEL		[phys_software_revision];
	HELP		[phys_software_revision_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "1.00";
	}
	HANDLING	READ;
}

VARIABLE phys_HARDWARE_REVISION
{
	LABEL		[phys_hardware_revision];
	HELP		[phys_hardware_revision_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "2.00";
	}
	HANDLING	READ;
}

VARIABLE phys_DEVICE_MAN_ID
{
	LABEL		[phys_device_man_id];
	HELP		[phys_device_man_id_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	109;
		{ 1,   [Acromag]					},
		{ 2,   [Allen_Bradley]				},
		{ 3,   [Ametek]						},
		{ 4,   [Analog_Devices]				},
		{ 5,   [Elsag_Bailey]				},
		{ 6,   [Beckman]					},
		{ 7,   [Bell_Microsensor]			},
		{ 8,   [Bourns]						},
		{ 9,   [Bristol_Babcock]			},
		{ 10,  [Brooks_Instrument]			},
		{ 11,  [Chessell]					},
		{ 12,  [Combustion_Engineering]		},
		{ 13,  [Daniel_Industries]			},
		{ 14,  [Delta]						},
		{ 15,  [Dieterich_Standard]			},
		{ 16,  [Dohrmann]					},
		{ 17,  [Endress_and_Hauser]			},
		{ 18,  [Elsag_Bailey]				},
		{ 19,  [Fisher_Controls]			},
		{ 20,  [Foxboro]					},
		{ 21,  [Fuji]						},
		{ 22,  [Elsag_Bailey]				},
		{ 23,  [Honeywell]					},
		{ 24,  [ITT_Barton]					},
		{ 25,  [KayRay_Sensall]				},
		{ 26,  [Kent]						},
		{ 27,  [Leeds_and_Northrup]			},
		{ 28,  [Leslie]						},
		{ 29,  [M_System_Co]				},
		{ 30,  [Measurex]					},
		{ 31,  [Micro_Motion]				},
		{ 32,  [Moore_Industries]			},
		{ 33,  [Moore_Products]				},
		{ 34,  [Ohkura_Electric]			},
		{ 35,  [Paine]						},
		{ 36,  [Rochester_Instrument_Systems] },
		{ 37,  [Ronan]						},
		{ 38,  [Rosemount]					},
		{ 39,  [Peek_Measurement]			},
		{ 40,  [Schlumberger]				},
		{ 41,  [Sensall]					},
		{ 42,  [Siemens]					},
		{ 43,  [Camille_Bauer]				},
		{ 44,  [Toshiba]					},
		{ 45,  [Transmation]				},
		{ 46,  [Rosemount_Analytical]		},
		{ 47,  [Valmet]						},
		{ 48,  [Valtek]						},
		{ 49,  [Varec]						},
		{ 50,  [Viatran]					},
		{ 51,  [Weed]						},
		{ 52,  [Westinghouse]				},
		{ 53,  [Xomox]						},
		{ 54,  [Yamatake]					},
		{ 55,  [Yokogawa]					},
		{ 56,  [Nuovo_Pignone]				},
		{ 57,  [Promac]						},
		{ 58,  [Exac_Corporation]			},
		{ 59,  [KDG_Mobrey]					},
		{ 60,  [Acrom_Control_System]		},
		{ 61,  [Princo]						},
		{ 62,  [Smar]						},
		{ 63,  [Foxboro_Eckardt]			},
		{ 64,  [Measurement_Technology]		},
		{ 65,  [Applied_System_Technologies]},
		{ 66,  [Samson]						},
		{ 67,  [Sparling_Instruments]		},
		{ 68,  [Fireye]						},
		{ 69,  [Krohne]						},
		{ 70,  [Betz_Equipment]				},
		{ 71,  [Druck]						},
		{ 72,  [SOR]						},
		{ 73,  [Elcon_Instruments]			},
		{ 74,  [EMCO]						},
		{ 75,  [Termiflex]					},
		{ 76,  [VAF_Instruments]			},
		{ 77,  [Westlock_Controls]			},
		{ 78,  [Drexelbrook]				},
		{ 79,  [saab_tank_control]			},
		{ 80,  [K_TEK]						},
		{ 81,  [Flowdata]					},
		{ 82,  [Draeger]					},
		{ 83,  [Raytek]						},
		{ 84,  [Meridian_Instruments]		},
		{ 85,  [BTG]						},
		{ 86,  [Magnetrol]					},
		{ 87,  [Neles_Controls]				},
		{ 88,  [Milltronics]				},
		{ 89,  [HELIOS]						},
		{ 90,  [Anderson_Instrument_Company]},
		{ 91,  [INOR]						},
		{ 92,  [ROBERTSHAW]					},
		{ 93,  [PEPPERL_FUCHS]				},
		{ 94,  [ACCUTECH]					},
		{ 95,  [Flow_Measurement]			},
		{ 96,  [KAMSTRUP]					},
		{ 97,  [Knick]						},
		{ 98,  [VEGA]						},
		{ 99,  [MTS_SYS_CORPS_SENSORS]		},
		{ 100, [Oval]						},
		{ 101, [Masoneilan_DRESSER]			},
		{ 102, [Besta]						},
		{ 103, [Ohmart]						},
		{ 104, [Harold_Beck_and_Sons]		},
		{ 105, [rittmeyer_instrumentation]	},
		{ 106, [rossel_messtechnik]			},
		{ 107, [WIKA]						},
		{ 108, [Bopp_and_Reuther_Heinrichs]	},
		{ 109, [pr_eletronics]				},
		{ 110, [jordan_controls]			},
		{ 111, [valcom]						},
		{ 112, [us_electric_motors]			}, 
		{ 113, [apparatebau_hundsbach]		},
		{ 250, [not_used]					},
		{ 251, [none]						},
		{ 252, [unknown]					},
		{ 253, [special]					}
	}
	HANDLING	READ;
}

VARIABLE phys_DEVICE_ID
{
	LABEL		[phys_device_type];
	HELP		[phys_device_type_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16);
	HANDLING	READ;
}

VARIABLE phys_SERIAL_NUMBER
{
	LABEL		[phys_serial_num];
	HELP		[phys_device_ser_num_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16);
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS
{
	LABEL		[phys_diagnosis];
	HELP		[phys_diagnosis_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (4)
	{
	     DEFAULT_VALUE	0x0000;
		{	DIA_OK,					[dia_OK],					[dia_OK_help]					},
		{	DIA_HW_ELECTR,			[dia_HW_ELECTR],			[dia_HW_ELECTR_help]			},
		{	DIA_HW_MECH,			[dia_HW_MECH],				[dia_HW_MECH_help]				},
		{	DIA_TEMP_MOTOR,			[dia_TEMP_MOTOR],			[dia_TEMP_MOTOR_help]			},
		{	DIA_TEMP_ELECTR,		[dia_TEMP_ELECTR],			[dia_TEMP_ELECTR_help]			},
		{	DIA_MEM_CHKSUM,			[dia_MEM_CHKSUM],			[dia_MEM_CHKSUM_help]			},
		{	DIA_MEASUREMENT,		[dia_MEASUREMENT],			[dia_MEASUREMENT_help]			},
		{	DIA_NOT_INIT,			[dia_NOT_INIT],				[dia_NOT_INIT_help]				},
		{	DIA_INIT_ERR,			[dia_INIT_ERR],				[dia_INIT_ERR_help]				},
		{	DIA_ZERO_ERR,			[dia_ZERO_ERR],				[dia_ZERO_ERR_help]				},
		{	DIA_SUPPLY,				[dia_SUPPLY],				[dia_SUPPLY_help]				},
		{	DIA_CONF_INVAL,			[dia_CONF_INVAL],			[dia_CONF_INVAL_help]			},
		{	DIA_WARMSTART,			[dia_WARMSTART],			[dia_WARMSTART_help]			},
		{	DIA_COLDSTART,			[dia_COLDSTART],			[dia_COLDSTART_help]			},
		{	DIA_MAINTENANCE,		[dia_MAINTENANCE],			[dia_MAINTENANCE_help]			},
		{	DIA_CHARACT,			[dia_CHARACT],				[dia_CHARACT_help]				},
		{	EXTENSION_AVAILABLE,	[dia_EXTENSION_AVAILABLE],	[dia_EXTENSION_AVAILABLE_help]	}  
	}
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_EXT_01
{
	LABEL		[phys_diagnosis_extension];
	HELP		[phys_diagnosis_extension_help];
	CLASS		CONTAINED & DYNAMIC;
   	TYPE		BIT_ENUMERATED (4)
   	{
		{	DIA_OK,	 [dia_OK],[dia_OK_help]	}
   	}
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_EXT_02
{
	LABEL		[phys_diagnosis_extension];
	HELP		[phys_diagnosis_extension_help];
	CLASS		CONTAINED & DYNAMIC;
   	TYPE		BIT_ENUMERATED (2)
   	{
		{	DIA_OK,	 [dia_OK],[dia_OK_help]	}
   	}
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_MASK
{
	LABEL		[phys_diagnosis_mask];
	HELP		[phys_diagnosis_mask_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (4)
	{
		{	DIA_HW_ELECTR,			[dia_HW_ELECTR],			[dia_HW_ELECTR_help]			},
		{	DIA_HW_MECH,			[dia_HW_MECH],				[dia_HW_MECH_help]				},
		{	DIA_TEMP_MOTOR,			[dia_TEMP_MOTOR],			[dia_TEMP_MOTOR_help]			},
		{	DIA_TEMP_ELECTR,		[dia_TEMP_ELECTR],			[dia_TEMP_ELECTR_help]			},
		{	DIA_MEM_CHKSUM,			[dia_MEM_CHKSUM],			[dia_MEM_CHKSUM_help]			},
		{	DIA_MEASUREMENT,		[dia_MEASUREMENT],			[dia_MEASUREMENT_help]			},
		{	DIA_NOT_INIT,			[dia_NOT_INIT],				[dia_NOT_INIT_help]				},
		{	DIA_INIT_ERR,			[dia_INIT_ERR],				[dia_INIT_ERR_help]				},
		{	DIA_ZERO_ERR,			[dia_ZERO_ERR],				[dia_ZERO_ERR_help]				},
		{	DIA_SUPPLY,				[dia_SUPPLY],				[dia_SUPPLY_help]				},
		{	DIA_CONF_INVAL,			[dia_CONF_INVAL],			[dia_CONF_INVAL_help]			},
		{	DIA_WARMSTART,			[dia_WARMSTART],			[dia_WARMSTART_help]			},
		{	DIA_COLDSTART,			[dia_COLDSTART],			[dia_COLDSTART_help]			},
		{	DIA_MAINTENANCE,		[dia_MAINTENANCE],			[dia_MAINTENANCE_help]			},
		{	DIA_CHARACT,			[dia_CHARACT],				[dia_CHARACT_help]				},
		{	EXTENSION_AVAILABLE,	[dia_EXTENSION_AVAILABLE],	[dia_EXTENSION_AVAILABLE_help]	}
	}
	HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_MASK_EXT_01
{
  LABEL		[phys_diagnosis_extension_mask];
  HELP		[phys_diagnosis_extension_mask_help];
  CLASS		CONTAINED;
  TYPE		BIT_ENUMERATED (4)
   	{
		{	DIA_OK,	 [dia_OK],[dia_OK_help]	}
   	}
	
  HANDLING	READ;
}

VARIABLE phys_DIAGNOSIS_MASK_EXT_02
{
  LABEL		[phys_diagnosis_extension_mask];
  HELP		[phys_diagnosis_extension_mask_help];
  CLASS		CONTAINED;
  TYPE		BIT_ENUMERATED (2)
  {
		{	DIA_OK,	 [dia_OK],[dia_OK_help]	}
  }
  HANDLING	READ;
}

VARIABLE phys_CERTIFICATION
{
	LABEL		[phys_device_certification];
	HELP		[phys_device_certification_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE	"";
	}
	HANDLING	READ;
}

VARIABLE phys_WRITE_LOCKING
{
	LABEL		[phys_write_locking];
	HELP		[phys_write_locking_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	2457;
		{ 2457,		[off]	},
		{ 0,		[on]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_FACTORY_RESET
{
	LABEL		[phys_factory_reset];
	HELP		[phys_factory_reset_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
 		DEFAULT_VALUE	0;
		{ 0,		[no_function]			},
		{ 1,		[factory_reset_PARAMS]	},
		{ 2506,		[phys_device_reset_cmd]	},
		{ 2712,		[factory_reset_ADDRESS]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_DESCRIPTION
{
	LABEL		[phys_descriptor];
	HELP		[phys_descriptor_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_DEVICE_MESSAGE
{
	LABEL		[phys_message];
	HELP		[phys_message_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_INSTALL_DATE
{
	LABEL		[phys_install_date];
	HELP		[phys_install_date_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_LOCAL_OP_ENABLED
{
	LABEL		[local_op_ena];
	HELP		[local_op_ena_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{   0,"Disabled"},
		{   1,"Enabled"}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_IDENT_NUMBER
{
	LABEL		[phys_ident_number];
	HELP		[phys_ident_number_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{	0,	[phys_ident_number_PROFILE]		},
		{	1,	[phys_ident_number_MANUFACURER]	}
	}
	HANDLING	READ & WRITE;
}

/*
VARIABLE phys_HW_WRITE_PROTECTION
{
	LABEL		[phys_hw_write_protection];
	HELP		[phys_hw_write_protection_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}
*/

/*******************************************************************************/
/*****	Transducer Block 1******************************************************/
/*******************************************************************************/
VARIABLE trans1_BLK_RESERVE
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
  	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE trans1_BLK_OBJECT
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	3,	[blk_block_object_TRANSDUCER]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_BLK_PARENT_CLASS
{
	LABEL		[blk_parent_class];
	HELP		[TB_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{ 0xf0, "PR Transducer" }
	}
	HANDLING	READ;
}

VARIABLE trans1_BLK_CLASS
{
	LABEL		[blk_class];
	HELP		[TB_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	1,		[trans_temp_blk_class_TC]	},
		{	2,		[trans_temp_blk_class_RTD]	},
		{	3,		[trans_temp_blk_class_PYR]	},
		{	250,	[not_used] 					},
		{	251,	[none]						},
		{	252,	[unknown]					},
		{	253,	[special]					}
	}
	HANDLING	READ;
}

VARIABLE trans1_BLK_DD_REFRENCE
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE trans1_BLK_DD_REV
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE trans1_BLK_PROFILE
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x4002;
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_BLK_PROFILE_REV
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0300;
		{	0x0300,	"3.0"	}
	}
	HANDLING	READ;
}

VARIABLE trans1_BLK_EXECUTION_TIME
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE trans1_BLK_NUM_PARAMETERS
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_BLK_INDEX_VIEW_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans1_BLK_NUM_VIEW_LISTS
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans1_STATIC_REVISION
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE trans1_TAG_DESCRIPTION
{
	LABEL		[tag_desc];		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_STRATEGY
{
	LABEL		[strategy];		
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_ALERT_KEY
{
	LABEL		[alert_key];		
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE trans1_TARGET_MODE
{
	LABEL	  	[target_mode];		
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	   DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				}
//		{	0x80,	[mode_OUT_OF_SERVICE]	}

	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_ACTUAL_MODE
{
	LABEL		[actual_mode];		
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0x08 ;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
//		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_PERMITTED_MODE
{
	LABEL		[permitted_mode];		
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
//		DEFAULT_VALUE	0x88;
		DEFAULT_VALUE	0x08;
//		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				}
//		{	0x10,	[mode_MAN]				},
//		{	0x20,	[mode_LO]				},
//		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_NORMAL_MODE
{
	LABEL		[normal_mode];		
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_CURRENT_STATE_ALARM_SUM
{
	LABEL		[current_state_alarm_sum];		
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_UNACKNOWLEDGED_STATE_ALARM_SUM
{
	LABEL		[unacknowledged_state_alarm_sum];		
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_UNREPORTED_STATE_ALARM_SUM
{
	LABEL		[unreported_state_alarm_sum];		
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_DISABLED_STATE_ALARM_SUM
{
	LABEL		[disabled_state_alarm_sum];		
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_PRIMARY_VALUE
{
	LABEL		[trans_value];
	HELP		[trans_temp_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
    	DEFAULT_VALUE	0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ;
}

VARIABLE trans1_PRIMARY_VALUE_STATUS
{
	LABEL		[trans_value_status];
	HELP		[trans_value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		STATUS_INPUT
	}
	HANDLING	READ;
}

VARIABLE trans1_PRIMARY_VALUE_UNIT
{
	LABEL		[digital_units];	
	HELP		[digital_units_help]; 
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE degC;
		{ Volt,	[unit_1240],	[unit_1240_help]	},
		{ mV,	[unit_1243],	[unit_1243_help]	},
		{ uV,	[unit_1244],	[unit_1244_help]	},
		{ ohm,	[unit_1281],	[unit_1281_help]	},
		{ kOhm,	[unit_1284],	[unit_1284_help]	},
		{ pcnt,	[unit_1342],	[unit_1342_help]	} 
		{ degK,	[unit_1000],	[unit_1000_help]	},
		{ degC,	[unit_1001],	[unit_1001_help]	},
		{ degF,	[unit_1002],	[unit_1002_help]	},
		{ degR,	[unit_1003],	[unit_1003_help]	} 
	}
	POST_EDIT_ACTIONS
	{
		method_SENSOR_MEAS_TYPE,
		method_LIN_TYPE_1,
		method_SENSOR_CONNECTION_1,
		method_SENSOR_LIMITS_1,
		method_LIN_TYPE_2,
		method_SENSOR_CONNECTION_2,
		method_SENSOR_LIMITS_2,
		method_RJ_TYPE
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_SECONDARY_VALUE_1
{
	LABEL		[trans_temp_temperature_1];	
	HELP		[trans_temp_temperature_1_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ;
}

VARIABLE trans1_SECONDARY_VALUE_STATUS_1
{
	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_INPUT
	}
	HANDLING	READ;
}

VARIABLE trans1_SECONDARY_VALUE_2
{
	LABEL		[trans_temp_temperature_2];	
	HELP		[trans_temp_temperature_2_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SECONDARY_VALUE_STATUS_2
{
	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_INPUT
	}
	HANDLING	READ;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SENSOR_MEAS_TYPE
{
	LABEL		"Sensor Measurement Type";	
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	220;
		IF (trans1_PRIMARY_VALUE_UNIT == mA)
		{
			{   220,	"Sensor 1, Sensor 2 not available", ""	}
		}
		ELSE
		{
			{	0,		"Sensor 1", ""							},
			{   1,      "Sensor 2", ""							},
			{	128,	"Sensor 1 - Sensor 2", ""				},
			{	129,	"Sensor 2 - Sensor 1", ""				},
			{	192,	"Average", ""							},
			{	193,	"Average Sensor 1 or Sensor 2", ""		},
			{   220,	"Sensor 1, Sensor 2 not available", ""	},
			{   221,	"Sensor 1, Sensor 2 if Sensor 1 is bad"	},
			{   222,	"Sensor 2, Sensor 1 if Sensor 2 is bad"	}
		}
	}
	POST_EDIT_ACTIONS
	{
		method_LIN_TYPE_1,
		method_SENSOR_CONNECTION_1,
		method_SENSOR_LIMITS_1,
		method_LIN_TYPE_2,
		method_SENSOR_CONNECTION_2,
		method_SENSOR_LIMITS_2,
		method_RJ_TYPE
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_LIN_TYPE_1
{
	LABEL		"Linearization Type";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE
			IS_DEGREE
			{
				102;
			}
			ELSE
			{
				0;
			}
		IS_DEGREE
		{
			LIST_RTD,
			LIST_TC,
			LIST_CUSTOM_TC,
			LIST_CUSTOM_RTD,
			LIST_RTDX
		}
		ELSE
		{
			LIST_NO_DEGREE
		} 
	}
	POST_EDIT_ACTIONS
	{
		method_SENSOR_CONNECTION_1,
		method_SENSOR_LIMITS_1,
		method_LIN_TYPE_2,
		method_SENSOR_LIMITS_2,
		method_SENSOR_CONNECTION_2,
		method_RJ_TYPE
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_BIAS_1
{
	LABEL		    "Bias";	
	CLASS		    CONTAINED;
	TYPE		    FLOAT
	{
	DEFAULT_VALUE	0.0;
	DISPLAY_FORMAT  ".4f";
	}
	HANDLING	    READ & WRITE;
}

VARIABLE trans1_BIAS_2
{
	LABEL		    "Bias";	
	CLASS		    CONTAINED;
	TYPE		    FLOAT
	{
	DEFAULT_VALUE	0.0;	
	DISPLAY_FORMAT  ".4f";
	}
	HANDLING	    READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_UPPER_SENSOR_LIMIT_1
{
	LABEL		    "Upper Limit";	
	CLASS		    CONTAINED & DYNAMIC;
	TYPE		    FLOAT
	{
	DEFAULT_VALUE   850.00;
	DISPLAY_FORMAT  ".4f";
	}
	HANDLING        READ;
}

VARIABLE trans1_LOWER_SENSOR_LIMIT_1
{
	LABEL		    "Lower Limit";	
	CLASS		    CONTAINED & DYNAMIC;
	TYPE		    FLOAT
	{
	DEFAULT_VALUE   -200.00;
	DISPLAY_FORMAT  ".4f";
	}
	HANDLING        READ;
}

VARIABLE trans1_INPUT_FAULT_GEN
{
	LABEL		"Input Malfunction";	
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x00;
		{ 0x00,	[trans_temp_input_fault_OK]			},
		{ 0x01,	[trans_temp_input_fault_RJ_ERR]		},
		{ 0x02,	[trans_temp_input_fault_HW_ERR]		}
	}
	HANDLING	READ;
}

VARIABLE trans1_INPUT_FAULT_1
{
	LABEL		"Sensor 1 Malfunction"; 
	CLASS		CONTAINED & DYNAMIC;
	STYLE		"MULTILINE 16 4" ;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x00;
		{ 0x00,	[trans_temp_input_fault_OK]				},
		{ 0x01,	[trans_temp_input_fault_UNDERRANGE]		},
		{ 0x02,	[trans_temp_input_fault_OVERRANGE]		},
		{ 0x04,	[trans_temp_input_fault_LEAD_BREAK]		},
		{ 0x08,	[trans_temp_input_fault_SHORT_CIRCUIT]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_INPUT_FAULT_2
{
	LABEL		"Sensor 2 Malfunction"; 
	CLASS		CONTAINED & DYNAMIC;
	STYLE		"MULTILINE 16 4" ;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x00;
		{ 0x00,	[trans_temp_input_fault_OK]				},
		{ 0x01,	[trans_temp_input_fault_UNDERRANGE]		},
		{ 0x02,	[trans_temp_input_fault_OVERRANGE]		},
		{ 0x04,	[trans_temp_input_fault_LEAD_BREAK]		},
		{ 0x08,	[trans_temp_input_fault_SHORT_CIRCUIT]	}
	}
	HANDLING	READ;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SENSOR_WIRE_CHECK_1
{
	LABEL		"Sensor Wire Check";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 3;
		{	0,	[trans_sensor_wire_check_BREAK_ON_SHORT_ON]		},
		{	1,	[trans_sensor_wire_check_BREAK_ON_SHORT_OFF]	},
		{	2,	[trans_sensor_wire_check_BREAK_OFF_SHORT_ON]	},
		{	3,	[disabled]										}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_SENSOR_WIRE_CHECK_2
{
	LABEL		"Sensor Wire Check";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 3;
		{	0,	[trans_sensor_wire_check_BREAK_ON_SHORT_ON]		},
		{	1,	[trans_sensor_wire_check_BREAK_ON_SHORT_OFF]	},
		{	2,	[trans_sensor_wire_check_BREAK_OFF_SHORT_ON]	},
		{	3,	[disabled]										}
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_MAX_SENSOR_VALUE_1
{
	LABEL		"Max Value";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_MIN_SENSOR_VALUE_1
{
	LABEL		"Min Value";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_MAX_SENSOR_VALUE_2
{
	LABEL		"Max Value";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_MIN_SENSOR_VALUE_2
{
	LABEL		"Min Value";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_RJ_TEMP
{
	LABEL		   [trans_temp_rj_temp];	
	HELP		   [trans_temp_rj_temp_help]; 
	CLASS		   CONTAINED & DYNAMIC;
	TYPE           FLOAT
	{
		DEFAULT_VALUE  0.00;
		DISPLAY_FORMAT ".4f";
	}
	HANDLING       READ;
}

VARIABLE trans1_RJ_TYPE
{
	LABEL		"Type";	
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		IS_SINGLE
		{
  			{ 0,	"No refrence"    },
			{ 1,	"Internal"       },	
			{ 2,	"External"   	 },	
			{ 3,	"Sensor, 2-wire" },
			{ 4,	"Sensor, 3-wire" }
		}
		ELSE
		{
			IS_TC(trans1_LIN_TYPE_2)
			{
  				{ 0,	"No refrence"    },
				{ 1,	"Internal"       },	
				{ 2,	"External"   	 },	
				{ 3,	"Sensor, 2-wire" }
			}
			ELSE
			{
  				{ 0,	"No refrence"    },
				{ 1,	"Internal"       },	
				{ 2,	"External"   	 }
			}
		}
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RJ_TYPE
}

VARIABLE trans1_EXTERNAL_RJ_VALUE
{
	LABEL		   "External Value";	
	CLASS		   CONTAINED;
	TYPE           FLOAT
	{
	DEFAULT_VALUE  0.00;
	MIN_VALUE      -40.00;
	MAX_VALUE      135.00;
	DISPLAY_FORMAT ".4f";
	}
	HANDLING       READ & WRITE;
	VALIDITY	   VALID_EXTERNAL_RJ_VALUE
}

VARIABLE trans1_SENSOR_CONNECTION_1
{
	LABEL		"Sensor Connection";	
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		IF (trans1_PRIMARY_VALUE_UNIT == pcnt)
		{
			IF (trans1_SENSOR_MEAS_TYPE == 220)
			{
				WIRE_CONNECTION_3,
				WIRE_CONNECTION_4
			}
			ELSE
			{
				WIRE_CONNECTION_3
			}
		}
		ELSE
		{
			IF (trans1_SENSOR_MEAS_TYPE == 220)
			{
				WIRE_CONNECTION_2,
				WIRE_CONNECTION_3,
				WIRE_CONNECTION_4
			}
			ELSE
			{
				WIRE_CONNECTION_2,
				WIRE_CONNECTION_3
			}
		}
	}
	POST_EDIT_ACTIONS
	{
		method_LIN_TYPE_2,
		method_SENSOR_CONNECTION_2,
		method_SENSOR_LIMITS_2,
		method_RJ_TYPE
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_CONNECTION_1
}

VARIABLE trans1_COMP_WIRE_1
{
	LABEL			"Wire Compenstation";	
	CLASS			CONTAINED;
	TYPE			FLOAT
	{
	DEFAULT_VALUE	0.0; 
	MIN_VALUE		0.0;
	MAX_VALUE		100.0;
	DISPLAY_FORMAT	".4f";
	}
	CONSTANT_UNIT	[Ohm];
	HANDLING		READ & WRITE;
	VALIDITY		VALID_COMP_WIRE_1
}

VARIABLE trans1_COMP_WIRE_2
{
	LABEL			"Wire Compenstation";	
	CLASS			CONTAINED;
	TYPE			FLOAT
	{
	DEFAULT_VALUE	0.0; 
	MIN_VALUE		0.0;
	MAX_VALUE		100.0;
	DISPLAY_FORMAT	".4f";
	}
	CONSTANT_UNIT	[Ohm];
	HANDLING		READ & WRITE;
	VALIDITY		VALID_COMP_WIRE_2
}

VARIABLE trans1_SENSOR_CONNECTION_2
{
	LABEL		"Sensor Connection";	
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		/* No wire */
		DEFAULT_VALUE	0;
		IS_TC(trans1_LIN_TYPE_1)
		{
			WIRE_CONNECTION_2,
			WIRE_CONNECTION_3
		}
		ELSE
		{
			IS_OHM
			{
				WIRE_CONNECTION_2
			}
			ELSE
			{
				IS_DEGREE
				{
					WIRE_CONNECTION_2
				}
				ELSE
				{
					WIRE_CONNECTION_3
				}
			}
		}
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_CONNECTION_2
}

VARIABLE trans1_LOWER_SENSOR_LIMIT_2
{
	LABEL		    "Lower Limit";	
	CLASS		    CONTAINED & DYNAMIC;
	TYPE		    FLOAT
	{
	DEFAULT_VALUE   -200.00;
	DISPLAY_FORMAT  ".4f";
	}
	HANDLING        READ;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_UPPER_SENSOR_LIMIT_2
{
	LABEL		    "Upper Limit";	
	CLASS		    CONTAINED & DYNAMIC;
	TYPE		    FLOAT
	{
	DEFAULT_VALUE   850.00;
	DISPLAY_FORMAT  ".4f";
	}
	HANDLING        READ;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_LIN_TYPE_2
{
	LABEL		"Linearization Type";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE
			IF(trans1_LIN_TYPE_1 == 0 || trans1_LIN_TYPE_1 == 1)
			{
				0;
			}
			ELSE
			{
				102;
			}
		IF(trans1_LIN_TYPE_1 == 0 || trans1_LIN_TYPE_1 == 1)
		{
			LIST_NO_DEGREE
		}
		ELSE
		{
			IS_TC(trans1_LIN_TYPE_1)
			{
				LIST_RTD,
				LIST_TC,
				LIST_CUSTOM_TC,
				LIST_CUSTOM_RTD,
				LIST_RTDX
			}
			ELSE
			{
				LIST_RTD,
				LIST_CUSTOM_RTD,
				LIST_RTDX
			}
		}
	}
	POST_EDIT_ACTIONS
	{
		method_SENSOR_CONNECTION_2,
		method_SENSOR_LIMITS_2,
		method_RJ_TYPE
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_RJ_COMP_WIRE
{
	LABEL		   "Wire Compensation";	
	CLASS		   CONTAINED;
	TYPE           FLOAT
	{
		DEFAULT_VALUE  0.00;
		MIN_VALUE	   0.00;
		MAX_VALUE	   100.00;	
		DISPLAY_FORMAT ".4f";
	}
	CONSTANT_UNIT  [Ohm];
	HANDLING       READ & WRITE;
	VALIDITY	   VALID_RJ_COMP_WIRE
}

VARIABLE trans1_RJ_FAULT
{
	LABEL		"RJ Fault";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x00;
		{ 0x00,	[trans_temp_input_fault_OK]				},
		{ 0x01,	[trans_temp_input_fault_UNDERRANGE]		},
		{ 0x02,	[trans_temp_input_fault_OVERRANGE]		},
		{ 0x04,	[trans_temp_input_fault_LEAD_BREAK]		},
		{ 0x08,	[trans_temp_input_fault_SHORT_CIRCUIT]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_SENSOR_WIRE_CHECK_RJ
{
	LABEL		"Sensor Wire Check";	
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 3;
		{	0,	[trans_sensor_wire_check_BREAK_ON_SHORT_ON]		},
		{	1,	[trans_sensor_wire_check_BREAK_ON_SHORT_OFF]	},
		{	2,	[trans_sensor_wire_check_BREAK_OFF_SHORT_ON]	},
		{	3,	[disabled]										}
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_WIRE_CHECK_RJ
}

VARIABLE trans1_INTERN_TEMP
{
	LABEL		"Internal Temperature";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
	DEFAULT_VALUE 0.0;
	}
	HANDLING	READ;
}

VARIABLE trans1_INTERN_TEMP_STATUS
{
	LABEL		"Internal temperature status";
	HELP		"";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		STATUS_INPUT
	}
	HANDLING	READ;
}

VARIABLE trans1_CAL_POINT_LO_1
{
	LABEL		"Low Point";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE 0.0;
	}
	HANDLING	HANDLING_CAL_1
}

VARIABLE trans1_CAL_ACTUAL_LO_1
{
	LABEL		"Actual Low";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE 0.0;
	}
	HANDLING	HANDLING_CAL_1
}

VARIABLE trans1_CAL_POINT_HI_1
{
	LABEL		"High Point";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE 0.0;
	}
	HANDLING	HANDLING_CAL_1
}

VARIABLE trans1_CAL_ACTUAL_HI_1
{
	LABEL		"Actual High";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE 0.0;
	}
	HANDLING	HANDLING_CAL_1
}

VARIABLE trans1_SENSOR_CAL_METHOD_1
{
	LABEL		"Calibration Method";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 103;
		{	103, "Factory trim standard", "" },
		{	104, "User trim standard", "" }
	}
    HANDLING	READ & WRITE;
}

VARIABLE trans1_SENSOR_CAL_LOC_1
{
	LABEL		"Calibration Location";
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
	DEFAULT_VALUE "";
	}
    HANDLING	READ & WRITE;
}

ITEM_ARRAY OF VARIABLE trans1_SENSOR_CAL_DATE_1
{
	LABEL		"Calibration Date";
	HELP		"Help";
	ELEMENTS
	{
		1, trans1_SENSOR1_CAL_DATE_INDEX1;
		2, trans1_SENSOR1_CAL_DATE_INDEX2;
		3, trans1_SENSOR1_CAL_DATE_INDEX3;
		4, trans1_SENSOR1_CAL_DATE_INDEX4;
		5, trans1_SENSOR1_CAL_DATE_INDEX5;
		6, trans1_SENSOR1_CAL_DATE_INDEX6;
	}
}

VARIABLE trans1_SENSOR_CAL_WHO_1
{
	LABEL		"Calibration Who";
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
	DEFAULT_VALUE "";
	}
    HANDLING	READ & WRITE;
}

VARIABLE trans1_CAL_POINT_LO_2
{
	LABEL		"Low Point";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE 0.0;
	}
	HANDLING	HANDLING_CAL_2
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_CAL_ACTUAL_LO_2
{
	LABEL		"Actual Low";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE 0.0;
	}
	HANDLING	HANDLING_CAL_2
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_CAL_POINT_HI_2
{
	LABEL		"High Point";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE 0.0;
	}
	HANDLING	HANDLING_CAL_2
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_CAL_ACTUAL_HI_2
{
	LABEL		"Actual High";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
	DEFAULT_VALUE 0.0;
	}
	HANDLING	HANDLING_CAL_2
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SENSOR_CAL_METHOD_2
{
	LABEL		"Calibration Method";
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 103;
		{	103, "Factory trim standard", "" },
		{	104, "User trim standard", "" }
	}
    HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_SENSOR_CAL_LOC_2
{
	LABEL		"Calibration Location";
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
    HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

ITEM_ARRAY OF VARIABLE trans1_SENSOR_CAL_DATE_2
{
	LABEL		"Calibration Date";
	HELP		"Help";
	ELEMENTS
	{
		1, trans1_SENSOR2_CAL_DATE_INDEX1;
		2, trans1_SENSOR2_CAL_DATE_INDEX2;
		3, trans1_SENSOR2_CAL_DATE_INDEX3;
		4, trans1_SENSOR2_CAL_DATE_INDEX4;
		5, trans1_SENSOR2_CAL_DATE_INDEX5;
		6, trans1_SENSOR2_CAL_DATE_INDEX6;
	}
}

VARIABLE trans1_SENSOR_CAL_WHO_2
{
	LABEL		"Calibration Who";
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
    HANDLING	READ & WRITE;
	VALIDITY	VALID_SENSOR_2
}

VARIABLE trans1_HW_ERROR
{
	LABEL		"Hardware Error";
	CLASS		CONTAINED & DYNAMIC;
	STYLE		"MULTILINE 16 5" ;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x00;
		{ 0x00,	"hardware OK"							},
		{ 0x01,	"Input power supply error"				},
		{ 0x02,	"Input initialization error"			},
		{ 0x04,	"Input communication error"				},
		{ 0x08,	"Internal temperature sensor error"		},
		{ 0x10,	"Device not factory calibrated"			}
	}
	HANDLING	READ;
}

VARIABLE trans1_CABLE_RES1
{
	LABEL		"Cable Resistance";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_CABLE_RES2
{
	LABEL		"Cable Resistance";
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_RTDX_FACTOR_1
{
	LABEL		"RTDX Factor";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	100;
		MIN_VALUE		10;
		MAX_VALUE		1000;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTDX_FACTOR_1
}

VARIABLE trans1_RTDX_FACTOR_2
{
	LABEL		"RTDX Factor";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	100;
		MIN_VALUE		10;
		MAX_VALUE		1000;
	}
	HANDLING	READ & WRITE;
	VALIDITY	VALID_RTDX_FACTOR_2
}

/*******************************************************************************/
/*****	Transducer Block 2******************************************************/
/*******************************************************************************/
VARIABLE trans2_BLK_RESERVE
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
  	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE trans2_BLK_OBJECT
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	3,	[blk_block_object_TRANSDUCER]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_BLK_PARENT_CLASS
{
	LABEL		[blk_parent_class];
	HELP		[TB_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	0xf0,	"PR Linearization"	}
	}
	HANDLING	READ;
}

VARIABLE trans2_BLK_CLASS
{
	LABEL		[blk_class];
	HELP		[TB_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	1,		[trans_temp_blk_class_TC]	},
		{	2,		[trans_temp_blk_class_RTD]	},
		{	3,		[trans_temp_blk_class_PYR]	},
		{	250,	[not_used] 					},
		{	251,	[none]						},
		{	252,	[unknown]					},
		{	253,	[special]					}
	}
	HANDLING	READ;
}

VARIABLE trans2_BLK_DD_REFRENCE
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE trans2_BLK_DD_REV
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE trans2_BLK_PROFILE
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x4002;
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_BLK_PROFILE_REV
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0300;
		{	0x0300,	"3.0"	}
	}
	HANDLING	READ;
}

VARIABLE trans2_BLK_EXECUTION_TIME
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE trans2_BLK_NUM_PARAMETERS
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans2_BLK_INDEX_VIEW_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans2_BLK_NUM_VIEW_LISTS
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE trans2_STATIC_REVISION
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE trans2_TAG_DESCRIPTION
{
	LABEL		[tag_desc];		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans2_STRATEGY
{
	LABEL		[strategy];		
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE trans2_ALERT_KEY
{
	LABEL		[alert_key];		
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE trans2_TARGET_MODE
{
	LABEL	  	[target_mode];		
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	   DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				}

	}
	HANDLING	READ & WRITE;
}

VARIABLE trans2_ACTUAL_MODE
{
	LABEL		[actual_mode];		
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0x08 ;
		{	0x08,	[mode_AUTO]				}
	}
	HANDLING	READ;
}

VARIABLE trans2_PERMITTED_MODE
{
	LABEL		[permitted_mode];		
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				}
	}
	HANDLING	READ;
}

VARIABLE trans2_NORMAL_MODE
{
	LABEL		[normal_mode];		
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_CURRENT_STATE_ALARM_SUM
{
	LABEL		[current_state_alarm_sum];		
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_UNACKNOWLEDGED_STATE_ALARM_SUM
{
	LABEL		[unacknowledged_state_alarm_sum];		
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_UNREPORTED_STATE_ALARM_SUM
{
	LABEL		[unreported_state_alarm_sum];		
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_DISABLED_STATE_ALARM_SUM
{
	LABEL		[disabled_state_alarm_sum];		
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_CUSTOM_TC_NAME
{
	LABEL			"Name";
	CLASS			CONTAINED;
	TYPE			ASCII (20)
	{
	DEFAULT_VALUE	"Linear TC; No RJ";
	}
	HANDLING		READ & WRITE;
}

VARIABLE trans2_CUSTOM_TC_POLY_COUNT
{
	LABEL			"Count";
	CLASS			CONTAINED;
	TYPE			UNSIGNED_INTEGER (1)
	{
	DEFAULT_VALUE	1;
	}
	HANDLING		READ & WRITE;
}

VARIABLE trans2_CUSTOM_TC_MIN_IN
{
	LABEL			"Minimum Input";
	CLASS			CONTAINED;
	TYPE			FLOAT
	{
	DEFAULT_VALUE	-800000;
	}
	CONSTANT_UNIT	[unit_1244];
	HANDLING		READ & WRITE;
}

VARIABLE trans2_CUSTOM_TC_MIN_OUT
{
	LABEL			"Minimum Output";
	CLASS			CONTAINED;
	TYPE			FLOAT
	{
	DEFAULT_VALUE	0;
	}
	CONSTANT_UNIT	[unit_1001];
	HANDLING		READ & WRITE;
}

VARIABLE trans2_CUSTOM_TC_MAX_OUT
{
	LABEL			"Maximum Output";
	CLASS			CONTAINED;
	TYPE			FLOAT
	{
	DEFAULT_VALUE	1000;
	}
	CONSTANT_UNIT	[unit_1001];
	HANDLING		READ & WRITE;
}

COLLECTION OF VARIABLE trans2_CUSTOM_TC_POLY_1
{
	LABEL			"Polynomial Part 1";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_TC1_OHM;
		a4,		trans2_CUSTOM_POLY_TC1_A4;
		a3,		trans2_CUSTOM_POLY_TC1_A3;
		a2,		trans2_CUSTOM_POLY_TC1_A2;
		a1,		trans2_CUSTOM_POLY_TC1_A1;
		a0,		trans2_CUSTOM_POLY_TC1_A0;
	}
}

COLLECTION OF VARIABLE trans2_CUSTOM_TC_POLY_2
{
	LABEL			"Polynomial Part 2";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_TC2_OHM;
		a4,		trans2_CUSTOM_POLY_TC2_A4;
		a3,		trans2_CUSTOM_POLY_TC2_A3;
		a2,		trans2_CUSTOM_POLY_TC2_A2;
		a1,		trans2_CUSTOM_POLY_TC2_A1;
		a0,		trans2_CUSTOM_POLY_TC2_A0;
	}
}

COLLECTION OF VARIABLE trans2_CUSTOM_TC_POLY_3
{
	LABEL			"Polynomial Part 3";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_TC3_OHM;
		a4,		trans2_CUSTOM_POLY_TC3_A4;
		a3,		trans2_CUSTOM_POLY_TC3_A3;
		a2,		trans2_CUSTOM_POLY_TC3_A2;
		a1,		trans2_CUSTOM_POLY_TC3_A1;
		a0,		trans2_CUSTOM_POLY_TC3_A0;
	}
}

COLLECTION OF VARIABLE trans2_CUSTOM_TC_POLY_4
{
	LABEL			"Polynomial Part 4";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_TC4_OHM;
		a4,		trans2_CUSTOM_POLY_TC4_A4;
		a3,		trans2_CUSTOM_POLY_TC4_A3;
		a2,		trans2_CUSTOM_POLY_TC4_A2;
		a1,		trans2_CUSTOM_POLY_TC4_A1;
		a0,		trans2_CUSTOM_POLY_TC4_A0;
	}
}

COLLECTION OF VARIABLE trans2_CUSTOM_TC_POLY_5
{
	LABEL			"Polynomial Part 5";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_TC5_OHM;
		a4,		trans2_CUSTOM_POLY_TC5_A4;
		a3,		trans2_CUSTOM_POLY_TC5_A3;
		a2,		trans2_CUSTOM_POLY_TC5_A2;
		a1,		trans2_CUSTOM_POLY_TC5_A1;
		a0,		trans2_CUSTOM_POLY_TC5_A0;
	}
}

COLLECTION OF VARIABLE trans2_CUSTOM_TC_RJ_POLY
{
	LABEL			"Polynomial Part RJ";
	MEMBERS
	{
		a3,		trans2_CUSTOM_POLY_TC_RJ_A3;
		a2,		trans2_CUSTOM_POLY_TC_RJ_A2;
		a1,		trans2_CUSTOM_POLY_TC_RJ_A1;
		a0,		trans2_CUSTOM_POLY_TC_RJ_A0;
	}
}

VARIABLE trans2_CUSTOM_RTD_NAME
{
	LABEL			"Name";
	CLASS			CONTAINED;
	TYPE			ASCII (20)
	{
	DEFAULT_VALUE	"Linear RTD";
	}
	HANDLING		READ & WRITE;
}

VARIABLE trans2_CUSTOM_RTD_POLY_COUNT
{
	LABEL			"Count";
	CLASS			CONTAINED;
	TYPE			UNSIGNED_INTEGER (1)
	{
	DEFAULT_VALUE	1;
	}
	HANDLING		READ & WRITE;
}

VARIABLE trans2_CUSTOM_RTD_MIN_IN
{
	LABEL			"Minimum Input";
	CLASS			CONTAINED;
	TYPE			FLOAT
	{
	DEFAULT_VALUE	0;
	}
	CONSTANT_UNIT	[unit_1281];
	HANDLING		READ & WRITE;
}

VARIABLE trans2_CUSTOM_RTD_MIN_OUT
{
	LABEL			"Minimum Output";
	CLASS			CONTAINED;
	TYPE			FLOAT
	{
	DEFAULT_VALUE	0;
	}
	CONSTANT_UNIT	[unit_1001];
	HANDLING		READ & WRITE;
}

VARIABLE trans2_CUSTOM_RTD_MAX_OUT
{
	LABEL			"Maximum Output";
	CLASS			CONTAINED;
	TYPE			FLOAT
	{
	DEFAULT_VALUE	1000;
	}
	CONSTANT_UNIT	[unit_1001];
	HANDLING		READ & WRITE;
}

COLLECTION OF VARIABLE trans2_CUSTOM_RTD_POLY_1
{
	LABEL			"Polynomial Part 1";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_RTD1_OHM;
		a4,		trans2_CUSTOM_POLY_RTD1_A4;
		a3,		trans2_CUSTOM_POLY_RTD1_A3;
		a2,		trans2_CUSTOM_POLY_RTD1_A2;
		a1,		trans2_CUSTOM_POLY_RTD1_A1;
		a0,		trans2_CUSTOM_POLY_RTD1_A0;
	}
}

COLLECTION OF VARIABLE trans2_CUSTOM_RTD_POLY_2
{
	LABEL			"Polynomial Part 2";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_RTD2_OHM;
		a4,		trans2_CUSTOM_POLY_RTD2_A4;
		a3,		trans2_CUSTOM_POLY_RTD2_A3;
		a2,		trans2_CUSTOM_POLY_RTD2_A2;
		a1,		trans2_CUSTOM_POLY_RTD2_A1;
		a0,		trans2_CUSTOM_POLY_RTD2_A0;
	}
}

COLLECTION OF VARIABLE trans2_CUSTOM_RTD_POLY_3
{
	LABEL			"Polynomial Part 3";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_RTD3_OHM;
		a4,		trans2_CUSTOM_POLY_RTD3_A4;
		a3,		trans2_CUSTOM_POLY_RTD3_A3;
		a2,		trans2_CUSTOM_POLY_RTD3_A2;
		a1,		trans2_CUSTOM_POLY_RTD3_A1;
		a0,		trans2_CUSTOM_POLY_RTD3_A0;
	}
}

COLLECTION OF VARIABLE trans2_CUSTOM_RTD_POLY_4
{
	LABEL			"Polynomial Part 4";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_RTD4_OHM;
		a4,		trans2_CUSTOM_POLY_RTD4_A4;
		a3,		trans2_CUSTOM_POLY_RTD4_A3;
		a2,		trans2_CUSTOM_POLY_RTD4_A2;
		a1,		trans2_CUSTOM_POLY_RTD4_A1;
		a0,		trans2_CUSTOM_POLY_RTD4_A0;
	}
}

COLLECTION OF VARIABLE trans2_CUSTOM_RTD_POLY_5
{
	LABEL			"Polynomial Part 5";
	MEMBERS
	{
		Ohm,	trans2_CUSTOM_POLY_RTD5_OHM;
		a4,		trans2_CUSTOM_POLY_RTD5_A4;
		a3,		trans2_CUSTOM_POLY_RTD5_A3;
		a2,		trans2_CUSTOM_POLY_RTD5_A2;
		a1,		trans2_CUSTOM_POLY_RTD5_A1;
		a0,		trans2_CUSTOM_POLY_RTD5_A0;
	}
}

VARIABLE trans2_TAB_MIN_NUMBER
{
	LABEL		"Minimum Points"; 
	CLASS		CONTAINED;
	HANDLING	READ;
	TYPE        UNSIGNED_INTEGER (1)
	{
	DEFAULT_VALUE	10;
	}
	VALIDITY	VALID_TABLE
}

VARIABLE trans2_TAB_MAX_NUMBER
{
	LABEL		"Maximum Points"; 
	CLASS		CONTAINED;
	HANDLING	READ;
	TYPE        UNSIGNED_INTEGER (1)
	{
	DEFAULT_VALUE	50;
	}
	VALIDITY	VALID_TABLE
}

VARIABLE trans2_TAB_ACTUAL_NUMBER
{
	LABEL		"Actual Number"; 
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 11;
		MIN_VALUE     10;
		MAX_VALUE     50;
	}
	VALIDITY	VALID_TABLE
}

VARIABLE trans2_TAB_X1
{
	LABEL		"X1";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(1)
}

VARIABLE trans2_TAB_Y1
{
	LABEL		"Y1";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(1)
}

VARIABLE trans2_TAB_X2
{
	LABEL		"X2";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 1000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(2)
}

VARIABLE trans2_TAB_Y2
{
	LABEL		"Y2";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 100.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(2)
}

VARIABLE trans2_TAB_X3
{
	LABEL		"X3";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 2000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(3)
}

VARIABLE trans2_TAB_Y3
{
	LABEL		"Y3";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 200.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(3)
}

VARIABLE trans2_TAB_X4
{
	LABEL		"X4";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 3000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(4)
}

VARIABLE trans2_TAB_Y4
{
	LABEL		"Y4";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 300.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(4)
}

VARIABLE trans2_TAB_X5
{
	LABEL		"X5";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 4000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(5)
}

VARIABLE trans2_TAB_Y5
{
	LABEL		"Y5";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 400.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(5)
}

VARIABLE trans2_TAB_X6
{
	LABEL		"Y6";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 5000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(6)
}

VARIABLE trans2_TAB_Y6
{
	LABEL		"Y6";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 500.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(6)
}

VARIABLE trans2_TAB_X7
{
	LABEL		"X7";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 6000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(7)
}

VARIABLE trans2_TAB_Y7
{
	LABEL		"Y7";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 600.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(7)
}

VARIABLE trans2_TAB_X8
{
	LABEL		"X8";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 7000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(8)
}

VARIABLE trans2_TAB_Y8
{
	LABEL		"Y8";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 700.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(8)
}

VARIABLE trans2_TAB_X9
{
	LABEL		"X9";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 8000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(9)
}

VARIABLE trans2_TAB_Y9
{
	LABEL		"Y9";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 800.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(9)
}

VARIABLE trans2_TAB_X10
{
	LABEL		"X10";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 9000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(10)
}

VARIABLE trans2_TAB_Y10
{
	LABEL		"Y10";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 900.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(10)
}

VARIABLE trans2_TAB_X11
{
	LABEL		"X11";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 10000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(11)
}

VARIABLE trans2_TAB_Y11
{
	LABEL		"Y11";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 1000.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(11)
}

VARIABLE trans2_TAB_X12
{
	LABEL		"X12";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(12)
}

VARIABLE trans2_TAB_Y12
{
	LABEL		"Y12";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(12)
}

VARIABLE trans2_TAB_X13
{
	LABEL		"X13";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(13)
}

VARIABLE trans2_TAB_Y13
{
	LABEL		"Y13";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(13)
}

VARIABLE trans2_TAB_X14
{
	LABEL		"X14";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(14)
}

VARIABLE trans2_TAB_Y14
{
	LABEL		"Y14";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(14)
}

VARIABLE trans2_TAB_X15
{
	LABEL		"X15";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(15)
}

VARIABLE trans2_TAB_Y15
{
	LABEL		"Y15";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(15)
}

VARIABLE trans2_TAB_X16
{
	LABEL		"X16";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(16)
}

VARIABLE trans2_TAB_Y16
{
	LABEL		"Y16";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(16)
}

VARIABLE trans2_TAB_X17
{
	LABEL		"X17";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(17)
}

VARIABLE trans2_TAB_Y17
{
	LABEL		"Y17";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(17)
}

VARIABLE trans2_TAB_X18
{
	LABEL		"X18";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(18)
}

VARIABLE trans2_TAB_Y18
{
	LABEL		"Y18";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(18)
}

VARIABLE trans2_TAB_X19
{
	LABEL		"X19";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(19)
}

VARIABLE trans2_TAB_Y19
{
	LABEL		"Y19";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(19)
}

VARIABLE trans2_TAB_X20
{
	LABEL		"X20";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(20)
}

VARIABLE trans2_TAB_Y20
{
	LABEL		"Y20";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(20)
}

VARIABLE trans2_TAB_X21
{
	LABEL		"X21";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(21)
}

VARIABLE trans2_TAB_Y21
{
	LABEL		"Y21";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(21)
}

VARIABLE trans2_TAB_X22
{
	LABEL		"X22";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(22)
}

VARIABLE trans2_TAB_Y22
{
	LABEL		"Y22";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(22)
}

VARIABLE trans2_TAB_X23
{
	LABEL		"X23";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(23)
}

VARIABLE trans2_TAB_Y23
{
	LABEL		"Y23";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(23)
}

VARIABLE trans2_TAB_X24
{
	LABEL		"X24";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(24)
}

VARIABLE trans2_TAB_Y24
{
	LABEL		"Y24";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(24)
}

VARIABLE trans2_TAB_X25
{
	LABEL		"X25";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(25)
}

VARIABLE trans2_TAB_Y25
{
	LABEL		"Y25";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(25)
}

VARIABLE trans2_TAB_X26
{
	LABEL		"X26";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(26)
}

VARIABLE trans2_TAB_Y26
{
	LABEL		"Y26";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(26)
}

VARIABLE trans2_TAB_X27
{
	LABEL		"X27";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(27)
}

VARIABLE trans2_TAB_Y27
{
	LABEL		"Y27";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(27)
}

VARIABLE trans2_TAB_X28
{
	LABEL		"X28";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(28)
}

VARIABLE trans2_TAB_Y28
{
	LABEL		"Y28";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(28)
}

VARIABLE trans2_TAB_X29
{
	LABEL		"X29";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(29)
}

VARIABLE trans2_TAB_Y29
{
	LABEL		"Y29";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(29)
}

VARIABLE trans2_TAB_X30
{
	LABEL		"X30";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(30)
}

VARIABLE trans2_TAB_Y30
{
	LABEL		"Y30";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(30)
}

VARIABLE trans2_TAB_X31
{
	LABEL		"X31";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(31)
}

VARIABLE trans2_TAB_Y31
{
	LABEL		"Y31";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(31)
}

VARIABLE trans2_TAB_X32
{
	LABEL		"X32";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(32)
}

VARIABLE trans2_TAB_Y32
{
	LABEL		"Y32";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(32)
}

VARIABLE trans2_TAB_X33
{
	LABEL		"X33";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(33)
}

VARIABLE trans2_TAB_Y33
{
	LABEL		"Y33";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(33)
}

VARIABLE trans2_TAB_X34
{
	LABEL		"X34";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(34)
}

VARIABLE trans2_TAB_Y34
{
	LABEL		"Y34";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(34)
}

VARIABLE trans2_TAB_X35
{
	LABEL		"X35";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(35)
}

VARIABLE trans2_TAB_Y35
{
	LABEL		"Y35";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(35)
}

VARIABLE trans2_TAB_X36
{
	LABEL		"X36";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(36)
}

VARIABLE trans2_TAB_Y36
{
	LABEL		"Y36";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(36)
}

VARIABLE trans2_TAB_X37
{
	LABEL		"X37";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(37)
}

VARIABLE trans2_TAB_Y37
{
	LABEL		"Y37";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(37)
}

VARIABLE trans2_TAB_X38
{
	LABEL		"X38";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(38)
}

VARIABLE trans2_TAB_Y38
{
	LABEL		"Y38";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(38)
}

VARIABLE trans2_TAB_X39
{
	LABEL		"X39";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(39)
}

VARIABLE trans2_TAB_Y39
{
	LABEL		"Y39";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(39)
}

VARIABLE trans2_TAB_X40
{
	LABEL		"X40";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(40)
}

VARIABLE trans2_TAB_Y40
{
	LABEL		"Y40";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(40)
}

VARIABLE trans2_TAB_X41
{
	LABEL		"X41";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(41)
}

VARIABLE trans2_TAB_Y41
{
	LABEL		"Y41";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(41)
}

VARIABLE trans2_TAB_X42
{
	LABEL		"X42";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(42)
}

VARIABLE trans2_TAB_Y42
{
	LABEL		"Y42";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(42)
}

VARIABLE trans2_TAB_X43
{
	LABEL		"X43";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(43)
}

VARIABLE trans2_TAB_Y43
{
	LABEL		"Y43";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(43)
}

VARIABLE trans2_TAB_X44
{
	LABEL		"X44";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(44)
}

VARIABLE trans2_TAB_Y44
{
	LABEL		"Y44";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(44)
}

VARIABLE trans2_TAB_X45
{
	LABEL		"X45";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(45)
}

VARIABLE trans2_TAB_Y45
{
	LABEL		"Y45";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(45)
}

VARIABLE trans2_TAB_X46
{
	LABEL		"X46";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(46)
}

VARIABLE trans2_TAB_Y46
{
	LABEL		"Y46";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(46)
}

VARIABLE trans2_TAB_X47
{
	LABEL		"X47";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(47)
}

VARIABLE trans2_TAB_Y47
{
	LABEL		"Y47";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(47)
}

VARIABLE trans2_TAB_X48
{
	LABEL		"X48";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(48)
}

VARIABLE trans2_TAB_Y48
{
	LABEL		"Y48";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(48)
}

VARIABLE trans2_TAB_X49
{
	LABEL		"X49";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(49)
}

VARIABLE trans2_TAB_Y49
{
	LABEL		"Y49";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(49)
}

VARIABLE trans2_TAB_X50
{
	LABEL		"X50";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(50)
}

VARIABLE trans2_TAB_Y50
{
	LABEL		"Y50";
	CLASS		CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT ".4f";
	}
	VALIDITY	VALID_POINT(50)
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE1
{
	LABEL	"Point 1";
	MEMBERS
	{
		x, trans2_TAB_X1;
		y, trans2_TAB_Y1;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE2
{
	LABEL	"Point 2";
	MEMBERS
	{
		x, trans2_TAB_X2;
		y, trans2_TAB_Y2;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE3
{
	LABEL	"Point 3";
	MEMBERS
	{
		x, trans2_TAB_X3;
		y, trans2_TAB_Y3;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE4
{
	LABEL	"Point 4";
	MEMBERS
	{
		x, trans2_TAB_X4;
		y, trans2_TAB_Y4;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE5
{
	LABEL	"Point 5";
	MEMBERS
	{
		x, trans2_TAB_X5;
		y, trans2_TAB_Y5;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE6
{
	LABEL	"Point 6";
	MEMBERS
	{
		x, trans2_TAB_X6;
		y, trans2_TAB_Y6;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE7
{
	LABEL	"Point 7";
	MEMBERS
	{
		x, trans2_TAB_X7;
		y, trans2_TAB_Y7;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE8
{
	LABEL	"Point 8";
	MEMBERS
	{
		x, trans2_TAB_X8;
		y, trans2_TAB_Y8;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE9
{
	LABEL	"Point 9";
	MEMBERS
	{
		x, trans2_TAB_X9;
		y, trans2_TAB_Y9;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE10
{
	LABEL	"Point 10";
	MEMBERS
	{
		x, trans2_TAB_X10;
		y, trans2_TAB_Y10;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE11
{
	LABEL	"Point 11";
	MEMBERS
	{
		x, trans2_TAB_X11;
		y, trans2_TAB_Y11;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE12
{
	LABEL	"Point 12";
	MEMBERS
	{
		x, trans2_TAB_X12;
		y, trans2_TAB_Y12;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE13
{
	LABEL	"Point 13";
	MEMBERS
	{
		x, trans2_TAB_X13;
		y, trans2_TAB_Y13;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE14
{
	LABEL	"Point 14";
	MEMBERS
	{
		x, trans2_TAB_X14;
		y, trans2_TAB_Y14;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE15
{
	LABEL	"Point 15";
	MEMBERS
	{
		x, trans2_TAB_X15;
		y, trans2_TAB_Y15;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE16
{
	LABEL	"Point 16";
	MEMBERS
	{
		x, trans2_TAB_X16;
		y, trans2_TAB_Y16;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE17
{
	LABEL	"Point 17";
	MEMBERS
	{
		x, trans2_TAB_X17;
		y, trans2_TAB_Y17;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE18
{
	LABEL	"Point 18";
	MEMBERS
	{
		x, trans2_TAB_X18;
		y, trans2_TAB_Y18;
	}
}


COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE19
{
	LABEL	"Point 19";
	MEMBERS
	{
		x, trans2_TAB_X19;
		y, trans2_TAB_Y19;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE20
{
	LABEL	"Point 20";
	MEMBERS
	{
		x, trans2_TAB_X20;
		y, trans2_TAB_Y20;
	}
}


COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE21
{
	LABEL	"Point 21";
	MEMBERS
	{
		x, trans2_TAB_X21;
		y, trans2_TAB_Y21;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE22
{
	LABEL	"Point 22";
	MEMBERS
	{
		x, trans2_TAB_X22;
		y, trans2_TAB_Y22;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE23
{
	LABEL	"Point 23";
	MEMBERS
	{
		x, trans2_TAB_X23;
		y, trans2_TAB_Y23;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE24
{
	LABEL	"Point 24";
	MEMBERS
	{
		x, trans2_TAB_X24;
		y, trans2_TAB_Y24;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE25
{
	LABEL	"Point 25";
	MEMBERS
	{
		x, trans2_TAB_X25;
		y, trans2_TAB_Y25;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE26
{
	LABEL	"Point 26";
	MEMBERS
	{
		x, trans2_TAB_X26;
		y, trans2_TAB_Y26;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE27
{
	LABEL	"Point 27";
	MEMBERS
	{
		x, trans2_TAB_X27;
		y, trans2_TAB_Y27;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE28
{
	LABEL	"Point 28";
	MEMBERS
	{
		x, trans2_TAB_X28;
		y, trans2_TAB_Y28;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE29
{
	LABEL	"Point 29";
	MEMBERS
	{
		x, trans2_TAB_X29;
		y, trans2_TAB_Y29;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE30
{
	LABEL	"Point 30";
	MEMBERS
	{
		x, trans2_TAB_X30;
		y, trans2_TAB_Y30;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE31
{
	LABEL	"Point 31";
	MEMBERS
	{
		x, trans2_TAB_X31;
		y, trans2_TAB_Y31;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE32
{
	LABEL	"Point 32";
	MEMBERS
	{
		x, trans2_TAB_X32;
		y, trans2_TAB_Y32;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE33
{
	LABEL	"Point 33";
	MEMBERS
	{
		x, trans2_TAB_X33;
		y, trans2_TAB_Y33;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE34
{
	LABEL	"Point 34";
	MEMBERS
	{
		x, trans2_TAB_X34;
		y, trans2_TAB_Y34;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE35
{
	LABEL	"Point 35";
	MEMBERS
	{
		x, trans2_TAB_X35;
		y, trans2_TAB_Y35;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE36
{
	LABEL	"Point 36";
	MEMBERS
	{
		x, trans2_TAB_X36;
		y, trans2_TAB_Y36;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE37
{
	LABEL	"Point 37";
	MEMBERS
	{
		x, trans2_TAB_X37;
		y, trans2_TAB_Y37;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE38
{
	LABEL	"Point 38";
	MEMBERS
	{
		x, trans2_TAB_X38;
		y, trans2_TAB_Y38;
	}
}


COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE39
{
	LABEL	"Point 39";
	MEMBERS
	{
		x, trans2_TAB_X39;
		y, trans2_TAB_Y39;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE40
{
	LABEL	"Point 40";
	MEMBERS
	{
		x, trans2_TAB_X40;
		y, trans2_TAB_Y40;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE41
{
	LABEL	"Point 41";
	MEMBERS
	{
		x, trans2_TAB_X41;
		y, trans2_TAB_Y41;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE42
{
	LABEL	"Point 42";
	MEMBERS
	{
		x, trans2_TAB_X42;
		y, trans2_TAB_Y42;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE43
{
	LABEL	"Point 43";
	MEMBERS
	{
		x, trans2_TAB_X43;
		y, trans2_TAB_Y43;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE44
{
	LABEL	"Point 44";
	MEMBERS
	{
		x, trans2_TAB_X44;
		y, trans2_TAB_Y44;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE45
{
	LABEL	"Point 45";
	MEMBERS
	{
		x, trans2_TAB_X45;
		y, trans2_TAB_Y45;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE46
{
	LABEL	"Point 46";
	MEMBERS
	{
		x, trans2_TAB_X46;
		y, trans2_TAB_Y46;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE47
{
	LABEL	"Point 47";
	MEMBERS
	{
		x, trans2_TAB_X47;
		y, trans2_TAB_Y47;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE48
{
	LABEL	"Point 48";
	MEMBERS
	{
		x, trans2_TAB_X48;
		y, trans2_TAB_Y48;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE49
{
	LABEL	"Point 49";
	MEMBERS
	{
		x, trans2_TAB_X49;
		y, trans2_TAB_Y49;
	}
}

COLLECTION OF VARIABLE trans2_TAB_X_Y_VALUE50
{
	LABEL	"Point 50";
	MEMBERS
	{
		x, trans2_TAB_X50;
		y, trans2_TAB_Y50;
	}
}

/*******************************************************************************/
/*****	OUTPUT 1 VARIABLES  ****************************************************/
/*******************************************************************************/
VARIABLE func1_BLK_RESERVE
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
  	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE func1_BLK_OBJECT
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	2;
		{	2,	[blk_block_object_FUNCTION]	}
	}
	HANDLING	READ;
}

VARIABLE func1_BLK_PARENT_CLASS
{
	LABEL		[blk_parent_class];
	HELP		[FB_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	1;
		{	1,	[func_blk_parent_class_INPUT]	}
	}
	HANDLING	READ;
}

VARIABLE func1_BLK_CLASS
{
	LABEL		[blk_class];
	HELP		[FB_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	1;
		{	1,	[func_blk_class_AI]		}
	}
	HANDLING	READ;
}

VARIABLE func1_BLK_DD_REFRENCE
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE func1_BLK_DD_REV
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE func1_BLK_PROFILE
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x4002;
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE func1_BLK_PROFILE_REV
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0300;
		{	0x0300,	"3.0"	}
	}
	HANDLING	READ;
}

VARIABLE func1_BLK_EXECUTION_TIME
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE func1_BLK_NUM_PARAMETERS
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func1_BLK_INDEX_VIEW_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func1_BLK_NUM_VIEW_LISTS
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func1_STATIC_REVISION
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE func1_TAG_DESCRIPTION
{
	LABEL		[tag_desc];		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_STRATEGY
{
	LABEL		[strategy];		
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE func1_ALERT_KEY
{
	LABEL		[alert_key];		
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE func1_TARGET_MODE
{
	LABEL	  	[target_mode];		
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	   DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}

	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_ACTUAL_MODE
{
	LABEL		[actual_mode];		
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0x08 ;
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE func1_PERMITTED_MODE
{
	LABEL		[permitted_mode];		
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x88;
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE func1_NORMAL_MODE
{
	LABEL		[normal_mode];		
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE func1_CURRENT_STATE_ALARM_SUM
{
	LABEL		[current_state_alarm_sum];		
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE func1_UNACKNOWLEDGED_STATE_ALARM_SUM
{
	LABEL		[unacknowledged_state_alarm_sum];		
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE func1_UNREPORTED_STATE_ALARM_SUM
{
	LABEL		[unreported_state_alarm_sum];		
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE func1_DISABLED_STATE_ALARM_SUM
{
	LABEL		[disabled_state_alarm_sum];		
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE func1_BATCH_ID
{
	LABEL		[func_batch_id];		
	HELP		[func_batch_id_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_BATCH_UNIT
{
	LABEL		[func_batch_unit];		
	HELP		[func_batch_unit_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_BATCH_OPERATION
{
	LABEL		[func_batch_operation];		
	HELP		[func_batch_operation_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_BATCH_PHASE
{
	LABEL		[func_batch_phase];		
	HELP		[func_batch_phase_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_OUT_VALUE
{
	LABEL		"Output Value AI 1";
	HELP		[func_ai_out_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING
		IF(func1_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func1_OUT_STATUS
{
	LABEL		[func_out_status];
	HELP		[func_out_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		STATUS_INPUT
	}
	HANDLING
		IF(func1_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func1_PV_SCALE_UPPER
{
	LABEL		"Upper Value [EU100%]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100.00;
		DISPLAY_FORMAT  ".4f";
	}
	HANDLING
		IF(func1_TARGET_MODE == BLOCK_MODE_OOS || func1_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func1_PV_SCALE_LOWER
{
	LABEL		"Lower Value [EU0%]";
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT  ".4f";
	}
	HANDLING
		IF(func1_TARGET_MODE == BLOCK_MODE_OOS || func1_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func1_OUTPUT_SCALE_LOWER_VALUE
{
	LABEL		"Lower Value [EU0%]";
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT  ".4f";
	}
	HANDLING
		IF(func1_TARGET_MODE == BLOCK_MODE_OOS || func1_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func1_OUTPUT_SCALE_UPPER_VALUE
{
	LABEL		"Upper Value [EU100%]";
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 100.00;
		DISPLAY_FORMAT  ".4f";
	}
	HANDLING
		IF(func1_TARGET_MODE == BLOCK_MODE_OOS || func1_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func1_OUTPUT_SCALE_UNIT
{
	LABEL		[digital_units];	
	HELP		[digital_units_help];
	CLASS		CONTAINED & SERVICE;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE degC;
		UNIT_LIST
	}
	HANDLING
		IF(func1_TARGET_MODE == BLOCK_MODE_OOS || func1_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func1_OUTPUT_SCALE_DECIMAL_POINT
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE  1;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		},
		{	4,   "4"		},
		{	5,   "5"		},
		{	6,   "6"		}
	}
	HANDLING
		IF(func1_TARGET_MODE == BLOCK_MODE_OOS || func1_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func1_LIN_TYPE
{
	LABEL		[trans_lin_type];
	HELP		[trans_lin_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0,	[linear]			}
	}
	HANDLING  	READ & WRITE;
}

VARIABLE func1_CHANNEL
{
	LABEL		"Channel"; 
	HELP		[func_channel_help];
	CLASS		CONTAINED;
   	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x119;
		IS_SINGLE
		{
	 		{ 0x119,"Primary Value"			},
			{ 0x11B,"Sensor 1 Value"		},
			{ 0x156,"Internal Temperature"	}
		}
		ELSE
		{
	 		{ 0x119,"Primary Value"			},
			{ 0x11B,"Sensor 1 Value"		},
			{ 0x11C,"Sensor 2 Value"		},
			{ 0x156,"Internal Temperature"	}
		}
	}
	HANDLING
		IF(func1_TARGET_MODE == BLOCK_MODE_OOS )
   		{
   			READ & WRITE;
   		}
		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func1_PV_FTIME
{
	LABEL		[func_pv_ftime];
	HELP		[func_pv_ftime_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE		0.0;
		MAX_VALUE		500.0;
	}
	CONSTANT_UNIT [sec];
	HANDLING	  READ & WRITE;
}

VARIABLE func1_FSAFE_TYPE
{
	LABEL		[func_ai_fsafe_type];
	HELP		[func_ao_fsafe_type_help_PROFILE_3];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE    FUNC_STORING_LAST_SETPOINT;
		{ FUNC_STORING_LAST_SETPOINT,	[func_ai_fsafe_type_STORING_LAST_SETPOINT]	},
		{ FUNC_FAIL_SAFE_POSITION,		[func_ai_fsafe_type_FAIL_SAFE_POSITION]		}
	}
   HANDLING  READ & WRITE;
}

VARIABLE func1_FSAFE_VALUE
{
   LABEL     [func_ai_fsafe_value] ;
   HELP      [func_ai_fsafe_value_help];
   CLASS     CONTAINED;
   TYPE      FLOAT
   {
      DEFAULT_VALUE    0;
   }
   HANDLING  READ & WRITE;
}

VARIABLE func1_LIMIT_HYSTERESIS
{
	LABEL		[limit_hysteresis];
	HELP		[limit_hysteresis_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	5.0;
		MIN_VALUE		0.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_LIMIT_HI_HI
{
	LABEL		[limit_hi_hi];
	HELP		[limit_hi_hi_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_LIMIT_HI
{
	LABEL		[limit_hi];
	HELP		[limit_hi_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_LIMIT_LO
{
	LABEL		[limit_lo];
	HELP		[limit_lo_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_LIMIT_LO_LO
{
	LABEL		[limit_lo_lo];
	HELP		[limit_lo_lo_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_HI_HI_ALM_UNACKNOWLEDGED
{
	LABEL		[limit_alarm_unacknowledged];
	HELP		[limit_alarm_unacknowledged_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func1_HI_HI_ALM_STATE
{
	LABEL		[limit_state];
	HELP		[limit_hi_hi_state_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[limit_state_NO_ALARM]	},
		{	1,	[limit_state_HI_HI]		}
	}
	HANDLING	READ;
}
/*
VARIABLE func1_HI_HI_ALM_TIMESTAMP
{
	LABEL		[limit_time_stamp];
	HELP		[limit_time_stamp_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ASCII (8);
//	TYPE		TIME_VALUE;
	HANDLING	READ;
}
*/

VARIABLE func1_HI_HI_ALM_TIMESTAMP_HIGH
{
	LABEL		"high_HI_HI1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func1_HI_HI_ALM_TIMESTAMP_LOW
{
	LABEL		"low_HI_HI1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func1_HI_HI_ALM_SUBCODE
{
	LABEL		[limit_subcode];
	HELP		[limit_hi_hi_subcode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func1_HI_HI_ALM_VALUE
{
	LABEL		[limit_alarm_value];
	HELP		[limit_hi_hi_alarm_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}	

VARIABLE func1_HI_ALM_UNACKNOWLEDGED
{
	LABEL		[limit_warn_unacknowledged];
	HELP		[limit_warn_unacknowledged_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func1_HI_ALM_STATE
{
	LABEL		[limit_state];
	HELP		[limit_hi_state_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[limit_state_NO_WARNING]	},
		{	1,	[limit_state_HI]			}
	}
	HANDLING	READ;
}

/*
VARIABLE func1_HI_ALM_TIMESTAMP
{
	LABEL		[limit_time_stamp];
	HELP		[limit_time_stamp_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ASCII (8);
//	TYPE		TIME_VALUE;
	HANDLING	READ;
}
*/

VARIABLE func1_HI_ALM_TIMESTAMP_HIGH
{
	LABEL		"high_HI1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func1_HI_ALM_TIMESTAMP_LOW
{
	LABEL		"low_HI1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func1_HI_ALM_SUBCODE
{
	LABEL		[limit_subcode];
	HELP		[limit_hi_subcode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func1_HI_ALM_VALUE
{
	LABEL		[limit_warn_value];
	HELP		[limit_hi_warn_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE func1_LO_ALM_UNACKNOWLEDGED
{
	LABEL		[limit_warn_unacknowledged];
	HELP		[limit_warn_unacknowledged_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func1_LO_ALM_STATE
{
	LABEL		[limit_state];
	HELP		[limit_lo_state_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[limit_state_NO_WARNING]	},
		{	1,	[limit_state_LO]			}
	}
	HANDLING	READ;
}

/*
VARIABLE func1_LO_ALM_TIMESTAMP
{
	LABEL		[limit_time_stamp];
	HELP		[limit_time_stamp_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ASCII (8);
//	TYPE		TIME_VALUE;
	HANDLING	READ;
}
*/

VARIABLE func1_LO_ALM_TIMESTAMP_HIGH
{
	LABEL		"high_LO1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func1_LO_ALM_TIMESTAMP_LOW
{
	LABEL		"low_LO1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func1_LO_ALM_SUBCODE
{
	LABEL		[limit_subcode];
	HELP		[limit_lo_subcode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func1_LO_ALM_VALUE
{
	LABEL		[limit_warn_value];
	HELP		[limit_lo_warn_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE func1_LO_LO_ALM_UNACKNOWLEDGED
{
	LABEL		[limit_alarm_unacknowledged];
	HELP		[limit_alarm_unacknowledged_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func1_LO_LO_ALM_STATE
{
	LABEL		[limit_state];
	HELP		[limit_lo_lo_state_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[limit_state_NO_ALARM]		},
		{	1,	[limit_state_LO_LO]			}
	}
	HANDLING	READ;
}

/*
VARIABLE func1_LO_LO_ALM_TIMESTAMP
{
	LABEL		[limit_time_stamp];
	HELP		[limit_time_stamp_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ASCII (8);
//	TYPE		TIME_VALUE;
	HANDLING	READ;
}
*/

VARIABLE func1_LO_LO_ALM_TIMESTAMP_HIGH
{
	LABEL		"high_LO_LO1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func1_LO_LO_ALM_TIMESTAMP_LOW
{
	LABEL		"low_LO_LO1";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func1_LO_LO_ALM_SUBCODE
{
	LABEL		[limit_subcode];
	HELP		[limit_lo_lo_subcode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func1_LO_LO_ALM_VALUE
{
	LABEL		[limit_alarm_value];
	HELP		[limit_lo_lo_alarm_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE func1_SIMULATION_VALUE
{
	LABEL		"Simulation Value AI 1";
	HELP		[func_ai_simulate_value_help];
	CLASS		CONTAINED & SERVICE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE	0.0;
	}   
	HANDLING	READ & WRITE;
}

VARIABLE func1_SIMULATION_STATUS
{
	LABEL		[status_quality];
	HELP		[func_simulate_status_help];
	CLASS		CONTAINED & SERVICE;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_INPUT_NO_RCAS
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_SIMULATION_ENABLED
{
	LABEL		"Simulation AI 1";
	HELP		[func_simulation_enabled_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,	[disabled]		},
		{	1,	[enabled]		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_OUTPUT_UNIT_TEXT
{
	LABEL		"Out unit text";		
	HELP		"";
	CLASS		CONTAINED;
	TYPE		ASCII (16);
	HANDLING	READ & WRITE;
}

/*******************************************************************************/
/*****	OUTPUT 2 VARIABLES  ****************************************************/
/*******************************************************************************/
VARIABLE func2_BLK_RESERVE
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
  	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE func2_BLK_OBJECT
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	2;
		{	2,	[blk_block_object_FUNCTION]	}
	}
	HANDLING	READ;
}

VARIABLE func2_BLK_PARENT_CLASS
{
	LABEL		[blk_parent_class];
	HELP		[FB_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	1;
		{	1,	[func_blk_parent_class_INPUT]	}
	}
	HANDLING	READ;
}

VARIABLE func2_BLK_CLASS
{
	LABEL		[blk_class];
	HELP		[FB_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	1;
		{	1,	[func_blk_class_AI]		}
	}
	HANDLING	READ;
}

VARIABLE func2_BLK_DD_REFRENCE
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE func2_BLK_DD_REV
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE func2_BLK_PROFILE
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x4002;
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE func2_BLK_PROFILE_REV
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0300;
		{	0x0300,	"3.0"	}
	}
	HANDLING	READ;
}

VARIABLE func2_BLK_EXECUTION_TIME
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE func2_BLK_NUM_PARAMETERS
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func2_BLK_INDEX_VIEW_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func2_BLK_NUM_VIEW_LISTS
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func2_STATIC_REVISION
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE func2_TAG_DESCRIPTION
{
	LABEL		[tag_desc];		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_STRATEGY
{
	LABEL		[strategy];		
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}

VARIABLE func2_ALERT_KEY
{
	LABEL		[alert_key];		
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

VARIABLE func2_TARGET_MODE
{
	LABEL	  	[target_mode];		
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	   DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}

	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_ACTUAL_MODE
{
	LABEL		[actual_mode];		
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0x08 ;
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE func2_PERMITTED_MODE
{
	LABEL		[permitted_mode];		
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x88;
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE func2_NORMAL_MODE
{
	LABEL		[normal_mode];		
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE func2_CURRENT_STATE_ALARM_SUM
{
	LABEL		[current_state_alarm_sum];		
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE func2_UNACKNOWLEDGED_STATE_ALARM_SUM
{
	LABEL		[unacknowledged_state_alarm_sum];		
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE func2_UNREPORTED_STATE_ALARM_SUM
{
	LABEL		[unreported_state_alarm_sum];		
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE func2_DISABLED_STATE_ALARM_SUM
{
	LABEL		[disabled_state_alarm_sum];		
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		DEFAULT_VALUE	0x0000; 
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE func2_BATCH_ID
{
	LABEL		[func_batch_id];		
	HELP		[func_batch_id_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_BATCH_UNIT
{
	LABEL		[func_batch_unit];		
	HELP		[func_batch_unit_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_BATCH_OPERATION
{
	LABEL		[func_batch_operation];		
	HELP		[func_batch_operation_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_BATCH_PHASE
{
	LABEL		[func_batch_phase];		
	HELP		[func_batch_phase_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_OUT_VALUE
{
	LABEL		"Output Value AI 2";
	HELP		[func_ai_out_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING
		IF(func2_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func2_OUT_STATUS
{
	LABEL		[func_out_status];
	HELP		[func_out_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		STATUS_INPUT
	}
	HANDLING
		IF(func2_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func2_PV_SCALE_UPPER
{
	LABEL		"Upper Value [EU100%]";
	HELP		[func_pv_scale_upper_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100.00;
		DISPLAY_FORMAT  ".4f";
	}
	HANDLING
		IF(func2_TARGET_MODE == BLOCK_MODE_OOS || func2_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func2_PV_SCALE_LOWER
{
	LABEL		"Lower Value [EU0%]";
	HELP		[func_pv_scale_lower_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT  ".4f";
	}
	HANDLING
		IF(func2_TARGET_MODE == BLOCK_MODE_OOS || func2_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func2_OUTPUT_SCALE_LOWER_VALUE
{
	LABEL		"Lower Value [EU0%]";
	HELP		[func_out_scale_lower_value_help];
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 0.00;
		DISPLAY_FORMAT  ".4f";
	}
	HANDLING
		IF(func2_TARGET_MODE == BLOCK_MODE_OOS || func2_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func2_OUTPUT_SCALE_UPPER_VALUE
{
	LABEL		"Upper Value [EU100%]";
	HELP		[func_out_scale_upper_value_help];
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 100.00;
		DISPLAY_FORMAT  ".4f";
	}
	HANDLING
		IF(func2_TARGET_MODE == BLOCK_MODE_OOS || func2_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func2_OUTPUT_SCALE_UNIT
{
	LABEL		[digital_units];	
	HELP		[digital_units_help];
	CLASS		CONTAINED & SERVICE;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE degC;
		UNIT_LIST
	}
	HANDLING
		IF(func2_TARGET_MODE == BLOCK_MODE_OOS || func2_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func2_OUTPUT_SCALE_DECIMAL_POINT
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE  1;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		},
		{	4,   "4"		},
		{	5,   "5"		},
		{	6,   "6"		}
	}
	HANDLING
		IF(func2_TARGET_MODE == BLOCK_MODE_OOS || func2_TARGET_MODE == BLOCK_MODE_MAN)
   		{
   		  	READ & WRITE;
   		}
   		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func2_LIN_TYPE
{
	LABEL		[trans_lin_type];
	HELP		[trans_lin_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0,	[linear]			}
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_CHANNEL
{
	LABEL		"Channel"; 
	HELP		[func_channel_help];
	CLASS		CONTAINED;
   	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x11B;
		IS_SINGLE
		{
	 		{ 0x119,"Primary Value"			},
			{ 0x11B,"Sensor 1 Value"		},
			{ 0x156,"Internal Temperature"	}
		}
		ELSE
		{
	 		{ 0x119,"Primary Value"			},
			{ 0x11B,"Sensor 1 Value"		},
			{ 0x11C,"Sensor 2 Value"		},
			{ 0x156,"Internal Temperature"	}
		}
	}
	HANDLING
		IF(func2_TARGET_MODE == BLOCK_MODE_OOS )
   		{
   			READ & WRITE;
   		}
		ELSE 
   	 	{
   			READ;
   		}
}

VARIABLE func2_PV_FTIME
{
	LABEL		[func_pv_ftime];
	HELP		[func_pv_ftime_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE		0.0;
		MAX_VALUE		500.0;
	}
	CONSTANT_UNIT [sec];
	HANDLING	  READ & WRITE;
}

VARIABLE func2_FSAFE_TYPE
{
	LABEL		[func_ai_fsafe_type];
	HELP		[func_ao_fsafe_type_help_PROFILE_3];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE    FUNC_STORING_LAST_SETPOINT;
		{ FUNC_STORING_LAST_SETPOINT,	[func_ai_fsafe_type_STORING_LAST_SETPOINT]	},
		{ FUNC_FAIL_SAFE_POSITION,		[func_ai_fsafe_type_FAIL_SAFE_POSITION]		}
	}
   HANDLING  READ & WRITE;
}

VARIABLE func2_FSAFE_VALUE
{
   LABEL     [func_ai_fsafe_value] ;
   HELP      [func_ai_fsafe_value_help];
   CLASS     CONTAINED;
   TYPE      FLOAT
   {
      DEFAULT_VALUE    0;
   }
   HANDLING  READ & WRITE;
}

VARIABLE func2_LIMIT_HYSTERESIS
{
	LABEL		[limit_hysteresis];
	HELP		[limit_hysteresis_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 5.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_LIMIT_HI_HI
{
	LABEL		[limit_hi_hi];
	HELP		[limit_hi_hi_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_LIMIT_HI
{
	LABEL		[limit_hi];
	HELP		[limit_hi_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_LIMIT_LO
{
	LABEL		[limit_lo];
	HELP		[limit_lo_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_LIMIT_LO_LO
{
	LABEL		[limit_lo_lo];
	HELP		[limit_lo_lo_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0.0;
		DISPLAY_FORMAT	".4f";	
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_HI_HI_ALM_UNACKNOWLEDGED
{
	LABEL		[limit_alarm_unacknowledged];
	HELP		[limit_alarm_unacknowledged_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func2_HI_HI_ALM_STATE
{
	LABEL		[limit_state];
	HELP		[limit_hi_hi_state_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[limit_state_NO_ALARM]	},
		{	1,	[limit_state_HI_HI]		}
	}
	HANDLING	READ;
}

/*
VARIABLE func2_HI_HI_ALM_TIMESTAMP
{
	LABEL		[limit_time_stamp];
	HELP		[limit_time_stamp_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ASCII (8);
//	TYPE		TIME_VALUE;
	HANDLING	READ;
}
*/

VARIABLE func2_HI_HI_ALM_TIMESTAMP_HIGH
{
	LABEL		"high_HI_HI2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func2_HI_HI_ALM_TIMESTAMP_LOW
{
	LABEL		"low_HI_HI2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func2_HI_HI_ALM_SUBCODE
{
	LABEL		[limit_subcode];
	HELP		[limit_hi_hi_subcode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func2_HI_HI_ALM_VALUE
{
	LABEL		[limit_alarm_value];
	HELP		[limit_hi_hi_alarm_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}	

VARIABLE func2_HI_ALM_UNACKNOWLEDGED
{
	LABEL		[limit_warn_unacknowledged];
	HELP		[limit_warn_unacknowledged_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func2_HI_ALM_STATE
{
	LABEL		[limit_state];
	HELP		[limit_hi_state_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[limit_state_NO_WARNING]	},
		{	1,	[limit_state_HI]			}
	}
	HANDLING	READ;
}

/*
VARIABLE func2_HI_ALM_TIMESTAMP
{
	LABEL		[limit_time_stamp];
	HELP		[limit_time_stamp_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ASCII (8);
//	TYPE		TIME_VALUE;
	HANDLING	READ;
}
*/
VARIABLE func2_HI_ALM_TIMESTAMP_HIGH
{
	LABEL		"high_HI2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func2_HI_ALM_TIMESTAMP_LOW
{
	LABEL		"low_HI2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func2_HI_ALM_SUBCODE
{
	LABEL		[limit_subcode];
	HELP		[limit_hi_subcode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func2_HI_ALM_VALUE
{
	LABEL		[limit_warn_value];
	HELP		[limit_hi_warn_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE func2_LO_ALM_UNACKNOWLEDGED
{
	LABEL		[limit_warn_unacknowledged];
	HELP		[limit_warn_unacknowledged_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func2_LO_ALM_STATE
{
	LABEL		[limit_state];
	HELP		[limit_lo_state_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[limit_state_NO_WARNING]	},
		{	1,	[limit_state_LO]			}
	}
	HANDLING	READ;
}

/*
VARIABLE func2_LO_ALM_TIMESTAMP
{
	LABEL		[limit_time_stamp];
	HELP		[limit_time_stamp_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ASCII (8);
//	TYPE		TIME_VALUE;
	HANDLING	READ;
}
*/

VARIABLE func2_LO_ALM_TIMESTAMP_HIGH
{
	LABEL		"high_LO2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func2_LO_ALM_TIMESTAMP_LOW
{
	LABEL		"low_LO2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func2_LO_ALM_SUBCODE
{
	LABEL		[limit_subcode];
	HELP		[limit_lo_subcode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func2_LO_ALM_VALUE
{
	LABEL		[limit_warn_value];
	HELP		[limit_lo_warn_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE func2_LO_LO_ALM_UNACKNOWLEDGED
{
	LABEL		[limit_alarm_unacknowledged];
	HELP		[limit_alarm_unacknowledged_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE func2_LO_LO_ALM_STATE
{
	LABEL		[limit_state];
	HELP		[limit_lo_lo_state_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[limit_state_NO_ALARM]		},
		{	1,	[limit_state_LO_LO]			}
	}
	HANDLING	READ;
}

/*
VARIABLE func2_LO_LO_ALM_TIMESTAMP
{
	LABEL		[limit_time_stamp];
	HELP		[limit_time_stamp_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ASCII (8);
//	TYPE		TIME_VALUE;
	HANDLING	READ;
}
*/

VARIABLE func2_LO_LO_ALM_TIMESTAMP_HIGH
{
	LABEL		"high_LO_LO2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func2_LO_LO_ALM_TIMESTAMP_LOW
{
	LABEL		"low_LO_LO2";
	HELP		"";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE		 0;
	}
	HANDLING	READ;
}

VARIABLE func2_LO_LO_ALM_SUBCODE
{
	LABEL		[limit_subcode];
	HELP		[limit_lo_lo_subcode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE func2_LO_LO_ALM_VALUE
{
	LABEL		[limit_alarm_value];
	HELP		[limit_lo_lo_alarm_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE func2_SIMULATION_VALUE
{
	LABEL		"Simulation Value AI 2";
	HELP		[func_ai_simulate_value_help];
	CLASS		CONTAINED & SERVICE;
	TYPE        FLOAT
	{
		DEFAULT_VALUE	0.0;
	}   
	HANDLING	READ & WRITE;
}

VARIABLE func2_SIMULATION_STATUS
{
	LABEL		[status_quality];
	HELP		[func_simulate_status_help];
	CLASS		CONTAINED & SERVICE;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_INPUT_NO_RCAS
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_SIMULATION_ENABLED
{
	LABEL		"Simulation AI 2";
	HELP		[func_simulation_enabled_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,	[disabled]		},
		{	1,	[enabled]		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE func2_OUTPUT_UNIT_TEXT
{
	LABEL		"Out unit text";		
	HELP		"";
	CLASS		CONTAINED;
	TYPE		ASCII (16);
	HANDLING	READ & WRITE;
}

/*******************************************************************************/
/*****	METHODS  ***************************************************************/
/*******************************************************************************/
METHOD method_set
{
	LABEL		"Download";
	HELP		"Download changes to device";
	DEFINITION
	{
   	}
}

METHOD method_SENSOR_MEAS_TYPE
{
	LABEL	"Validtate SENSOR_MEAS_TYPE";
	CLASS	INPUT;
	DEFINITION
	{
		if(ivar_value(trans1_PRIMARY_VALUE_UNIT) == mA)
		{
			if(ivar_value(trans1_SENSOR_MEAS_TYPE) != 220)
			{
				iassign(trans1_SENSOR_MEAS_TYPE, 220);
			}
		}
	}
}

METHOD method_LIN_TYPE_1
{
	LABEL	"Validtate LIN_TYPE_1";
	CLASS	INPUT;
	DEFINITION
	{
		int unit;
		int type;

		unit = ivar_value(trans1_PRIMARY_VALUE_UNIT);
		type = ivar_value(trans1_LIN_TYPE_1);
		if(unit < degK || unit > degR)
		{
			if(type < 0 || type > 1)
				iassign(trans1_LIN_TYPE_1, 0);
		}
		else
		{
			if(type <= 1)
				iassign(trans1_LIN_TYPE_1, 102);
		}
	}
}

METHOD method_LIN_TYPE_2
{
	LABEL	"Validtate LIN_TYPE_2";
	CLASS	INPUT;
	DEFINITION
	{
		int lin1;
		int lin2;

		lin1 = ivar_value(trans1_LIN_TYPE_1);
		lin2 = ivar_value(trans1_LIN_TYPE_2);
		if(lin1 == 0 || lin1 == 1)
		{
			if(lin2 < 0 || lin2 > 1)
				iassign(trans1_LIN_TYPE_2, 0);
		}
		else if((lin1 >= 128 && lin1 <= 140) || lin1 == 240) 
		{
			if(lin2 < 100 || lin2 > 245)
				iassign(trans1_LIN_TYPE_2, 102);
		}
		else
		{
			if(lin2 < 100 || lin2 > 245 || (lin2 >= 128 && lin2 <= 240))
				iassign(trans1_LIN_TYPE_2, 102);
		}
	}
}

METHOD method_SENSOR_CONNECTION_1
{
	LABEL	"Validtate SENSOR_CONNECTION_1";
	CLASS	INPUT;
	DEFINITION
	{
		int type;
		int unit;

		type = ivar_value(trans1_SENSOR_CONNECTION_1);
		unit = ivar_value(trans1_PRIMARY_VALUE_UNIT);


		if(ivar_value(trans1_SENSOR_MEAS_TYPE) == 220)
		{
			if(unit == pcnt)
			{
				if(type < 1 || type > 2)
					iassign(trans1_SENSOR_CONNECTION_1, 1);
			}
		}
		else
		{
			if(unit == pcnt)
			{
				if(type != 1)
					iassign(trans1_SENSOR_CONNECTION_1, 1);
			}
			else if(unit >= degK && unit <= degR)
			{
				if(type < 0 || type > 1)
					iassign(trans1_SENSOR_CONNECTION_1, 0);
			}
			else
			{
				if(type < 0 || type > 1)
					iassign(trans1_SENSOR_CONNECTION_1, 0);
			}
		}
	}
}

METHOD method_SENSOR_CONNECTION_2
{
	LABEL	"Validtate SENSOR_CONNECTION_2";
	CLASS	INPUT;
	DEFINITION
	{
		int lin1;
		int lin2;
		int type;
		int unit;

		lin1 = ivar_value(trans1_LIN_TYPE_1);
		lin2 = ivar_value(trans1_LIN_TYPE_2);
		type = ivar_value(trans1_SENSOR_CONNECTION_2);
		unit = ivar_value(trans1_PRIMARY_VALUE_UNIT);

		if((lin1 >= 128 && lin1 <= 140) || lin1 == 240)
		{
			if(type < 0 || type > 1)
				iassign(trans1_SENSOR_CONNECTION_2, 0);
		}
		else
		{
			if((lin2 >= 100 && lin2 <= 127) || (lin2 >= 241 && lin2 <= 245))
			{
				if(type != 0)
					iassign(trans1_SENSOR_CONNECTION_2, 0);
			}
			else if(unit == ohm || unit == kOhm)
			{
				if(type != 0)
					iassign(trans1_SENSOR_CONNECTION_2, 0);
			}
			else
			{
				if(type != 1)
					iassign(trans1_SENSOR_CONNECTION_2, 1);
			}
		}
	}
}

METHOD method_RJ_TYPE
{
	LABEL	"update RJ TYPE";
	CLASS	INPUT;
	DEFINITION
	{
		int type;

		type = ivar_value(trans1_RJ_TYPE);
		if(ivar_value(trans1_SENSOR_MEAS_TYPE) == 220)
		{
			if(type < 0 || type > 4)
				iassign(trans1_RJ_TYPE, 0);
		}
		else
		{
			int lin2;

			lin2 = ivar_value(trans1_LIN_TYPE_2);
			if((lin2 >= 128 && lin2 <= 140) || lin2 == 240)
			{
				if(type < 0 || type > 3)
					iassign(trans1_RJ_TYPE, 0);
			}
			else
			{
				if(type < 0 || type > 2)
					iassign(trans1_RJ_TYPE, 0);
			}
		}
	}
}

METHOD method_SENSOR_LIMITS_1
{
	LABEL	"update LOWER_SENSOR_LIMIT_1";
	CLASS	INPUT;
	DEFINITION
	{
		float	lower_val, upper_val;
		switch (ivar_value(trans1_LIN_TYPE_1))
		{
			case 0:	    lower_val =	   0.0;	upper_val =  100.0; break;  /* Linear           */
			case 1:	    lower_val =	   0.0;	upper_val =  100.0; break;  /* Linearisation table */
			case 100:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt10		IEC	    */
			case 101:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt50	    IEC	    */
			case 102:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt100	IEC	    */
			case 103:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt200	IEC	    */
			case 104:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt500	IEC	    */
			case 105:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt1000	IEC	    */
			case 106:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt10     JIS     */
			case 107:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt50		JIS	    */
			case 108:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt100	JIS     */
			case 122:	lower_val =  -60.0;	upper_val =  250.0;	break;	/* Ni50             */
			case 123:	lower_val =  -60.0;	upper_val =  250.0;	break;	/* Ni100	   	    */
			case 124:	lower_val =  -60.0;	upper_val =  250.0;	break;	/* Ni120            */
			case 125:	lower_val =  -60.0;	upper_val =  250.0;	break;	/* Ni1000           */
			case 126:	lower_val =  -50.0;	upper_val =  200.0;	break;	/* Cu10             */
			case 127:	lower_val =  -50.0;	upper_val =  200.0;	break;	/* Cu100            */
			case 128:	lower_val =  400.0;	upper_val = 1820.0;	break;	/* TC type B        */
			case 129:	lower_val =    0.0;	upper_val = 2315.0;	break;	/* TC type C        */
			case 130:	lower_val =    0.0;	upper_val = 2315.0;	break;	/* TC type D        */
			case 132:	lower_val =  400.0;	upper_val = 1820.0;	break;	/* TC type G	    */
			case 133:	lower_val = -100.0;	upper_val = 1200.0;	break;	/* TC type J	    */
			case 134:	lower_val = -180.0;	upper_val = 1372.0;	break;	/* TC type K	    */
			case 135:	lower_val = -180.0;	upper_val = 1302.0;	break;	/* TC type N	    */
			case 136:	lower_val =  -50.0;	upper_val = 1760.0;	break;	/* TC type R	    */
			case 137:	lower_val =  -50.0;	upper_val = 1760.0;	break;	/* TC type S	    */ 
			case 138:	lower_val = -200.0;	upper_val = 400.0;	break;	/* TC type T	    */ 
			case 139:	lower_val = -100.0;	upper_val = 900.0;	break;	/* TC type L	    */ 
			case 140:	lower_val = -200.0;	upper_val = 600.0;	break;	/* TC type U	    */ 
			case 240:	lower_val = -200.0;	upper_val = 850.0;	break;	/* Custom TC	    */ 
			case 241:	lower_val = -200.0;	upper_val = 850.0;	break;	/* Custom RTD	    */ 
			case 242:	lower_val = -200.0;	upper_val = 850.0;	break;	/* PtX (IEC)	    */ 
			case 243:	lower_val = -200.0;	upper_val = 850.0;	break;	/* PtX (JIS)	    */ 
			case 244:	lower_val = -200.0;	upper_val = 850.0;	break;	/* NiX (DIN)	    */ 
			case 245:	lower_val = -200.0;	upper_val = 850.0;	break;	/* CuX				*/ 
			default:	lower_val = -200.0; upper_val =  850.0;
		}
		CELSIUS_TO_CURRENT_UNIT(lower_val);
		CELSIUS_TO_CURRENT_UNIT(upper_val);
		fassign(trans1_LOWER_SENSOR_LIMIT_1, lower_val);
		fassign(trans1_UPPER_SENSOR_LIMIT_1, upper_val);
	}
}

METHOD method_SENSOR_LIMITS_2
{
	LABEL	"update LOWER_SENSOR_LIMIT_2";
	CLASS	INPUT;
	DEFINITION
	{
		float	lower_val, upper_val;
		switch (ivar_value(trans1_LIN_TYPE_2))
		{
			case 0:	    lower_val =	   0.0;	upper_val =  100.0; break;  /* Linear           */
			case 1:	    lower_val =	   0.0;	upper_val =  100.0; break;  /* Linearisation table */
			case 100:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt10		IEC	    */
			case 101:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt50	    IEC	    */
			case 102:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt100	IEC	    */
			case 103:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt200	IEC	    */
			case 104:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt500	IEC	    */
			case 105:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt1000	IEC	    */
			case 106:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt10     JIS     */
			case 107:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt50		JIS	    */
			case 108:	lower_val = -200.0;	upper_val =  850.0;	break;	/* Pt100	JIS     */
			case 122:	lower_val =  -60.0;	upper_val =  250.0;	break;	/* Ni50             */
			case 123:	lower_val =  -60.0;	upper_val =  250.0;	break;	/* Ni100	   	    */
			case 124:	lower_val =  -60.0;	upper_val =  250.0;	break;	/* Ni120            */
			case 125:	lower_val =  -60.0;	upper_val =  250.0;	break;	/* Ni1000           */
			case 126:	lower_val =  -50.0;	upper_val =  200.0;	break;	/* Cu10             */
			case 127:	lower_val =  -50.0;	upper_val =  200.0;	break;	/* Cu100            */
			case 128:	lower_val =  400.0;	upper_val = 1820.0;	break;	/* TC type B        */
			case 129:	lower_val =    0.0;	upper_val = 2315.0;	break;	/* TC type C        */
			case 130:	lower_val =    0.0;	upper_val = 2315.0;	break;	/* TC type D        */
			case 132:	lower_val =  400.0;	upper_val = 1820.0;	break;	/* TC type G	    */
			case 133:	lower_val = -100.0;	upper_val = 1200.0;	break;	/* TC type J	    */
			case 134:	lower_val = -180.0;	upper_val = 1372.0;	break;	/* TC type K	    */
			case 135:	lower_val = -180.0;	upper_val = 1302.0;	break;	/* TC type N	    */
			case 136:	lower_val =  -50.0;	upper_val = 1760.0;	break;	/* TC type R	    */
			case 137:	lower_val =  -50.0;	upper_val = 1760.0;	break;	/* TC type S	    */ 
			case 138:	lower_val = -200.0;	upper_val = 400.0;	break;	/* TC type T	    */ 
			case 139:	lower_val = -100.0;	upper_val = 900.0;	break;	/* TC type L	    */ 
			case 140:	lower_val = -200.0;	upper_val = 600.0;	break;	/* TC type U	    */ 
			case 240:	lower_val = -200.0;	upper_val = 850.0;	break;	/* Custom TC	    */ 
			case 241:	lower_val = -200.0;	upper_val = 850.0;	break;	/* Custom RTD	    */ 
			case 242:	lower_val = -200.0;	upper_val = 850.0;	break;	/* PtX (IEC)	    */ 
			case 243:	lower_val = -200.0;	upper_val = 850.0;	break;	/* PtX (JIS)	    */ 
			case 244:	lower_val = -200.0;	upper_val = 850.0;	break;	/* NiX (DIN)	    */ 
			case 245:	lower_val = -200.0;	upper_val = 850.0;	break;	/* CuX				*/ 
			default:	lower_val = -200.0; upper_val =  850.0;
		}
		CELSIUS_TO_CURRENT_UNIT(lower_val);
		CELSIUS_TO_CURRENT_UNIT(upper_val);
		fassign(trans1_LOWER_SENSOR_LIMIT_2, lower_val);
		fassign(trans1_UPPER_SENSOR_LIMIT_2, upper_val);
	}
}

/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/
UNIT TRANS1_UNIT
{
	trans1_PRIMARY_VALUE_UNIT:
		trans1_PRIMARY_VALUE,
		trans1_SECONDARY_VALUE_1,
		trans1_SECONDARY_VALUE_2,
		trans1_LOWER_SENSOR_LIMIT_1,
		trans1_UPPER_SENSOR_LIMIT_1,
		trans1_LOWER_SENSOR_LIMIT_2,
		trans1_UPPER_SENSOR_LIMIT_2,
		trans1_MIN_SENSOR_VALUE_1,
		trans1_MAX_SENSOR_VALUE_1,
		trans1_MIN_SENSOR_VALUE_2,
		trans1_MAX_SENSOR_VALUE_2,
		trans1_BIAS_1,
		trans1_BIAS_2,
		trans1_EXTERNAL_RJ_VALUE,
		trans1_RJ_TEMP,
		trans1_INTERN_TEMP
}

UNIT FUNC1_UNIT
{
	func1_OUTPUT_SCALE_UNIT:
		func1_OUTPUT_SCALE_LOWER_VALUE,
		func1_OUTPUT_SCALE_UPPER_VALUE,
		func1_LIMIT_LO_LO,
		func1_LIMIT_LO,
		func1_LIMIT_HI,
		func1_LIMIT_HI_HI,
		func1_LIMIT_HYSTERESIS,
		func1_HI_HI_ALM_VALUE,
		func1_HI_ALM_VALUE,
		func1_LO_ALM_VALUE,
		func1_LO_LO_ALM_VALUE
}

UNIT FUNC2_UNIT
{
	func2_OUTPUT_SCALE_UNIT:
		func2_OUTPUT_SCALE_LOWER_VALUE,
		func2_OUTPUT_SCALE_UPPER_VALUE,
		func2_LIMIT_LO_LO,
		func2_LIMIT_LO,
		func2_LIMIT_HI,
		func2_LIMIT_HI_HI,
		func2_LIMIT_HYSTERESIS,
		func2_HI_HI_ALM_VALUE,
		func2_HI_ALM_VALUE,
		func2_LO_ALM_VALUE,
		func2_LO_LO_ALM_VALUE
}

REFRESH	SENSOR_LIMITS_1
{
	trans1_LIN_TYPE_1:
		trans1_LOWER_SENSOR_LIMIT_1,
		trans1_UPPER_SENSOR_LIMIT_1
}

REFRESH	SENSOR_LIMITS_2
{
	trans1_LIN_TYPE_2:
		trans1_LOWER_SENSOR_LIMIT_2,
		trans1_UPPER_SENSOR_LIMIT_2
}

/***********************************************************************/
/*    Commands                                                         */
/***********************************************************************/

/* phys_BLOCK */
COMMAND read_phys_BLOCK
{
	BLOCK phys_BLOCK;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_BLK_RESERVE,
			phys_BLK_OBJECT,
			phys_BLK_PARENT_CLASS,
			phys_BLK_CLASS,
			phys_BLK_DD_REFRENCE,
			phys_BLK_DD_REV,
			phys_BLK_PROFILE,
			phys_BLK_PROFILE_REV,
			phys_BLK_EXECUTION_TIME,
			phys_BLK_NUM_PARAMETERS,
			phys_BLK_INDEX_VIEW_1,
			phys_BLK_NUM_VIEW_LISTS
		}
	}
}

COMMAND read_phys_STATIC_REVISION
{
	BLOCK phys_BLOCK;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_STATIC_REVISION
		}
	}
}

COMMAND read_phys_TAG_DESCRIPTION
{
	BLOCK phys_BLOCK;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_TAG_DESCRIPTION
		}
	}
}

COMMAND write_phys_TAG_DESCRIPTION
{
	BLOCK phys_BLOCK;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_TAG_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_STRATEGY
{
	BLOCK phys_BLOCK;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_STRATEGY
		}
	}
}

COMMAND write_phys_STRATEGY
{
	BLOCK phys_BLOCK;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_STRATEGY
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_ALERT_KEY
{
	BLOCK phys_BLOCK;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_ALERT_KEY
		}
	}
}

COMMAND write_phys_ALERT_KEY
{
	BLOCK phys_BLOCK;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_ALERT_KEY
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_TARGET_MODE
{
	BLOCK phys_BLOCK;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_TARGET_MODE
		}
	}
}

COMMAND write_phys_TARGET_MODE
{
	BLOCK phys_BLOCK;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_TARGET_MODE
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_MODE
{
	BLOCK phys_BLOCK;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_ACTUAL_MODE,
			phys_PERMITTED_MODE,
			phys_NORMAL_MODE
		}
	}
}

COMMAND read_phys_ALARM_SUM
{
	BLOCK phys_BLOCK;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_CURRENT_STATE_ALARM_SUM,
			phys_UNACKNOWLEDGED_STATE_ALARM_SUM,
			phys_UNREPORTED_STATE_ALARM_SUM,
			phys_DISABLED_STATE_ALARM_SUM
		}
	}
}

COMMAND read_phys_SOFTWARE_REVISION
{
	BLOCK phys_BLOCK;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_SOFTWARE_REVISION
		}
	}
}

COMMAND read_phys_HARDWARE_REVISION
{
	BLOCK phys_BLOCK;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_HARDWARE_REVISION
		}
	}
}

COMMAND read_phys_DEVICE_MAN_ID
{
	BLOCK phys_BLOCK;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DEVICE_MAN_ID
		}
	}
}

COMMAND read_phys_DEVICE_ID
{
	BLOCK phys_BLOCK;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DEVICE_ID
		}
	}
}

/*
COMMAND write_phys_DEVICE_ID
{
	BLOCK phys_BLOCK;
	INDEX 11;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_DEVICE_ID
		}
		REPLY
		{
		}
	}
}
*/			//fbi

COMMAND read_phys_SERIAL_NUMBER
{
	BLOCK phys_BLOCK;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_SERIAL_NUMBER
		}
	}
}

COMMAND read_phys_DIAGNOSIS
{
	BLOCK phys_BLOCK;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DIAGNOSIS
		}
	}
}

COMMAND read_phys_DIAGNOSIS_EXT
{
	BLOCK phys_BLOCK;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DIAGNOSIS_EXT_01,
			phys_DIAGNOSIS_EXT_02
		}
	}
}

COMMAND read_phys_DIAGNOSIS_MASK
{
	BLOCK phys_BLOCK;
	INDEX 15;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DIAGNOSIS_MASK
		}
	}
}

COMMAND read_phys_DIAGNOSIS_MASK_EXT
{
	BLOCK phys_BLOCK;
	INDEX 16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DIAGNOSIS_MASK_EXT_01,
			phys_DIAGNOSIS_MASK_EXT_02
		}
	}
}

COMMAND read_phys_CERTIFICATION
{
	BLOCK phys_BLOCK;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_CERTIFICATION
		}
	}
}

COMMAND read_phys_WRITE_LOCKING
{
	BLOCK phys_BLOCK;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_WRITE_LOCKING
		}
	}
}

COMMAND write_phys_WRITE_LOCKING
{
	BLOCK phys_BLOCK;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_WRITE_LOCKING
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_FACTORY_RESET
{
	BLOCK phys_BLOCK;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_FACTORY_RESET
		}
	}
}

COMMAND write_phys_FACTORY_RESET
{
	BLOCK phys_BLOCK;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_FACTORY_RESET
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_DESCRIPTION
{
	BLOCK phys_BLOCK;
	INDEX 20;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DESCRIPTION
		}
	}
}

COMMAND write_phys_DESCRIPTION
{
	BLOCK phys_BLOCK;
	INDEX 20;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_DEVICE_MESSAGE
{
	BLOCK phys_BLOCK;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_DEVICE_MESSAGE
		}
	}
}

COMMAND write_phys_DEVICE_MESSAGE
{
	BLOCK phys_BLOCK;
	INDEX 21;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_DEVICE_MESSAGE
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_INSTALL_DATE
{
	BLOCK phys_BLOCK;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_INSTALL_DATE
		}
	}
}

COMMAND write_phys_INSTALL_DATE
{
	BLOCK phys_BLOCK;
	INDEX 22;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_INSTALL_DATE
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_LOCAL_OP_ENABLED
{
	BLOCK phys_BLOCK;
	INDEX 23;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_LOCAL_OP_ENABLED
		}
	}
}

COMMAND write_phys_LOCAL_OP_ENABLED
{
	BLOCK phys_BLOCK;
	INDEX 23;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_LOCAL_OP_ENABLED
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_IDENT_NUMBER
{
	BLOCK phys_BLOCK;
	INDEX 24;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_IDENT_NUMBER
		}
	}
}

COMMAND write_phys_IDENT_NUMBER
{
	BLOCK phys_BLOCK;
	INDEX 24;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_IDENT_NUMBER
		}
		REPLY
		{
		}
	}
}
/*
COMMAND read_phys_HW_WRITE_PROTECTION
{
	BLOCK phys_BLOCK;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_HW_WRITE_PROTECTION
		}
	}
}
*/

/*********** Tranducer Block 1 **************/
/*************** trans BLOCK *****************/
COMMAND read_trans1_BLOCK
{
	BLOCK trans1_BLOCK;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_BLK_RESERVE,
			trans1_BLK_OBJECT,
			trans1_BLK_PARENT_CLASS,
			trans1_BLK_CLASS,
			trans1_BLK_DD_REFRENCE,
			trans1_BLK_DD_REV,
			trans1_BLK_PROFILE,
			trans1_BLK_PROFILE_REV,
			trans1_BLK_EXECUTION_TIME,
			trans1_BLK_NUM_PARAMETERS,
			trans1_BLK_INDEX_VIEW_1,
			trans1_BLK_NUM_VIEW_LISTS
		}
	}
}

COMMAND read_trans1_STATIC_REVISION
{
	BLOCK trans1_BLOCK;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_STATIC_REVISION
		}
	}
}

COMMAND read_trans1_TAG_DESCRIPTION
{
	BLOCK trans1_BLOCK;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_TAG_DESCRIPTION
		}
	}
}

COMMAND write_trans1_TAG_DESCRIPTION
{
	BLOCK trans1_BLOCK;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_TAG_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_STRATEGY
{
	BLOCK trans1_BLOCK;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_STRATEGY
		}
	}
}

COMMAND write_trans1_STRATEGY
{
	BLOCK trans1_BLOCK;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_STRATEGY
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_ALERT_KEY
{
	BLOCK trans1_BLOCK;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_ALERT_KEY
		}
	}
}

COMMAND write_trans1_ALERT_KEY
{
	BLOCK trans1_BLOCK;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_ALERT_KEY
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_TARGET_MODE
{
	BLOCK trans1_BLOCK;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_TARGET_MODE
		}
	}
}

COMMAND write_trans1_TARGET_MODE
{
	BLOCK trans1_BLOCK;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_TARGET_MODE
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_MODE
{
	BLOCK trans1_BLOCK;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_ACTUAL_MODE,
			trans1_PERMITTED_MODE,
			trans1_NORMAL_MODE
		}
	}
}

COMMAND read_trans1_ALARM_SUM
{
	BLOCK trans1_BLOCK;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CURRENT_STATE_ALARM_SUM,
			trans1_UNACKNOWLEDGED_STATE_ALARM_SUM,
			trans1_UNREPORTED_STATE_ALARM_SUM,
			trans1_DISABLED_STATE_ALARM_SUM
		}
	}
}

COMMAND read_trans1_PRIMARY_VALUE
{
	BLOCK trans1_BLOCK;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_PRIMARY_VALUE,
			trans1_PRIMARY_VALUE_STATUS
		}
	}
}

COMMAND read_trans1_PRIMARY_VALUE_UNIT
{
	BLOCK trans1_BLOCK;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_PRIMARY_VALUE_UNIT
		}
	}
}

COMMAND write_trans1_PRIMARY_VALUE_UNIT
{
	BLOCK trans1_BLOCK;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_PRIMARY_VALUE_UNIT
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SECONDARY_VALUE_1
{
	BLOCK trans1_BLOCK;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SECONDARY_VALUE_1, 
			trans1_SECONDARY_VALUE_STATUS_1
		}
	}
}

COMMAND read_trans1_SECONDARY_VALUE_2
{
	BLOCK trans1_BLOCK;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SECONDARY_VALUE_2, 
			trans1_SECONDARY_VALUE_STATUS_2
		}
	}
}

COMMAND read_trans1_SENSOR_MEAS_TYPE
{
	BLOCK trans1_BLOCK;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_MEAS_TYPE
		}
	}
}

COMMAND write_trans1_SENSOR_MEAS_TYPE
{
	BLOCK trans1_BLOCK;
	INDEX 12;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_MEAS_TYPE
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_LIN_TYPE_1
{
	BLOCK trans1_BLOCK;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_LIN_TYPE_1
		}
	}
}

COMMAND write_trans1_LIN_TYPE_1
{
	BLOCK trans1_BLOCK;
	INDEX 14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_LIN_TYPE_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_BIAS_1
{
	BLOCK trans1_BLOCK;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_BIAS_1
		}
	}
}

COMMAND write_trans1_BIAS_1
{
	BLOCK trans1_BLOCK;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_BIAS_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_BIAS_2
{
	BLOCK trans1_BLOCK;
	INDEX 20;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_BIAS_2
		}
	}
}

COMMAND write_trans1_BIAS_2
{
	BLOCK trans1_BLOCK;
	INDEX 20;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_BIAS_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_UPPER_SENSOR_LIMIT_1
{
	BLOCK trans1_BLOCK;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_UPPER_SENSOR_LIMIT_1
		}
	}
}

COMMAND read_trans1_LOWER_SENSOR_LIMIT_1
{
	BLOCK trans1_BLOCK;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_LOWER_SENSOR_LIMIT_1
		}
	}
}

COMMAND read_trans1_INPUT_FAULT_GEN
{
	BLOCK trans1_BLOCK;
	INDEX 24;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_INPUT_FAULT_GEN
		}
	}
}

COMMAND read_trans1_INPUT_FAULT_1
{
	BLOCK trans1_BLOCK;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_INPUT_FAULT_1
		}
	}
}

COMMAND read_trans1_INPUT_FAULT_2
{
	BLOCK trans1_BLOCK;
	INDEX 26;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_INPUT_FAULT_2
		}
	}
}

COMMAND read_trans1_SENSOR_WIRE_CHECK_1
{
	BLOCK trans1_BLOCK;
	INDEX 27;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_WIRE_CHECK_1
		}
	}
}

COMMAND write_trans1_SENSOR_WIRE_CHECK_1
{
	BLOCK trans1_BLOCK;
	INDEX 27;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_WIRE_CHECK_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_WIRE_CHECK_2
{
	BLOCK trans1_BLOCK;
	INDEX 28;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_WIRE_CHECK_2
		}
	}
}

COMMAND write_trans1_SENSOR_WIRE_CHECK_2
{
	BLOCK trans1_BLOCK;
	INDEX 28;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_WIRE_CHECK_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_MAX_SENSOR_VALUE_1
{
	BLOCK trans1_BLOCK;
	INDEX 29;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_MAX_SENSOR_VALUE_1
		}
	}
}

COMMAND write_trans1_MAX_SENSOR_VALUE_1
{
	BLOCK trans1_BLOCK;
	INDEX 29;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_MAX_SENSOR_VALUE_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_MIN_SENSOR_VALUE_1
{
	BLOCK trans1_BLOCK;
	INDEX 30;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_MIN_SENSOR_VALUE_1 
		}
	}
}

COMMAND write_trans1_MIN_SENSOR_VALUE_1
{
	BLOCK trans1_BLOCK;
	INDEX 30;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_MIN_SENSOR_VALUE_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_MAX_SENSOR_VALUE_2
{
	BLOCK trans1_BLOCK;
	INDEX 31;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_MAX_SENSOR_VALUE_2 
		}
	}
}

COMMAND write_trans1_MAX_SENSOR_VALUE_2
{
	BLOCK trans1_BLOCK;
	INDEX 31;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_MAX_SENSOR_VALUE_2 
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_MIN_SENSOR_VALUE_2
{
	BLOCK trans1_BLOCK;
	INDEX 32;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_MIN_SENSOR_VALUE_2 
		}
	}
}

COMMAND write_trans1_MIN_SENSOR_VALUE_2
{
	BLOCK trans1_BLOCK;
	INDEX 32;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_MIN_SENSOR_VALUE_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_RJ_TEMP
{
	BLOCK trans1_BLOCK;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_RJ_TEMP
		}
	}
}

COMMAND read_trans1_RJ_TYPE
{
	BLOCK trans1_BLOCK;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_RJ_TYPE
		}
	}
}

COMMAND write_trans1_RJ_TYPE
{
	BLOCK trans1_BLOCK;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_RJ_TYPE
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_EXTERNAL_RJ_VALUE
{
	BLOCK trans1_BLOCK;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_EXTERNAL_RJ_VALUE
		}
	}
}

COMMAND write_trans1_EXTERNAL_RJ_VALUE
{
	BLOCK trans1_BLOCK;
	INDEX 35;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_EXTERNAL_RJ_VALUE
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CONNECTION_1
{
	BLOCK trans1_BLOCK;
	INDEX 36;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CONNECTION_1
		}
	}
}

COMMAND write_trans1_SENSOR_CONNECTION_1
{
	BLOCK trans1_BLOCK;
	INDEX 36;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CONNECTION_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_COMP_WIRE_1
{
	BLOCK trans1_BLOCK;
	INDEX 37;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_COMP_WIRE_1
		}
	}
}

COMMAND write_trans1_COMP_WIRE_1
{
	BLOCK trans1_BLOCK;
	INDEX 37;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_COMP_WIRE_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_COMP_WIRE_2
{
	BLOCK trans1_BLOCK;
	INDEX 38;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_COMP_WIRE_2
		}
	}
}

COMMAND write_trans1_COMP_WIRE_2
{
	BLOCK trans1_BLOCK;
	INDEX 38;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_COMP_WIRE_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CONNECTION_2
{
	BLOCK trans1_BLOCK;
	INDEX 62;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CONNECTION_2
		}
	}
}

COMMAND write_trans1_SENSOR_CONNECTION_2
{
	BLOCK trans1_BLOCK;
	INDEX 62;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CONNECTION_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_LOWER_SENSOR_LIMIT_2
{
	BLOCK trans1_BLOCK;
	INDEX 63;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_LOWER_SENSOR_LIMIT_2
		}
	}
}

COMMAND read_trans1_UPPER_SENSOR_LIMIT_2
{
	BLOCK trans1_BLOCK;
	INDEX 64;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_UPPER_SENSOR_LIMIT_2
		}
	}
}

COMMAND read_trans1_LIN_TYPE_2
{
	BLOCK trans1_BLOCK;
	INDEX 65;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			trans1_LIN_TYPE_2
		}
	}
}

COMMAND write_trans1_LIN_TYPE_2
{
	BLOCK trans1_BLOCK;
	INDEX 65;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_LIN_TYPE_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_RJ_COMP_WIRE
{
	BLOCK trans1_BLOCK;
	INDEX 66;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_RJ_COMP_WIRE
		}
	}
}

COMMAND write_trans1_RJ_COMP_WIRE
{
	BLOCK trans1_BLOCK;
	INDEX 66;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_RJ_COMP_WIRE
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_RJ_FAULT
{
	BLOCK trans1_BLOCK;
	INDEX 67;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_RJ_FAULT
		}
	}
}

COMMAND read_trans1_SENSOR_WIRE_CHECK_RJ
{
	BLOCK trans1_BLOCK;
	INDEX 68;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_WIRE_CHECK_RJ
		}
	}
}

COMMAND write_trans1_SENSOR_WIRE_CHECK_RJ
{
	BLOCK trans1_BLOCK;
	INDEX 68;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_WIRE_CHECK_RJ
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_INTERN_TEMP
{
	BLOCK trans1_BLOCK;
	INDEX 69;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_INTERN_TEMP,
			trans1_INTERN_TEMP_STATUS
		}
	}
}

COMMAND read_trans1_CAL_POINT_LO_1
{
	BLOCK trans1_BLOCK;
	INDEX 70;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CAL_POINT_LO_1
		}
	}
}

COMMAND write_trans1_CAL_POINT_LO_1
{
	BLOCK trans1_BLOCK;
	INDEX 70;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_CAL_POINT_LO_1
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_CAL_ACTUAL_LO_1
{
	BLOCK trans1_BLOCK;
	INDEX 71;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CAL_ACTUAL_LO_1
		}
	}
}

COMMAND write_trans1_CAL_ACTUAL_LO_1
{
	BLOCK trans1_BLOCK;
	INDEX 71;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_CAL_ACTUAL_LO_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_CAL_POINT_HI_1
{
	BLOCK trans1_BLOCK;
	INDEX 72;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CAL_POINT_HI_1
		}
	}
}

COMMAND write_trans1_CAL_POINT_HI_1
{
	BLOCK trans1_BLOCK;
	INDEX 72;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_CAL_POINT_HI_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_CAL_ACTUAL_HI_1
{
	BLOCK trans1_BLOCK;
	INDEX 73;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CAL_ACTUAL_HI_1
		}
	}
}

COMMAND write_trans1_CAL_ACTUAL_HI_1
{
	BLOCK trans1_BLOCK;
	INDEX 73;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_CAL_ACTUAL_HI_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CAL_METHOD_1
{
	BLOCK trans1_BLOCK;
	INDEX 74;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CAL_METHOD_1
		}
	}
}

COMMAND write_trans1_SENSOR_CAL_METHOD_1
{
	BLOCK trans1_BLOCK;
	INDEX 74;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CAL_METHOD_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CAL_LOC_1
{
	BLOCK trans1_BLOCK;
	INDEX 75;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CAL_LOC_1
		}
	}
}

COMMAND write_trans1_SENSOR_CAL_LOC_1
{
	BLOCK trans1_BLOCK;
	INDEX 75;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CAL_LOC_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CAL_DATE_1
{
	BLOCK trans1_BLOCK;
	INDEX 76;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CAL_DATE_1
//			trans1_SENSOR_CAL_DATE_1[1],
//			trans1_SENSOR_CAL_DATE_1[2],
//			trans1_SENSOR_CAL_DATE_1[3],
//			trans1_SENSOR_CAL_DATE_1[4],
//			trans1_SENSOR_CAL_DATE_1[5],
//			trans1_SENSOR_CAL_DATE_1[6]
		}
	}
}

COMMAND write_trans1_SENSOR_CAL_DATE_1
{
	BLOCK trans1_BLOCK;
	INDEX 76;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CAL_DATE_1
//			trans1_SENSOR_CAL_DATE_1[1],
//			trans1_SENSOR_CAL_DATE_1[2],
//			trans1_SENSOR_CAL_DATE_1[3],
//			trans1_SENSOR_CAL_DATE_1[4],
//			trans1_SENSOR_CAL_DATE_1[5],
//			trans1_SENSOR_CAL_DATE_1[6]
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CAL_WHO_1
{
	BLOCK trans1_BLOCK;
	INDEX 77;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CAL_WHO_1
		}
	}
}

COMMAND write_trans1_SENSOR_CAL_WHO_1
{
	BLOCK trans1_BLOCK;
	INDEX 77;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CAL_WHO_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_CAL_POINT_LO_2
{
	BLOCK trans1_BLOCK;
	INDEX 78;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CAL_POINT_LO_2
		}
	}
}

COMMAND write_trans1_CAL_POINT_LO_2
{
	BLOCK trans1_BLOCK;
	INDEX 78;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_CAL_POINT_LO_2
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_CAL_ACTUAL_LO_2
{
	BLOCK trans1_BLOCK;
	INDEX 79;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CAL_ACTUAL_LO_2
		}
	}
}

COMMAND write_trans1_CAL_ACTUAL_LO_2
{
	BLOCK trans1_BLOCK;
	INDEX 79;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_CAL_ACTUAL_LO_2
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_CAL_POINT_HI_2
{
	BLOCK trans1_BLOCK;
	INDEX 80;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CAL_POINT_HI_2
		}
	}
}

COMMAND write_trans1_CAL_POINT_HI_2
{
	BLOCK trans1_BLOCK;
	INDEX 80;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_CAL_POINT_HI_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_CAL_ACTUAL_HI_2
{
	BLOCK trans1_BLOCK;
	INDEX 81;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CAL_ACTUAL_HI_2
		}
	}
}

COMMAND write_trans1_CAL_ACTUAL_HI_2
{
	BLOCK trans1_BLOCK;
	INDEX 81;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_CAL_ACTUAL_HI_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CAL_METHOD_2
{
	BLOCK trans1_BLOCK;
	INDEX 82;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CAL_METHOD_2
		}
	}
}

COMMAND write_trans1_SENSOR_CAL_METHOD_2
{
	BLOCK trans1_BLOCK;
	INDEX 82;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CAL_METHOD_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CAL_LOC_2
{
	BLOCK trans1_BLOCK;
	INDEX 83;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CAL_LOC_2
		}
	}
}

COMMAND write_trans1_SENSOR_CAL_LOC_2
{
	BLOCK trans1_BLOCK;
	INDEX 83;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CAL_LOC_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CAL_DATE_2
{
	BLOCK trans1_BLOCK;
	INDEX 84;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CAL_DATE_2
//			trans1_SENSOR_CAL_DATE_2[1],
//			trans1_SENSOR_CAL_DATE_2[2],
//			trans1_SENSOR_CAL_DATE_2[3],
//			trans1_SENSOR_CAL_DATE_2[4],
//			trans1_SENSOR_CAL_DATE_2[5],
//			trans1_SENSOR_CAL_DATE_2[6]
		}
	}
}

COMMAND write_trans1_SENSOR_CAL_DATE_2
{
	BLOCK trans1_BLOCK;
	INDEX 84;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CAL_DATE_2
//			trans1_SENSOR_CAL_DATE_2[1],
//			trans1_SENSOR_CAL_DATE_2[2],
//			trans1_SENSOR_CAL_DATE_2[3],
//			trans1_SENSOR_CAL_DATE_2[4],
//			trans1_SENSOR_CAL_DATE_2[5],
//			trans1_SENSOR_CAL_DATE_2[6]
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_SENSOR_CAL_WHO_2
{
	BLOCK trans1_BLOCK;
	INDEX 85;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_SENSOR_CAL_WHO_2
		}
	}
}

COMMAND write_trans1_SENSOR_CAL_WHO_2
{
	BLOCK trans1_BLOCK;
	INDEX 85;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_SENSOR_CAL_WHO_2
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_HW_ERROR
{
	BLOCK trans1_BLOCK;
	INDEX 86;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_HW_ERROR
		}
	}
}

COMMAND read_trans1_CABLE_RES1
{
	BLOCK trans1_BLOCK;
	INDEX 87;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CABLE_RES1
		}
	}
}

COMMAND read_trans1_CABLE_RES2
{
	BLOCK trans1_BLOCK;
	INDEX 88;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_CABLE_RES2
		}
	}
}

COMMAND read_trans1_RTDX_FACTOR_1
{
	BLOCK trans1_BLOCK;
	INDEX 89;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_RTDX_FACTOR_1
		}
	}
}

COMMAND write_trans1_RTDX_FACTOR_1
{
	BLOCK trans1_BLOCK;
	INDEX 89;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_RTDX_FACTOR_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_RTDX_FACTOR_2
{
	BLOCK trans1_BLOCK;
	INDEX 90;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_RTDX_FACTOR_2
		}
	}
}

COMMAND write_trans1_RTDX_FACTOR_2
{
	BLOCK trans1_BLOCK;
	INDEX 90;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_RTDX_FACTOR_2
		}
		REPLY
		{
		}
	}
}



/* End Transducer Block 1 */






/* Start Transducer Block 2 */

COMMAND read_trans2_BLOCK
{
	BLOCK trans2_BLOCK;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_BLK_RESERVE,
			trans2_BLK_OBJECT,
			trans2_BLK_PARENT_CLASS,
			trans2_BLK_CLASS,
			trans2_BLK_DD_REFRENCE,
			trans2_BLK_DD_REV,
			trans2_BLK_PROFILE,
			trans2_BLK_PROFILE_REV,
			trans2_BLK_EXECUTION_TIME,
			trans2_BLK_NUM_PARAMETERS,
			trans2_BLK_INDEX_VIEW_1,
			trans2_BLK_NUM_VIEW_LISTS
		}
	}
}

COMMAND read_trans2_STATIC_REVISION
{
	BLOCK trans2_BLOCK;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_STATIC_REVISION
		}
	}
}

COMMAND read_trans2_TAG_DESCRIPTION
{
	BLOCK trans2_BLOCK;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAG_DESCRIPTION
		}
	}
}

COMMAND write_trans2_TAG_DESCRIPTION
{
	BLOCK trans2_BLOCK;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAG_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_STRATEGY
{
	BLOCK trans2_BLOCK;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_STRATEGY
		}
	}
}

COMMAND write_trans2_STRATEGY
{
	BLOCK trans2_BLOCK;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_STRATEGY
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_ALERT_KEY
{
	BLOCK trans2_BLOCK;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_ALERT_KEY
		}
	}
}

COMMAND write_trans2_ALERT_KEY
{
	BLOCK trans2_BLOCK;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_ALERT_KEY
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TARGET_MODE
{
	BLOCK trans2_BLOCK;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TARGET_MODE
		}
	}
}

COMMAND write_trans2_TARGET_MODE
{
	BLOCK trans2_BLOCK;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TARGET_MODE
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_MODE
{
	BLOCK trans2_BLOCK;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_ACTUAL_MODE,
			trans2_PERMITTED_MODE,
			trans2_NORMAL_MODE
		}
	}
}

COMMAND read_trans2_ALARM_SUM
{
	BLOCK trans2_BLOCK;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CURRENT_STATE_ALARM_SUM,
			trans2_UNACKNOWLEDGED_STATE_ALARM_SUM,
			trans2_UNREPORTED_STATE_ALARM_SUM,
			trans2_DISABLED_STATE_ALARM_SUM
		}
	}
}


COMMAND read_trans2_CUSTOM_TC_NAME
{
	BLOCK trans2_BLOCK;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_TC_NAME
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_NAME
{
	BLOCK trans2_BLOCK;
	INDEX 8;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_TC_NAME
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_POLY_COUNT
{
	BLOCK trans2_BLOCK;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_TC_POLY_COUNT
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_POLY_COUNT
{
	BLOCK trans2_BLOCK;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_TC_POLY_COUNT
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_MIN_IN
{
	BLOCK trans2_BLOCK;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_TC_MIN_IN
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_MIN_IN
{
	BLOCK trans2_BLOCK;
	INDEX 10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_TC_MIN_IN
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_MIN_OUT
{
	BLOCK trans2_BLOCK;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_TC_MIN_OUT
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_MIN_OUT
{
	BLOCK trans2_BLOCK;
	INDEX 11;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_TC_MIN_OUT
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_MAX_OUT
{
	BLOCK trans2_BLOCK;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_TC_MAX_OUT
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_MAX_OUT
{
	BLOCK trans2_BLOCK;
	INDEX 12;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_TC_MAX_OUT
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_POLY_1
{
	BLOCK trans2_BLOCK;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_TC_POLY_1.Ohm,
			trans2_CUSTOM_TC_POLY_1.a4,
			trans2_CUSTOM_TC_POLY_1.a3,
			trans2_CUSTOM_TC_POLY_1.a2,
			trans2_CUSTOM_TC_POLY_1.a1,
			trans2_CUSTOM_TC_POLY_1.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_POLY_1
{
	BLOCK trans2_BLOCK;
	INDEX 13;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_TC_POLY_1.Ohm,
		trans2_CUSTOM_TC_POLY_1.a4,
		trans2_CUSTOM_TC_POLY_1.a3,
		trans2_CUSTOM_TC_POLY_1.a2,
		trans2_CUSTOM_TC_POLY_1.a1,
		trans2_CUSTOM_TC_POLY_1.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_POLY_2
{
	BLOCK trans2_BLOCK;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_TC_POLY_2.Ohm,
		trans2_CUSTOM_TC_POLY_2.a4,
		trans2_CUSTOM_TC_POLY_2.a3,
		trans2_CUSTOM_TC_POLY_2.a2,
		trans2_CUSTOM_TC_POLY_2.a1,
		trans2_CUSTOM_TC_POLY_2.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_POLY_2
{
	BLOCK trans2_BLOCK;
	INDEX 14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_TC_POLY_2.Ohm,
		trans2_CUSTOM_TC_POLY_2.a4,
		trans2_CUSTOM_TC_POLY_2.a3,
		trans2_CUSTOM_TC_POLY_2.a2,
		trans2_CUSTOM_TC_POLY_2.a1,
		trans2_CUSTOM_TC_POLY_2.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_POLY_3
{
	BLOCK trans2_BLOCK;
	INDEX 15;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_TC_POLY_3.Ohm,
		trans2_CUSTOM_TC_POLY_3.a4,
		trans2_CUSTOM_TC_POLY_3.a3,
		trans2_CUSTOM_TC_POLY_3.a2,
		trans2_CUSTOM_TC_POLY_3.a1,
		trans2_CUSTOM_TC_POLY_3.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_POLY_3
{
	BLOCK trans2_BLOCK;
	INDEX 15;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_TC_POLY_3.Ohm,
		trans2_CUSTOM_TC_POLY_3.a4,
		trans2_CUSTOM_TC_POLY_3.a3,
		trans2_CUSTOM_TC_POLY_3.a2,
		trans2_CUSTOM_TC_POLY_3.a1,
		trans2_CUSTOM_TC_POLY_3.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_POLY_4
{
	BLOCK trans2_BLOCK;
	INDEX 16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_TC_POLY_4.Ohm,
		trans2_CUSTOM_TC_POLY_4.a4,
		trans2_CUSTOM_TC_POLY_4.a3,
		trans2_CUSTOM_TC_POLY_4.a2,
		trans2_CUSTOM_TC_POLY_4.a1,
		trans2_CUSTOM_TC_POLY_4.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_POLY_4
{
	BLOCK trans2_BLOCK;
	INDEX 16;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_TC_POLY_4.Ohm,
		trans2_CUSTOM_TC_POLY_4.a4,
		trans2_CUSTOM_TC_POLY_4.a3,
		trans2_CUSTOM_TC_POLY_4.a2,
		trans2_CUSTOM_TC_POLY_4.a1,
		trans2_CUSTOM_TC_POLY_4.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_POLY_5
{
	BLOCK trans2_BLOCK;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_TC_POLY_5.Ohm,
		trans2_CUSTOM_TC_POLY_5.a4,
		trans2_CUSTOM_TC_POLY_5.a3,
		trans2_CUSTOM_TC_POLY_5.a2,
		trans2_CUSTOM_TC_POLY_5.a1,
		trans2_CUSTOM_TC_POLY_5.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_POLY_5
{
	BLOCK trans2_BLOCK;
	INDEX 17;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_TC_POLY_5.Ohm,
		trans2_CUSTOM_TC_POLY_5.a4,
		trans2_CUSTOM_TC_POLY_5.a3,
		trans2_CUSTOM_TC_POLY_5.a2,
		trans2_CUSTOM_TC_POLY_5.a1,
		trans2_CUSTOM_TC_POLY_5.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_TC_RJ_POLY
{
	BLOCK trans2_BLOCK;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_TC_RJ_POLY.a3,
		trans2_CUSTOM_TC_RJ_POLY.a2,
		trans2_CUSTOM_TC_RJ_POLY.a1,
		trans2_CUSTOM_TC_RJ_POLY.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_TC_RJ_POLY
{
	BLOCK trans2_BLOCK;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_TC_RJ_POLY.a3,
		trans2_CUSTOM_TC_RJ_POLY.a2,
		trans2_CUSTOM_TC_RJ_POLY.a1,
		trans2_CUSTOM_TC_RJ_POLY.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_NAME
{
	BLOCK trans2_BLOCK;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_RTD_NAME
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_NAME
{
	BLOCK trans2_BLOCK;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_RTD_NAME
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_POLY_COUNT
{
	BLOCK trans2_BLOCK;
	INDEX 20;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_RTD_POLY_COUNT
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_POLY_COUNT
{
	BLOCK trans2_BLOCK;
	INDEX 20;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_RTD_POLY_COUNT
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_MIN_IN
{
	BLOCK trans2_BLOCK;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_RTD_MIN_IN
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_MIN_IN
{
	BLOCK trans2_BLOCK;
	INDEX 21;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_RTD_MIN_IN
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_MIN_OUT
{
	BLOCK trans2_BLOCK;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_RTD_MIN_OUT
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_MIN_OUT
{
	BLOCK trans2_BLOCK;
	INDEX 22;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_RTD_MIN_OUT
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_MAX_OUT
{
	BLOCK trans2_BLOCK;
	INDEX 23;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_CUSTOM_RTD_MAX_OUT
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_MAX_OUT
{
	BLOCK trans2_BLOCK;
	INDEX 23;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_CUSTOM_RTD_MAX_OUT
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_POLY_1
{
	BLOCK trans2_BLOCK;
	INDEX 24;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_RTD_POLY_1.Ohm,
		trans2_CUSTOM_RTD_POLY_1.a4,
		trans2_CUSTOM_RTD_POLY_1.a3,
		trans2_CUSTOM_RTD_POLY_1.a2,
		trans2_CUSTOM_RTD_POLY_1.a1,
		trans2_CUSTOM_RTD_POLY_1.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_POLY_1
{
	BLOCK trans2_BLOCK;
	INDEX 24;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_RTD_POLY_1.Ohm,
		trans2_CUSTOM_RTD_POLY_1.a4,
		trans2_CUSTOM_RTD_POLY_1.a3,
		trans2_CUSTOM_RTD_POLY_1.a2,
		trans2_CUSTOM_RTD_POLY_1.a1,
		trans2_CUSTOM_RTD_POLY_1.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_POLY_2
{
	BLOCK trans2_BLOCK;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_RTD_POLY_2.Ohm,
		trans2_CUSTOM_RTD_POLY_2.a4,
		trans2_CUSTOM_RTD_POLY_2.a3,
		trans2_CUSTOM_RTD_POLY_2.a2,
		trans2_CUSTOM_RTD_POLY_2.a1,
		trans2_CUSTOM_RTD_POLY_2.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_POLY_2
{
	BLOCK trans2_BLOCK;
	INDEX 25;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_RTD_POLY_2.Ohm,
		trans2_CUSTOM_RTD_POLY_2.a4,
		trans2_CUSTOM_RTD_POLY_2.a3,
		trans2_CUSTOM_RTD_POLY_2.a2,
		trans2_CUSTOM_RTD_POLY_2.a1,
		trans2_CUSTOM_RTD_POLY_2.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_POLY_3
{
	BLOCK trans2_BLOCK;
	INDEX 26;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_RTD_POLY_3.Ohm,
		trans2_CUSTOM_RTD_POLY_3.a4,
		trans2_CUSTOM_RTD_POLY_3.a3,
		trans2_CUSTOM_RTD_POLY_3.a2,
		trans2_CUSTOM_RTD_POLY_3.a1,
		trans2_CUSTOM_RTD_POLY_3.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_POLY_3
{
	BLOCK trans2_BLOCK;
	INDEX 26;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_RTD_POLY_3.Ohm,
		trans2_CUSTOM_RTD_POLY_3.a4,
		trans2_CUSTOM_RTD_POLY_3.a3,
		trans2_CUSTOM_RTD_POLY_3.a2,
		trans2_CUSTOM_RTD_POLY_3.a1,
		trans2_CUSTOM_RTD_POLY_3.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_POLY_4
{
	BLOCK trans2_BLOCK;
	INDEX 27;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_RTD_POLY_4.Ohm,
		trans2_CUSTOM_RTD_POLY_4.a4,
		trans2_CUSTOM_RTD_POLY_4.a3,
		trans2_CUSTOM_RTD_POLY_4.a2,
		trans2_CUSTOM_RTD_POLY_4.a1,
		trans2_CUSTOM_RTD_POLY_4.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_POLY_4
{
	BLOCK trans2_BLOCK;
	INDEX 27;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_RTD_POLY_4.Ohm,
		trans2_CUSTOM_RTD_POLY_4.a4,
		trans2_CUSTOM_RTD_POLY_4.a3,
		trans2_CUSTOM_RTD_POLY_4.a2,
		trans2_CUSTOM_RTD_POLY_4.a1,
		trans2_CUSTOM_RTD_POLY_4.a0
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_CUSTOM_RTD_POLY_5
{
	BLOCK trans2_BLOCK;
	INDEX 28;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		trans2_CUSTOM_RTD_POLY_5.Ohm,
		trans2_CUSTOM_RTD_POLY_5.a4,
		trans2_CUSTOM_RTD_POLY_5.a3,
		trans2_CUSTOM_RTD_POLY_5.a2,
		trans2_CUSTOM_RTD_POLY_5.a1,
		trans2_CUSTOM_RTD_POLY_5.a0
		}
	}
}

COMMAND write_trans2_CUSTOM_RTD_POLY_5
{
	BLOCK trans2_BLOCK;
	INDEX 28;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		trans2_CUSTOM_RTD_POLY_5.Ohm,
		trans2_CUSTOM_RTD_POLY_5.a4,
		trans2_CUSTOM_RTD_POLY_5.a3,
		trans2_CUSTOM_RTD_POLY_5.a2,
		trans2_CUSTOM_RTD_POLY_5.a1,
		trans2_CUSTOM_RTD_POLY_5.a0
		}
		REPLY
		{
		}
	}
}

/* End of transducer block 1*/

/* Start of transducer block 2*/

COMMAND read_trans2_TAB_MIN_NUMBER
{
	BLOCK trans2_BLOCK;
	INDEX 29;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_MIN_NUMBER
		}
	}
}

COMMAND read_trans2_TAB_MAX_NUMBER
{
	BLOCK trans2_BLOCK;
	INDEX 30;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_MAX_NUMBER
		}
	}
}


COMMAND read_trans2_TAB_ACTUAL_NUMBER
{
	BLOCK trans2_BLOCK;
	INDEX 31;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_ACTUAL_NUMBER
		}
	}
}


COMMAND write_trans2_TAB_ACTUAL_NUMBER
{
	BLOCK trans2_BLOCK;
	INDEX 31;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_ACTUAL_NUMBER
		}
		REPLY
		{
		}
	}
}



COMMAND read_trans2_TAB_X_Y_VALUE1
{
	BLOCK trans2_BLOCK;
	INDEX 32;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE1.x,
			trans2_TAB_X_Y_VALUE1.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE1
{
	BLOCK trans2_BLOCK;
	INDEX 32;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE1.x,
			trans2_TAB_X_Y_VALUE1.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE2
{
	BLOCK trans2_BLOCK;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE2.x,
			trans2_TAB_X_Y_VALUE2.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE2
{
	BLOCK trans2_BLOCK;
	INDEX 33;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE2.x,
			trans2_TAB_X_Y_VALUE2.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE3
{
	BLOCK trans2_BLOCK;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE3.x,
			trans2_TAB_X_Y_VALUE3.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE3
{
	BLOCK trans2_BLOCK;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE3.x,
			trans2_TAB_X_Y_VALUE3.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE4
{
	BLOCK trans2_BLOCK;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE4.x,
			trans2_TAB_X_Y_VALUE4.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE4
{
	BLOCK trans2_BLOCK;
	INDEX 35;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE4.x,
			trans2_TAB_X_Y_VALUE4.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE5
{
	BLOCK trans2_BLOCK;
	INDEX 36;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE5.x,
			trans2_TAB_X_Y_VALUE5.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE5
{
	BLOCK trans2_BLOCK;
	INDEX 36;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE5.x,
			trans2_TAB_X_Y_VALUE5.y
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans2_TAB_X_Y_VALUE6
{
	BLOCK trans2_BLOCK;
	INDEX 37;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE6.x,
			trans2_TAB_X_Y_VALUE6.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE6
{
	BLOCK trans2_BLOCK;
	INDEX 37;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE6.x,
			trans2_TAB_X_Y_VALUE6.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE7
{
	BLOCK trans2_BLOCK;
	INDEX 38;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE7.x,
			trans2_TAB_X_Y_VALUE7.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE7
{
	BLOCK trans2_BLOCK;
	INDEX 38;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE7.x,
			trans2_TAB_X_Y_VALUE7.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE8
{
	BLOCK trans2_BLOCK;
	INDEX 39;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE8.x,
			trans2_TAB_X_Y_VALUE8.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE8
{
	BLOCK trans2_BLOCK;
	INDEX 39;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE8.x,
			trans2_TAB_X_Y_VALUE8.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE9
{
	BLOCK trans2_BLOCK;
	INDEX 40;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE9.x,
			trans2_TAB_X_Y_VALUE9.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE9
{
	BLOCK trans2_BLOCK;
	INDEX 40;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE9.x,
			trans2_TAB_X_Y_VALUE9.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE10
{
	BLOCK trans2_BLOCK;
	INDEX 41;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE10.x,
			trans2_TAB_X_Y_VALUE10.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE10
{
	BLOCK trans2_BLOCK;
	INDEX 41;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE10.x,
			trans2_TAB_X_Y_VALUE10.y
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans2_TAB_X_Y_VALUE11
{
	BLOCK trans2_BLOCK;
	INDEX 42;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE11.x,
			trans2_TAB_X_Y_VALUE11.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE11
{
	BLOCK trans2_BLOCK;
	INDEX 42;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE11.x,
			trans2_TAB_X_Y_VALUE11.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE12
{
	BLOCK trans2_BLOCK;
	INDEX 43;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE12.x,
			trans2_TAB_X_Y_VALUE12.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE12
{
	BLOCK trans2_BLOCK;
	INDEX 43;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE12.x,
			trans2_TAB_X_Y_VALUE12.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE13
{
	BLOCK trans2_BLOCK;
	INDEX 44;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE13.x,
			trans2_TAB_X_Y_VALUE13.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE13
{
	BLOCK trans2_BLOCK;
	INDEX 44;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE13.x,
			trans2_TAB_X_Y_VALUE13.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE14
{
	BLOCK trans2_BLOCK;
	INDEX 45;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE14.x,
			trans2_TAB_X_Y_VALUE14.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE14
{
	BLOCK trans2_BLOCK;
	INDEX 45;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE14.x,
			trans2_TAB_X_Y_VALUE14.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE15
{
	BLOCK trans2_BLOCK;
	INDEX 46;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE15.x,
			trans2_TAB_X_Y_VALUE15.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE15
{
	BLOCK trans2_BLOCK;
	INDEX 46;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE15.x,
			trans2_TAB_X_Y_VALUE15.y
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans2_TAB_X_Y_VALUE16
{
	BLOCK trans2_BLOCK;
	INDEX 47;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE16.x,
			trans2_TAB_X_Y_VALUE16.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE16
{
	BLOCK trans2_BLOCK;
	INDEX 47;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE16.x,
			trans2_TAB_X_Y_VALUE16.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE17
{
	BLOCK trans2_BLOCK;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE17.x,
			trans2_TAB_X_Y_VALUE17.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE17
{
	BLOCK trans2_BLOCK;
	INDEX 48;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE17.x,
			trans2_TAB_X_Y_VALUE17.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE18
{
	BLOCK trans2_BLOCK;
	INDEX 49;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE18.x,
			trans2_TAB_X_Y_VALUE18.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE18
{
	BLOCK trans2_BLOCK;
	INDEX 49;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE18.x,
			trans2_TAB_X_Y_VALUE18.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE19
{
	BLOCK trans2_BLOCK;
	INDEX 50;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE19.x,
			trans2_TAB_X_Y_VALUE19.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE19
{
	BLOCK trans2_BLOCK;
	INDEX 50;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE19.x,
			trans2_TAB_X_Y_VALUE19.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE20
{
	BLOCK trans2_BLOCK;
	INDEX 51;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE20.x,
			trans2_TAB_X_Y_VALUE20.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE20
{
	BLOCK trans2_BLOCK;
	INDEX 51;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE20.x,
			trans2_TAB_X_Y_VALUE20.y
		}
		REPLY
		{
		}
	}
}







COMMAND read_trans2_TAB_X_Y_VALUE21
{
	BLOCK trans2_BLOCK;
	INDEX 52;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE21.x,
			trans2_TAB_X_Y_VALUE21.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE21
{
	BLOCK trans2_BLOCK;
	INDEX 52;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE21.x,
			trans2_TAB_X_Y_VALUE21.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE22
{
	BLOCK trans2_BLOCK;
	INDEX 53;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE22.x,
			trans2_TAB_X_Y_VALUE22.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE22
{
	BLOCK trans2_BLOCK;
	INDEX 53;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE22.x,
			trans2_TAB_X_Y_VALUE22.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE23
{
	BLOCK trans2_BLOCK;
	INDEX 54;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE23.x,
			trans2_TAB_X_Y_VALUE23.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE23
{
	BLOCK trans2_BLOCK;
	INDEX 54;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE23.x,
			trans2_TAB_X_Y_VALUE23.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE24
{
	BLOCK trans2_BLOCK;
	INDEX 55;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE24.x,
			trans2_TAB_X_Y_VALUE24.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE24
{
	BLOCK trans2_BLOCK;
	INDEX 55;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE24.x,
			trans2_TAB_X_Y_VALUE24.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE25
{
	BLOCK trans2_BLOCK;
	INDEX 56;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE25.x,
			trans2_TAB_X_Y_VALUE25.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE25
{
	BLOCK trans2_BLOCK;
	INDEX 56;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE25.x,
			trans2_TAB_X_Y_VALUE25.y
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans2_TAB_X_Y_VALUE26
{
	BLOCK trans2_BLOCK;
	INDEX 57;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE26.x,
			trans2_TAB_X_Y_VALUE26.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE26
{
	BLOCK trans2_BLOCK;
	INDEX 57;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE26.x,
			trans2_TAB_X_Y_VALUE26.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE27
{
	BLOCK trans2_BLOCK;
	INDEX 58;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE27.x,
			trans2_TAB_X_Y_VALUE27.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE27
{
	BLOCK trans2_BLOCK;
	INDEX 58;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE27.x,
			trans2_TAB_X_Y_VALUE27.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE28
{
	BLOCK trans2_BLOCK;
	INDEX 59;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE28.x,
			trans2_TAB_X_Y_VALUE28.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE28
{
	BLOCK trans2_BLOCK;
	INDEX 59;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE28.x,
			trans2_TAB_X_Y_VALUE28.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE29
{
	BLOCK trans2_BLOCK;
	INDEX 60;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE29.x,
			trans2_TAB_X_Y_VALUE29.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE29
{
	BLOCK trans2_BLOCK;
	INDEX 60;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE29.x,
			trans2_TAB_X_Y_VALUE29.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE30
{
	BLOCK trans2_BLOCK;
	INDEX 61;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE30.x,
			trans2_TAB_X_Y_VALUE30.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE30
{
	BLOCK trans2_BLOCK;
	INDEX 61;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE30.x,
			trans2_TAB_X_Y_VALUE30.y
		}
		REPLY
		{
		}
	}
}






COMMAND read_trans2_TAB_X_Y_VALUE31
{
	BLOCK trans2_BLOCK;
	INDEX 62;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE31.x,
			trans2_TAB_X_Y_VALUE31.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE31
{
	BLOCK trans2_BLOCK;
	INDEX 62;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE31.x,
			trans2_TAB_X_Y_VALUE31.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE32
{
	BLOCK trans2_BLOCK;
	INDEX 63;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE32.x,
			trans2_TAB_X_Y_VALUE32.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE32
{
	BLOCK trans2_BLOCK;
	INDEX 63;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE32.x,
			trans2_TAB_X_Y_VALUE32.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE33
{
	BLOCK trans2_BLOCK;
	INDEX 64;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE33.x,
			trans2_TAB_X_Y_VALUE33.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE33
{
	BLOCK trans2_BLOCK;
	INDEX 64;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE33.x,
			trans2_TAB_X_Y_VALUE33.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE34
{
	BLOCK trans2_BLOCK;
	INDEX 65;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE34.x,
			trans2_TAB_X_Y_VALUE34.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE34
{
	BLOCK trans2_BLOCK;
	INDEX 65;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE34.x,
			trans2_TAB_X_Y_VALUE34.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE35
{
	BLOCK trans2_BLOCK;
	INDEX 66;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE35.x,
			trans2_TAB_X_Y_VALUE35.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE35
{
	BLOCK trans2_BLOCK;
	INDEX 66;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE35.x,
			trans2_TAB_X_Y_VALUE35.y
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans2_TAB_X_Y_VALUE36
{
	BLOCK trans2_BLOCK;
	INDEX 67;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE36.x,
			trans2_TAB_X_Y_VALUE36.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE36
{
	BLOCK trans2_BLOCK;
	INDEX 67;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE36.x,
			trans2_TAB_X_Y_VALUE36.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE37
{
	BLOCK trans2_BLOCK;
	INDEX 68;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE37.x,
			trans2_TAB_X_Y_VALUE37.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE37
{
	BLOCK trans2_BLOCK;
	INDEX 68;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE37.x,
			trans2_TAB_X_Y_VALUE37.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE38
{
	BLOCK trans2_BLOCK;
	INDEX 69;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE38.x,
			trans2_TAB_X_Y_VALUE38.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE38
{
	BLOCK trans2_BLOCK;
	INDEX 69;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE38.x,
			trans2_TAB_X_Y_VALUE38.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE39
{
	BLOCK trans2_BLOCK;
	INDEX 70;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE39.x,
			trans2_TAB_X_Y_VALUE39.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE39
{
	BLOCK trans2_BLOCK;
	INDEX 70;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE39.x,
			trans2_TAB_X_Y_VALUE39.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE40
{
	BLOCK trans2_BLOCK;
	INDEX 71;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE40.x,
			trans2_TAB_X_Y_VALUE40.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE40
{
	BLOCK trans2_BLOCK;
	INDEX 71;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE40.x,
			trans2_TAB_X_Y_VALUE40.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE41
{
	BLOCK trans2_BLOCK;
	INDEX 72;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE41.x,
			trans2_TAB_X_Y_VALUE41.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE41
{
	BLOCK trans2_BLOCK;
	INDEX 72;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE41.x,
			trans2_TAB_X_Y_VALUE41.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE42
{
	BLOCK trans2_BLOCK;
	INDEX 73;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE42.x,
			trans2_TAB_X_Y_VALUE42.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE42
{
	BLOCK trans2_BLOCK;
	INDEX 73;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE42.x,
			trans2_TAB_X_Y_VALUE42.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE43
{
	BLOCK trans2_BLOCK;
	INDEX 74;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE43.x,
			trans2_TAB_X_Y_VALUE43.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE43
{
	BLOCK trans2_BLOCK;
	INDEX 74;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE43.x,
			trans2_TAB_X_Y_VALUE43.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE44
{
	BLOCK trans2_BLOCK;
	INDEX 75;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE44.x,
			trans2_TAB_X_Y_VALUE44.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE44
{
	BLOCK trans2_BLOCK;
	INDEX 75;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE44.x,
			trans2_TAB_X_Y_VALUE44.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE45
{
	BLOCK trans2_BLOCK;
	INDEX 76;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE45.x,
			trans2_TAB_X_Y_VALUE45.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE45
{
	BLOCK trans2_BLOCK;
	INDEX 76;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE45.x,
			trans2_TAB_X_Y_VALUE45.y
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans2_TAB_X_Y_VALUE46
{
	BLOCK trans2_BLOCK;
	INDEX 77;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE46.x,
			trans2_TAB_X_Y_VALUE46.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE46
{
	BLOCK trans2_BLOCK;
	INDEX 77;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE46.x,
			trans2_TAB_X_Y_VALUE46.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE47
{
	BLOCK trans2_BLOCK;
	INDEX 78;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE47.x,
			trans2_TAB_X_Y_VALUE47.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE47
{
	BLOCK trans2_BLOCK;
	INDEX 78;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE47.x,
			trans2_TAB_X_Y_VALUE47.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE48
{
	BLOCK trans2_BLOCK;
	INDEX 79;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE48.x,
			trans2_TAB_X_Y_VALUE48.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE48
{
	BLOCK trans2_BLOCK;
	INDEX 79;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE48.x,
			trans2_TAB_X_Y_VALUE48.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE49
{
	BLOCK trans2_BLOCK;
	INDEX 80;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE49.x,
			trans2_TAB_X_Y_VALUE49.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE49
{
	BLOCK trans2_BLOCK;
	INDEX 80;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE49.x,
			trans2_TAB_X_Y_VALUE49.y
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans2_TAB_X_Y_VALUE50
{
	BLOCK trans2_BLOCK;
	INDEX 81;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_TAB_X_Y_VALUE50.x,
			trans2_TAB_X_Y_VALUE50.y
		}
	}
}

COMMAND write_trans2_TAB_X_Y_VALUE50
{
	BLOCK trans2_BLOCK;
	INDEX 81;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_TAB_X_Y_VALUE50.x,
			trans2_TAB_X_Y_VALUE50.y
		}
		REPLY
		{
		}
	}
}

/****** func BLOCK 1 ******/
COMMAND read_func1_BLOCK
{
	BLOCK func1_BLOCK;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_BLK_RESERVE,
			func1_BLK_OBJECT,
			func1_BLK_PARENT_CLASS,
			func1_BLK_CLASS,
			func1_BLK_DD_REFRENCE,
			func1_BLK_DD_REV,
			func1_BLK_PROFILE,
			func1_BLK_PROFILE_REV,
			func1_BLK_EXECUTION_TIME,
			func1_BLK_NUM_PARAMETERS,
			func1_BLK_INDEX_VIEW_1,
			func1_BLK_NUM_VIEW_LISTS
		}
	}
}

COMMAND read_func1_STATIC_REVISION
{
	BLOCK func1_BLOCK;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_STATIC_REVISION
		}
	}
}

COMMAND read_func1_TAG_DESCRIPTION
{
	BLOCK func1_BLOCK;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_TAG_DESCRIPTION
		}
	}
}

COMMAND write_func1_TAG_DESCRIPTION
{
	BLOCK func1_BLOCK;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_TAG_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_STRATEGY
{
	BLOCK func1_BLOCK;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_STRATEGY
		}
	}
}

COMMAND write_func1_STRATEGY
{
	BLOCK func1_BLOCK;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_STRATEGY
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_ALERT_KEY
{
	BLOCK func1_BLOCK;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_ALERT_KEY
		}
	}
}

COMMAND write_func1_ALERT_KEY
{
	BLOCK func1_BLOCK;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_ALERT_KEY
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_TARGET_MODE
{
	BLOCK func1_BLOCK;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_TARGET_MODE
		}
	}
}

COMMAND write_func1_TARGET_MODE
{
	BLOCK func1_BLOCK;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_TARGET_MODE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_MODE
{
	BLOCK func1_BLOCK;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_ACTUAL_MODE,
			func1_PERMITTED_MODE,
			func1_NORMAL_MODE
		}
	}
}

COMMAND read_func1_ALARM_SUM
{
	BLOCK func1_BLOCK;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_CURRENT_STATE_ALARM_SUM,
			func1_UNACKNOWLEDGED_STATE_ALARM_SUM,
			func1_UNREPORTED_STATE_ALARM_SUM,
			func1_DISABLED_STATE_ALARM_SUM
		}
	}
}

COMMAND read_func1_BATCH
{
	BLOCK func1_BLOCK;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_BATCH_ID, 
			func1_BATCH_UNIT, 
			func1_BATCH_OPERATION, 
			func1_BATCH_PHASE
		}
	}
}

COMMAND write_func1_BATCH
{
	BLOCK func1_BLOCK;
	INDEX 8;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_BATCH_ID, 
			func1_BATCH_UNIT, 
			func1_BATCH_OPERATION, 
			func1_BATCH_PHASE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_OUT_VALUE
{
	BLOCK func1_BLOCK;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_OUT_VALUE,
			func1_OUT_STATUS
		}
	}
}

COMMAND write_func1_OUT_VALUE
{
	BLOCK func1_BLOCK;
	INDEX 10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_OUT_VALUE,
			func1_OUT_STATUS
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_PV_SCALE
{
	BLOCK func1_BLOCK;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_PV_SCALE_UPPER,
			func1_PV_SCALE_LOWER
		}
	}
}

COMMAND write_func1_PV_SCALE
{
	BLOCK func1_BLOCK;
	INDEX 11;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_PV_SCALE_UPPER,
			func1_PV_SCALE_LOWER
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_OUTPUT_SCALE_VALUE
{
	BLOCK func1_BLOCK;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_OUTPUT_SCALE_UPPER_VALUE,
			func1_OUTPUT_SCALE_LOWER_VALUE,
			func1_OUTPUT_SCALE_UNIT,
			func1_OUTPUT_SCALE_DECIMAL_POINT
		}
	}
}

COMMAND write_func1_OUTPUT_SCALE_VALUE
{
	BLOCK func1_BLOCK;
	INDEX 12;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_OUTPUT_SCALE_UPPER_VALUE,
			func1_OUTPUT_SCALE_LOWER_VALUE,
			func1_OUTPUT_SCALE_UNIT,
			func1_OUTPUT_SCALE_DECIMAL_POINT
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_LIN_TYPE
{
	BLOCK func1_BLOCK;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_LIN_TYPE
		}
	}
}

COMMAND write_func1_LIN_TYPE
{
	BLOCK func1_BLOCK;
	INDEX 13;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_LIN_TYPE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_CHANNEL
{
	BLOCK func1_BLOCK;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_CHANNEL
		}
	}
}

COMMAND write_func1_CHANNEL
{
	BLOCK func1_BLOCK;
	INDEX 14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_CHANNEL
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_PV_FTIME
{
	BLOCK func1_BLOCK;
	INDEX 16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_PV_FTIME
		}
	}
}

COMMAND write_func1_PV_FTIME
{
	BLOCK func1_BLOCK;
	INDEX 16;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_PV_FTIME
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_FSAFE_TYPE
{
	BLOCK func1_BLOCK;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_FSAFE_TYPE
		}
	}
}

COMMAND write_func1_FSAFE_TYPE
{
	BLOCK func1_BLOCK;
	INDEX 17;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_FSAFE_TYPE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_FSAFE_VALUE
{
	BLOCK func1_BLOCK;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_FSAFE_VALUE
		}
	}
}

COMMAND write_func1_FSAFE_VALUE
{
	BLOCK func1_BLOCK;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_FSAFE_VALUE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_LIMIT_HYSTERESIS
{
	BLOCK func1_BLOCK;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_LIMIT_HYSTERESIS
		}
	}
}

COMMAND write_func1_LIMIT_HYSTERESIS
{
	BLOCK func1_BLOCK;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_LIMIT_HYSTERESIS
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_LIMIT_HI_HI
{
	BLOCK func1_BLOCK;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_LIMIT_HI_HI
		}
	}
}

COMMAND write_func1_LIMIT_HI_HI
{
	BLOCK func1_BLOCK;
	INDEX 21;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_LIMIT_HI_HI
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_LIMIT_HI
{
	BLOCK func1_BLOCK;
	INDEX 23;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_LIMIT_HI
		}
	}
}

COMMAND write_func1_LIMIT_HI
{
	BLOCK func1_BLOCK;
	INDEX 23;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_LIMIT_HI
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_LIMIT_LO
{
	BLOCK func1_BLOCK;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_LIMIT_LO
		}
	}
}

COMMAND write_func1_LIMIT_LO
{
	BLOCK func1_BLOCK;
	INDEX 25;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_LIMIT_LO
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_LIMIT_LO_LO
{
	BLOCK func1_BLOCK;
	INDEX 27;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_LIMIT_LO_LO
		}
	}
}

COMMAND write_func1_LIMIT_LO_LO
{
	BLOCK func1_BLOCK;
	INDEX 27;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_LIMIT_LO_LO
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_HI_HI_ALM
{
	BLOCK func1_BLOCK;
	INDEX 30;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_HI_HI_ALM_UNACKNOWLEDGED, 
			func1_HI_HI_ALM_STATE,
			func1_HI_HI_ALM_TIMESTAMP_HIGH, 
			func1_HI_HI_ALM_TIMESTAMP_LOW, 
			func1_HI_HI_ALM_SUBCODE,
			func1_HI_HI_ALM_VALUE
		}
	}
}

COMMAND read_func1_HI_ALM
{
	BLOCK func1_BLOCK;
	INDEX 31;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_HI_ALM_UNACKNOWLEDGED, 
			func1_HI_ALM_STATE,
			func1_HI_ALM_TIMESTAMP_HIGH, 
			func1_HI_ALM_TIMESTAMP_LOW,
			func1_HI_ALM_SUBCODE,
			func1_HI_ALM_VALUE
		}
	}
}

COMMAND read_func1_LO_ALM
{
	BLOCK func1_BLOCK;
	INDEX 32;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_LO_ALM_UNACKNOWLEDGED, 
			func1_LO_ALM_STATE,
			func1_LO_ALM_TIMESTAMP_HIGH, 
			func1_LO_ALM_TIMESTAMP_LOW,
			func1_LO_ALM_SUBCODE,
			func1_LO_ALM_VALUE
		}
	}
}

COMMAND read_func1_LO_LO_ALM
{
	BLOCK func1_BLOCK;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_LO_LO_ALM_UNACKNOWLEDGED, 
			func1_LO_LO_ALM_STATE,
			func1_LO_LO_ALM_TIMESTAMP_HIGH, 
			func1_LO_LO_ALM_TIMESTAMP_LOW,
			func1_LO_LO_ALM_SUBCODE,
			func1_LO_LO_ALM_VALUE
		}
	}
}

COMMAND read_func1_SIMULATE
{
	BLOCK func1_BLOCK;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_SIMULATION_STATUS,
			func1_SIMULATION_VALUE, 
			func1_SIMULATION_ENABLED
		}
	}
}

COMMAND write_func1_SIMULATE
{
	BLOCK func1_BLOCK;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_SIMULATION_STATUS,
			func1_SIMULATION_VALUE, 
			func1_SIMULATION_ENABLED
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_OUTPUT_UNIT_TEXT
{
	BLOCK func1_BLOCK;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_OUTPUT_UNIT_TEXT
		}
	}
}

COMMAND write_func1_OUTPUT_UNIT_TEXT
{
	BLOCK func1_BLOCK;
	INDEX 35;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_OUTPUT_UNIT_TEXT
		}
		REPLY
		{
		}
	}
}

/****** func BLOCK 2 ******/
COMMAND read_func2_BLOCK
{
	BLOCK func2_BLOCK;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_BLK_RESERVE,
			func2_BLK_OBJECT,
			func2_BLK_PARENT_CLASS,
			func2_BLK_CLASS,
			func2_BLK_DD_REFRENCE,
			func2_BLK_DD_REV,
			func2_BLK_PROFILE,
			func2_BLK_PROFILE_REV,
			func2_BLK_EXECUTION_TIME,
			func2_BLK_NUM_PARAMETERS,
			func2_BLK_INDEX_VIEW_1,
			func2_BLK_NUM_VIEW_LISTS
		}
	}
}

COMMAND read_func2_STATIC_REVISION
{
	BLOCK func2_BLOCK;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_STATIC_REVISION
		}
	}
}

COMMAND read_func2_TAG_DESCRIPTION
{
	BLOCK func2_BLOCK;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_TAG_DESCRIPTION
		}
	}
}

COMMAND write_func2_TAG_DESCRIPTION
{
	BLOCK func2_BLOCK;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_TAG_DESCRIPTION
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_STRATEGY
{
	BLOCK func2_BLOCK;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_STRATEGY
		}
	}
}

COMMAND write_func2_STRATEGY
{
	BLOCK func2_BLOCK;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_STRATEGY
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_ALERT_KEY
{
	BLOCK func2_BLOCK;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_ALERT_KEY
		}
	}
}

COMMAND write_func2_ALERT_KEY
{
	BLOCK func2_BLOCK;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_ALERT_KEY
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_TARGET_MODE
{
	BLOCK func2_BLOCK;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_TARGET_MODE
		}
	}
}

COMMAND write_func2_TARGET_MODE
{
	BLOCK func2_BLOCK;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_TARGET_MODE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_MODE
{
	BLOCK func2_BLOCK;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_ACTUAL_MODE,
			func2_PERMITTED_MODE,
			func2_NORMAL_MODE
		}
	}
}

COMMAND read_func2_ALARM_SUM
{
	BLOCK func2_BLOCK;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_CURRENT_STATE_ALARM_SUM,
			func2_UNACKNOWLEDGED_STATE_ALARM_SUM,
			func2_UNREPORTED_STATE_ALARM_SUM,
			func2_DISABLED_STATE_ALARM_SUM
		}
	}
}

COMMAND read_func2_BATCH
{
	BLOCK func2_BLOCK;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_BATCH_ID, 
			func2_BATCH_UNIT, 
			func2_BATCH_OPERATION, 
			func2_BATCH_PHASE
		}
	}
}

COMMAND write_func2_BATCH
{
	BLOCK func2_BLOCK;
	INDEX 8;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_BATCH_ID, 
			func2_BATCH_UNIT, 
			func2_BATCH_OPERATION, 
			func2_BATCH_PHASE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_OUT_VALUE
{
	BLOCK func2_BLOCK;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_OUT_VALUE,
			func2_OUT_STATUS
		}
	}
}

COMMAND write_func2_OUT_VALUE
{
	BLOCK func2_BLOCK;
	INDEX 10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_OUT_VALUE,
			func2_OUT_STATUS
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_PV_SCALE
{
	BLOCK func2_BLOCK;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_PV_SCALE_UPPER,
			func2_PV_SCALE_LOWER
		}
	}
}

COMMAND write_func2_PV_SCALE
{
	BLOCK func2_BLOCK;
	INDEX 11;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_PV_SCALE_UPPER,
			func2_PV_SCALE_LOWER
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_OUTPUT_SCALE_VALUE
{
	BLOCK func2_BLOCK;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_OUTPUT_SCALE_UPPER_VALUE,
			func2_OUTPUT_SCALE_LOWER_VALUE,
			func2_OUTPUT_SCALE_UNIT,
			func2_OUTPUT_SCALE_DECIMAL_POINT
		}
	}
}

COMMAND write_func2_OUTPUT_SCALE_VALUE
{
	BLOCK func2_BLOCK;
	INDEX 12;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_OUTPUT_SCALE_UPPER_VALUE,
			func2_OUTPUT_SCALE_LOWER_VALUE,
			func2_OUTPUT_SCALE_UNIT,
			func2_OUTPUT_SCALE_DECIMAL_POINT
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_LIN_TYPE
{
	BLOCK func2_BLOCK;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_LIN_TYPE
		}
	}
}

COMMAND write_func2_LIN_TYPE
{
	BLOCK func2_BLOCK;
	INDEX 13;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_LIN_TYPE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_CHANNEL
{
	BLOCK func2_BLOCK;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_CHANNEL
		}
	}
}

COMMAND write_func2_CHANNEL
{
	BLOCK func2_BLOCK;
	INDEX 14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_CHANNEL
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_PV_FTIME
{
	BLOCK func2_BLOCK;
	INDEX 16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_PV_FTIME
		}
	}
}

COMMAND write_func2_PV_FTIME
{
	BLOCK func2_BLOCK;
	INDEX 16;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_PV_FTIME
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_FSAFE_TYPE
{
	BLOCK func2_BLOCK;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_FSAFE_TYPE
		}
	}
}

COMMAND write_func2_FSAFE_TYPE
{
	BLOCK func2_BLOCK;
	INDEX 17;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_FSAFE_TYPE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_FSAFE_VALUE
{
	BLOCK func2_BLOCK;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_FSAFE_VALUE
		}
	}
}

COMMAND write_func2_FSAFE_VALUE
{
	BLOCK func2_BLOCK;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_FSAFE_VALUE
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_LIMIT_HYSTERESIS
{
	BLOCK func2_BLOCK;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_LIMIT_HYSTERESIS
		}
	}
}

COMMAND write_func2_LIMIT_HYSTERESIS
{
	BLOCK func2_BLOCK;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_LIMIT_HYSTERESIS
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_LIMIT_HI_HI
{
	BLOCK func2_BLOCK;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_LIMIT_HI_HI
		}
	}
}

COMMAND write_func2_LIMIT_HI_HI
{
	BLOCK func2_BLOCK;
	INDEX 21;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_LIMIT_HI_HI
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_LIMIT_HI
{
	BLOCK func2_BLOCK;
	INDEX 23;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_LIMIT_HI
		}
	}
}

COMMAND write_func2_LIMIT_HI
{
	BLOCK func2_BLOCK;
	INDEX 23;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_LIMIT_HI
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_LIMIT_LO
{
	BLOCK func2_BLOCK;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_LIMIT_LO
		}
	}
}

COMMAND write_func2_LIMIT_LO
{
	BLOCK func2_BLOCK;
	INDEX 25;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_LIMIT_LO
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_LIMIT_LO_LO
{
	BLOCK func2_BLOCK;
	INDEX 27;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_LIMIT_LO_LO
		}
	}
}

COMMAND write_func2_LIMIT_LO_LO
{
	BLOCK func2_BLOCK;
	INDEX 27;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_LIMIT_LO_LO
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_HI_HI_ALM
{
	BLOCK func2_BLOCK;
	INDEX 30;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_HI_HI_ALM_UNACKNOWLEDGED, 
			func2_HI_HI_ALM_STATE,
			func2_HI_HI_ALM_TIMESTAMP_HIGH,
			func2_HI_HI_ALM_TIMESTAMP_LOW,
			func2_HI_HI_ALM_SUBCODE,
			func2_HI_HI_ALM_VALUE
		}
	}
}

COMMAND read_func2_HI_ALM
{
	BLOCK func2_BLOCK;
	INDEX 31;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_HI_ALM_UNACKNOWLEDGED, 
			func2_HI_ALM_STATE,
			func2_HI_ALM_TIMESTAMP_HIGH, 
			func2_HI_ALM_TIMESTAMP_LOW,
			func2_HI_ALM_SUBCODE,
			func2_HI_ALM_VALUE
		}
	}
}

COMMAND read_func2_LO_ALM
{
	BLOCK func2_BLOCK;
	INDEX 32;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_LO_ALM_UNACKNOWLEDGED, 
			func2_LO_ALM_STATE,
			func2_LO_ALM_TIMESTAMP_HIGH,
			func2_LO_ALM_TIMESTAMP_LOW,
			func2_LO_ALM_SUBCODE,
			func2_LO_ALM_VALUE
		}
	}
}

COMMAND read_func2_LO_LO_ALM
{
	BLOCK func2_BLOCK;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_LO_LO_ALM_UNACKNOWLEDGED, 
			func2_LO_LO_ALM_STATE,
			func2_LO_LO_ALM_TIMESTAMP_HIGH,
			func2_LO_LO_ALM_TIMESTAMP_LOW,
			func2_LO_LO_ALM_SUBCODE,
			func2_LO_LO_ALM_VALUE
		}
	}
}

COMMAND read_func2_SIMULATE
{
	BLOCK func2_BLOCK;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_SIMULATION_STATUS,
			func2_SIMULATION_VALUE, 
			func2_SIMULATION_ENABLED
		}
	}
}

COMMAND write_func2_SIMULATE
{
	BLOCK func2_BLOCK;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_SIMULATION_STATUS,
			func2_SIMULATION_VALUE, 
			func2_SIMULATION_ENABLED
		}
		REPLY
		{
		}
	}
}

COMMAND read_func2_OUTPUT_UNIT_TEXT
{
	BLOCK func2_BLOCK;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func2_OUTPUT_UNIT_TEXT
		}
	}
}

COMMAND write_func2_OUTPUT_UNIT_TEXT
{
	BLOCK func2_BLOCK;
	INDEX 35;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func2_OUTPUT_UNIT_TEXT
		}
		REPLY
		{
		}
	}
}


/*******************************************************************************/
/*****	MENU Bar  **************************************************************/
/*******************************************************************************/
MENU Menu_Main_Specialist
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_S_Device,
		Menu_S_View,
		Menu_S_Options,
		Menu_Help
	}
}

MENU Menu_Main_Maintenance
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_M_Device,
		Menu_M_View,
		Menu_M_Options,
		Menu_Help
	}
}

/*---------------------------------------------------------------------*/
/*    Menu: Device													   */
/*---------------------------------------------------------------------*/
MENU Menu_S_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_NodeAddress,
		SEPARATOR,
		std_LoadinDevice,										
		std_LoadinPC,
		SEPARATOR,
		OnlineDialog_simulation,
		OnlineDialog_reset,
		SEPARATOR,
		OnlineDialog_BlockMode,
		OnlineDialog_channel,   
		OnlineDialog_SensorCal1,
		OnlineDialog_SensorCal2,
		SEPARATOR,
		OnlineDialog_write_locking
	}
}

MENU Menu_M_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_LoadinDevice,										
		std_LoadinPC											
	}
}

METHOD std_NodeAddress
{
	LABEL		[menu_Device_NodeAddress];
	DEFINITION
	{
	}
}

METHOD std_LoadinDevice
{
	LABEL		[menu_Device_LoadinDevice];
	DEFINITION
	{
	}
}

METHOD std_LoadinPC
{
	LABEL		[menu_Device_LoadinPC];
	DEFINITION
	{
	}
}

/*---------------------------------------------------------------------*/
/*    Menu: View													   */
/*---------------------------------------------------------------------*/
MENU Menu_S_View
{
	LABEL		[menu_View];
	ITEMS
	{
		OnlineWindow_display,
		OnlineWindow_yt,
		OnlineWindow_S_alarm,
		OnlineWindow_diagnosis,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	}
}

MENU Menu_M_View
{
	LABEL		[menu_View];
	ITEMS
	{
		OnlineWindow_display,
		OnlineWindow_yt,
		OnlineWindow_M_alarm,
		OnlineWindow_diagnosis,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	}
}

METHOD std_Funktionsleiste
{
	LABEL		[menu_View_Toolbar];
	DEFINITION
	{
	}
}

METHOD std_Statuszeile
{
	LABEL		[menu_View_Statusbar];
	DEFINITION
	{
	}
}

METHOD std_Update
{
	LABEL		[menu_View_Update];
	DEFINITION
	{
	}
}

/*******************************************************************************/
/*****	Online-Windows  ********************************************************/
/*******************************************************************************/

/*---------------------------------------------------------------------*/
/*    OnlineWindow: Display											   */
/*---------------------------------------------------------------------*/
MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_out,
		Page_display_measure,
		Page_display_scondary
	}
}

MENU Page_display_out
{
	LABEL		[menu_dialog_display_output];
	ITEMS
	{

		BarVal_out_display_1,
		BarVal_out_display_2,
		func1_OUT_VALUE,
		func1_OUT_STATUS,
		func2_OUT_VALUE,
		func2_OUT_STATUS
	}
}

MENU BarVal_out_display_1
{
	LABEL		"Output Value AI 1";
	ITEMS
	{
		func1_OUT_VALUE,
		func1_OUTPUT_SCALE_LOWER_VALUE (READ_ONLY),
		func1_OUTPUT_SCALE_UPPER_VALUE (READ_ONLY)
	}
}

MENU BarVal_out_display_2
{
	LABEL		"Output Value AI 2";
	ITEMS
	{
		func2_OUT_VALUE,
		func2_OUTPUT_SCALE_LOWER_VALUE (READ_ONLY),
		func2_OUTPUT_SCALE_UPPER_VALUE (READ_ONLY)
	}
}

MENU Page_display_measure
{
	LABEL		[menu_dialog_display_measure];
	ITEMS
	{
		Group_primary,
		Group_measure_1,
		Group_measure_2,
		Group_measure_3
	}
}

MENU Group_primary
{
	LABEL		"Primary Value";
	ITEMS
	{
		trans1_PRIMARY_VALUE,
		trans1_PRIMARY_VALUE_STATUS
	}
}

MENU Group_measure_1
{
	LABEL		"Sensor 1 Value";
	ITEMS
	{
		trans1_SECONDARY_VALUE_1,
		trans1_SECONDARY_VALUE_STATUS_1
	}
}

MENU Group_measure_2
{
	LABEL		"Sensor 2 Value";
	ITEMS
	{
		trans1_SECONDARY_VALUE_2,
		trans1_SECONDARY_VALUE_STATUS_2
	}
}

MENU Group_measure_3
{
	LABEL		"Internal Temperature";
	ITEMS
	{
		trans1_INTERN_TEMP,
		trans1_INTERN_TEMP_STATUS
	}
}

MENU Page_display_scondary
{
	LABEL		"Secondary";
	ITEMS
	{
		Group_display_secondary,
		trans1_RJ_TEMP
	}
}

MENU Group_display_secondary
{
	LABEL		"Input Fault";
	ITEMS
	{
		trans1_INPUT_FAULT_GEN,
		trans1_INPUT_FAULT_1,
		trans1_INPUT_FAULT_2,
		trans1_HW_ERROR
	}
}

/*---------------------------------------------------------------------*/
/*    Y t diagram													   */
/*---------------------------------------------------------------------*/
MENU OnlineWindow_yt
{
	LABEL		[menu_yt_diagram] ;
	ITEMS
	{
		Page_process_yt
	}
}

MENU Page_process_yt
{
	LABEL		[menu_yt_diagram] ;
	ITEMS
	{
		Val_yt_1,
		Val_yt_2,
		OCX_out_display_yt
	}
}

MENU Val_yt_1
{
    LABEL		"Output Value AI 1";
	STYLE		"OCX_DYNAMIC_YT";
	ITEMS
	{
		func1_OUT_VALUE	(READ_ONLY)
	}
}

MENU Val_yt_2
{
    LABEL		"Output Value AI 2";
	STYLE		"OCX_DYNAMIC_YT";
	ITEMS
	{
		func2_OUT_VALUE	(READ_ONLY)
	}
}

MENU OCX_out_display_yt
{
	LABEL		[menu_yt_diagram] ;
	STYLE		"PDMTVPROXY.PDMTVProxyCtrl.1";
	ITEMS
	{
		OCX_ProfilNum_yt,
		OCX_out_display_1,
		OCX_out_display_2,
		OCX_UserSettings_yt
	}
}

MENU OCX_out_display_1
{
    LABEL [func_out_value] ;
	STYLE		"OCX_DYNAMIC_YT";
	ITEMS
	{
		func1_OUT_VALUE					(READ_ONLY),
		func1_OUTPUT_SCALE_LOWER_VALUE	(READ_ONLY),
		func1_OUTPUT_SCALE_UPPER_VALUE	(READ_ONLY)
	}
}

MENU OCX_out_display_2
{
    LABEL [func_out_value] ;
	STYLE		"OCX_DYNAMIC_YT";
	ITEMS
	{
		func2_OUT_VALUE					(READ_ONLY),
		func2_OUTPUT_SCALE_LOWER_VALUE	(READ_ONLY),
		func2_OUTPUT_SCALE_UPPER_VALUE	(READ_ONLY)
	}
}

VARIABLE OCX_ProfilNum_yt
{
	LABEL		"ProfilID";
	STYLE		"OCX_PROPERTY";
	CLASS		LOCAL;
	TYPE		INTEGER(2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING    READ;
}

VARIABLE OCX_UserSettings_yt
{
	LABEL		"UserSettings";
	STYLE		"OCX_PROPERTY";
	CLASS		LOCAL;
	TYPE		ASCII (1000)
	{
		DEFAULT_VALUE	"";
	}
	HANDLING	READ & WRITE;
}

/*---------------------------------------------------------------------*/
/*    OnlineWindow: Alarm States									   */
/*---------------------------------------------------------------------*/
MENU OnlineWindow_S_alarm
{
	LABEL		[menu_dialog_alarm];
	ITEMS
	{
		Page_alarm_sum_1,
		Page_alarm_lim_1,

		Page_alarm_sum_2,
		Page_alarm_lim_2
	}
}

MENU OnlineWindow_M_alarm
{
	LABEL		[menu_dialog_alarm];
	ITEMS
	{
		Page_alarm_sum_1,
		Page_alarm_sum_2
	}
}

MENU Page_alarm_sum_1
{
	LABEL		"Analog Input 1 Alarm Summary";
	ITEMS
	{
	    func1_CURRENT_STATE_ALARM_SUM,
		func1_UNACKNOWLEDGED_STATE_ALARM_SUM,
		func1_UNREPORTED_STATE_ALARM_SUM,
		func1_DISABLED_STATE_ALARM_SUM
	}
}

MENU Page_alarm_lim_1
{
	LABEL		"Analog Input 1 Alarm Limits";
	ITEMS
	{
		func1_LIMIT_HI_HI	(READ_ONLY),
		func1_LIMIT_HI		(READ_ONLY),
		func1_LIMIT_LO		(READ_ONLY),
		func1_LIMIT_LO_LO	(READ_ONLY)
	}
}

MENU Page_alarm_sum_2
{
	LABEL		"Analog Input 2 Alarm Summary";
	ITEMS
	{
	    func2_CURRENT_STATE_ALARM_SUM,
		func2_UNACKNOWLEDGED_STATE_ALARM_SUM,
		func2_UNREPORTED_STATE_ALARM_SUM,
		func2_DISABLED_STATE_ALARM_SUM
	}
}

MENU Page_alarm_lim_2
{
	LABEL		"Analog Input 2 Alarm Limits";
	ITEMS
	{
		func2_LIMIT_HI_HI	(READ_ONLY),
		func2_LIMIT_HI		(READ_ONLY),
		func2_LIMIT_LO		(READ_ONLY),
		func2_LIMIT_LO_LO	(READ_ONLY)
	}
}

/*---------------------------------------------------------------------*/
/*    OnlineWindow: Diagnosis										   */
/*---------------------------------------------------------------------*/
MENU OnlineWindow_diagnosis
{
	LABEL		[menu_dialog_diagnosis];
	ITEMS
	{
		Page_diagnosis_general,
		Page_diagnosis_phys_block,
		Page_diagnosis_trans1_block,
		Page_diagnosis_trans2_block,
		Page_diagnosis_func1_block,
		Page_diagnosis_func2_block
	}
}

MENU Page_diagnosis_general
{
	LABEL		[menu_dialog_general];
	ITEMS
	{
		phys_TAG_DESCRIPTION	(READ_ONLY),
		phys_DEVICE_MAN_ID,
		phys_DEVICE_ID,
		phys_SERIAL_NUMBER,
		phys_SOFTWARE_REVISION,
		phys_HARDWARE_REVISION,
		phys_INSTALL_DATE		(READ_ONLY),
		phys_DIAGNOSIS,
		phys_DIAGNOSIS_EXT_01,
		phys_DIAGNOSIS_EXT_02
	}
}

MENU Page_diagnosis_phys_block
{
	LABEL		"Physical Block";
	ITEMS
	{
		phys_BLK_OBJECT,
		phys_BLK_PARENT_CLASS,
		phys_BLK_CLASS,
		phys_BLK_DD_REFRENCE,
		phys_BLK_DD_REV,
		phys_BLK_PROFILE,
		phys_BLK_PROFILE_REV,
		phys_STATIC_REVISION,
		phys_ACTUAL_MODE
	}
}

MENU Page_diagnosis_trans1_block
{
	LABEL		"Transducer Block";
	ITEMS
	{
		trans1_BLK_OBJECT,
		trans1_BLK_PARENT_CLASS,
		trans1_BLK_CLASS,
		trans1_BLK_DD_REFRENCE,
		trans1_BLK_DD_REV,
		trans1_BLK_PROFILE,
		trans1_BLK_PROFILE_REV,
		trans1_STATIC_REVISION,
		trans1_ACTUAL_MODE
	}
}

MENU Page_diagnosis_trans2_block
{
	LABEL		"Custom Lineraization Block";
	ITEMS
	{
		trans2_BLK_OBJECT,
		trans2_BLK_PARENT_CLASS,
		trans2_BLK_CLASS,
		trans2_BLK_DD_REFRENCE,
		trans2_BLK_DD_REV,
		trans2_BLK_PROFILE,
		trans2_BLK_PROFILE_REV,
		trans2_STATIC_REVISION,
		trans2_ACTUAL_MODE
	}
}

MENU Page_diagnosis_func1_block
{
	LABEL		"Analog Input Block 1";
	ITEMS
	{
		func1_BLK_OBJECT,
		func1_BLK_PARENT_CLASS,
		func1_BLK_CLASS,
		func1_BLK_DD_REFRENCE,
		func1_BLK_DD_REV,
		func1_BLK_PROFILE,
		func1_BLK_PROFILE_REV,
		func1_STATIC_REVISION,
		func1_ACTUAL_MODE
	}
}

MENU Page_diagnosis_func2_block
{
	LABEL		"Analog Input Block 2";
	ITEMS
	{
		func2_BLK_OBJECT,
		func2_BLK_PARENT_CLASS,
		func2_BLK_CLASS,
		func2_BLK_DD_REFRENCE,
		func2_BLK_DD_REV,
		func2_BLK_PROFILE,
		func2_BLK_PROFILE_REV,
		func2_STATIC_REVISION,
		func2_ACTUAL_MODE
	}
}

/*******************************************************************************/
/*****	Online-Dialogs  ********************************************************/
/*******************************************************************************/

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Simulation										   */
/*---------------------------------------------------------------------*/
MENU OnlineDialog_simulation
{
	LABEL		[menu_dialog_simulation];
	ITEMS
	{
		Page_simulation_input_1,
		Page_simulation_output_1,
		Page_simulation_input_2,
		Page_simulation_output_2
	}
}

MENU Page_simulation_input_1
{
	LABEL		"Simulation AI1 (Measured Value)";
	ITEMS
	{
		func1_SIMULATION_ENABLED,
		Group_simulate_input_1,
		method_set
	}
}

MENU Group_simulate_input_1
{
	LABEL		[func_simulate_value];
	ITEMS
	{
		func1_SIMULATION_VALUE,
		SEPARATOR,
		func1_SIMULATION_STATUS
	}
}

MENU Page_simulation_input_2
{
	LABEL		"Simulation AI2 (Measured Value)";
	ITEMS
	{
		func2_SIMULATION_ENABLED,
		Group_simulate_input_2,
		method_set
	}
}

MENU Group_simulate_input_2
{
	LABEL		[func_simulate_value];
	ITEMS
	{
		func2_SIMULATION_VALUE,
		SEPARATOR,
		func2_SIMULATION_STATUS
	}
}

MENU Page_simulation_output_1
{
	LABEL		"Simulation AI1 (Output)";
	ITEMS
	{
		func1_TARGET_MODE,
		func1_ACTUAL_MODE,
		Group_simulate_output_1,
		method_set
	}
}

MENU Group_simulate_output_1
{
	LABEL		[func_out_value];
	ITEMS
	{
		func1_OUT_VALUE,
		SEPARATOR,
		func1_OUT_STATUS
	}
}

MENU Page_simulation_output_2
{
	LABEL		"Simulation AI2 (Output)";
	ITEMS
	{
		func2_TARGET_MODE,
		func2_ACTUAL_MODE,
		Group_simulate_output_2,
		method_set
	}
}

MENU Group_simulate_output_2
{
	LABEL		[func_out_value];
	ITEMS
	{
		func2_OUT_VALUE,
		SEPARATOR,
		func2_OUT_STATUS
	}
}

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Reset											   */
/*---------------------------------------------------------------------*/
MENU OnlineDialog_reset
{
	LABEL		[master_reset];
	HELP		[master_reset_help];
	ITEMS
	{
		phys_FACTORY_RESET,
		phys_DIAGNOSIS,
		method_set
	}
}

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Write Locking									   */
/*---------------------------------------------------------------------*/
MENU OnlineDialog_write_locking
{
	LABEL		[phys_write_locking];
	HELP		[phys_write_locking_help];
	ITEMS
	{
		phys_WRITE_LOCKING,
		method_set
	}
}

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Channel											   */
/*---------------------------------------------------------------------*/
MENU OnlineDialog_channel
{
	LABEL		"Change Channel...";
	ITEMS
	{
		Page_channel_1,
		Page_channel_2
	}
}

MENU Page_channel_1
{
	LABEL		"AI Block Channel 1";
	ITEMS
	{

		func1_CHANNEL,
		method_set
	   
	}
}
MENU Page_channel_2
{
	LABEL		"AI Block Channel 2";
	ITEMS
	{
		func2_CHANNEL,
		method_set
	}
}

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Block Mode										   */
/*---------------------------------------------------------------------*/
MENU OnlineDialog_BlockMode      /* This menu have to be inserted */ 
{
	LABEL "Device Mode...";
	ITEMS
	{
		Page_Phys_Block_Mode,
		Page_trans1_Block_Mode,
		Page_trans2_Block_Mode,
		Page_Func1_Block_Mode,
		Page_Func2_Block_Mode
	}
}

MENU Page_Phys_Block_Mode      
{
	LABEL "Physical Block Mode";
	ITEMS
	{
		phys_ACTUAL_MODE,
		phys_TARGET_MODE,
		method_set             
	}
}

MENU Page_trans1_Block_Mode    
{
	LABEL "Transducer Block Mode";
	ITEMS
	{
		trans1_ACTUAL_MODE,    
		trans1_TARGET_MODE,
		method_set             
	}
}

MENU Page_trans2_Block_Mode    
{
	LABEL "Custom Linerization Block Mode";
	ITEMS
	{
		trans2_ACTUAL_MODE,    
		trans2_TARGET_MODE,
		method_set             
	}
}

MENU Page_Func1_Block_Mode     
{
	LABEL "Analog Input 1 Block Mode";
	ITEMS
	{
		func1_ACTUAL_MODE,     
		func1_TARGET_MODE,     
		method_set             
	}
}

MENU Page_Func2_Block_Mode     
{
	LABEL "Analog Input 2 Block Mode";
	ITEMS
	{
		func2_ACTUAL_MODE,     
		func2_TARGET_MODE,     
		method_set             
	}
}

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Sensor 1 Calibration							   */
/*---------------------------------------------------------------------*/
MENU OnlineDialog_SensorCal1      /* This menu have to be inserted */ 
{
	LABEL "Sensor 1 Calibration...";
	ITEMS
	{
		Page_Sensor_Cal1_Low,
		Page_Sensor_Cal1_High,
		Page_Sensor_Cal1_Method,
		Page_Sensor_Cal1_Other
	}
}

MENU Page_Sensor_Cal1_Low
{
	LABEL "Low";
	ITEMS
	{
		trans1_CAL_POINT_LO_1,
		trans1_CAL_ACTUAL_LO_1,
		method_set             
	}
}

MENU Page_Sensor_Cal1_High
{
	LABEL "High";
	ITEMS
	{
		trans1_CAL_POINT_HI_1,
		trans1_CAL_ACTUAL_HI_1,
		method_set             
	}
}

MENU Page_Sensor_Cal1_Method
{
	LABEL "Method";
	ITEMS
	{
		trans1_SENSOR_CAL_METHOD_1,
		method_set             
	}
}

MENU Page_Sensor_Cal1_Other
{
	LABEL "Other";
	ITEMS
	{
		trans1_SENSOR_CAL_LOC_1,
		trans1_SENSOR_CAL_WHO_1,
		trans1_SENSOR_CAL_DATE_1,
		method_set             
	}
}

/*---------------------------------------------------------------------*/
/*    OnlineDialog: Sensor 2 Calibration							   */
/*---------------------------------------------------------------------*/
MENU OnlineDialog_SensorCal2      /* This menu have to be inserted */ 
{
	LABEL "Sensor 2 Calibration...";
	ITEMS
	{
		Page_Sensor_Cal2_Low,
		Page_Sensor_Cal2_High,
		Page_Sensor_Cal2_Method,
		Page_Sensor_Cal2_Other
	}
	VALIDITY VALID_SENSOR_2
}

MENU Page_Sensor_Cal2_Low
{
	LABEL "Low";
	ITEMS
	{
		trans1_CAL_POINT_LO_2,
		trans1_CAL_ACTUAL_LO_2,
		method_set             
	}
}

MENU Page_Sensor_Cal2_High
{
	LABEL "High";
	ITEMS
	{
		trans1_CAL_POINT_HI_2,
		trans1_CAL_ACTUAL_HI_2,
		method_set             
	}
}

MENU Page_Sensor_Cal2_Method
{
	LABEL "Method";
	ITEMS
	{
		trans1_SENSOR_CAL_METHOD_2,
		method_set             
	}
}

MENU Page_Sensor_Cal2_Other
{
	LABEL "Other";
	ITEMS
	{
		trans1_SENSOR_CAL_LOC_2,
		trans1_SENSOR_CAL_WHO_2,
		trans1_SENSOR_CAL_DATE_2,
		method_set             
	}
}

/*******************************************************************************/
/*****	Table: Specialist  *****************************************************/
/*******************************************************************************/
MENU Table_Main_Specialist
{
	LABEL	MAIN_LABEL;
	ITEMS
	{
		Table2_s_Identification,
		Table2_s_Input,
		Table2_s_Output,
		Table2_s_Custom,
		Table2_s_Linear,
		Table2_s_Certification
	}
}

/**** IDENTIFICATION ****/
MENU Table2_s_Identification
{
	LABEL	[menu_ident];
	ITEMS
	{
		phys_STATIC_REVISION,
		Tab3_s_id_operation_unit,
		Tab3_s_id_device
	}
}

/**** IDENTIFICATION|OPERATION UNIT ****/
MENU Tab3_s_id_operation_unit
{
	LABEL		[menu_ident_opunit];
	ITEMS
	{
		phys_TAG_DESCRIPTION,
		phys_DESCRIPTION,	
		phys_DEVICE_MESSAGE	
	}
}

/**** IDENTIFICATION|DEVICE ****/
MENU Tab3_s_id_device
{
	LABEL		[menu_ident_device];
	ITEMS
	{
		phys_DEVICE_MAN_ID,
		phys_DEVICE_ID,
		phys_SERIAL_NUMBER,
		phys_SOFTWARE_REVISION,
		phys_HARDWARE_REVISION,
		phys_BLK_PROFILE_REV,
		phys_IDENT_NUMBER,
		phys_INSTALL_DATE
	}
}

/**** INPUT ****/
MENU Table2_s_Input
{
	LABEL	[menu_input];
	ITEMS
	{
		trans1_STATIC_REVISION,
		Table3_s_general,
		Table3_s_sensor1,
		Table3_s_sensor2,
		Table3_s_RJ
	}
}


/**** INPUT|GENERAL ****/
MENU Table3_s_general
{
	LABEL	"General";
	ITEMS
	{
		trans1_PRIMARY_VALUE_UNIT,
		trans1_SENSOR_MEAS_TYPE
	}
}


/**** INPUT|SENSOR1 ****/
MENU Table3_s_sensor1
{
	LABEL	"Sensor 1 (primary)";
	ITEMS
	{
		trans1_LIN_TYPE_1,
		trans1_RTDX_FACTOR_1,
		trans1_SENSOR_WIRE_CHECK_1,
		trans1_COMP_WIRE_1,
		trans1_SENSOR_CONNECTION_1,
		trans1_BIAS_1, 
		trans1_LOWER_SENSOR_LIMIT_1,
		trans1_UPPER_SENSOR_LIMIT_1,
		trans1_MIN_SENSOR_VALUE_1,
		trans1_MAX_SENSOR_VALUE_1,
		Table4_s_calibration1
	}
}

/**** INPUT|SENSOR1|CALIBRATION ****/
MENU Table4_s_calibration1
{
	LABEL	"Sensor 1 Calibration";
	ITEMS
	{
		trans1_CAL_POINT_LO_1 (READ_ONLY),
		trans1_CAL_ACTUAL_LO_1 (READ_ONLY),
		trans1_CAL_POINT_HI_1 (READ_ONLY),
		trans1_CAL_ACTUAL_HI_1 (READ_ONLY),
		trans1_SENSOR_CAL_METHOD_1 (READ_ONLY),
		trans1_SENSOR_CAL_LOC_1 (READ_ONLY),
		trans1_SENSOR_CAL_WHO_1 (READ_ONLY),
		Table5_s_Cal_Date_1
	}
}

/**** INPUT|SENSOR1|CALIBRATION|CALIBRATION DATE ****/
MENU Table5_s_Cal_Date_1
{
	LABEL	"Sensor 1 Calibration Date";
	ITEMS
	{
		trans1_SENSOR_CAL_DATE_1[1] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_1[2] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_1[3] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_1[4] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_1[5] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_1[6] (READ_ONLY)
	}
}

/**** INPUT|SENSOR2 ****/
MENU Table3_s_sensor2
{
	LABEL	"Sensor 2 (secondary)";
	ITEMS
	{
		trans1_LIN_TYPE_2,
		trans1_RTDX_FACTOR_2,
		trans1_SENSOR_WIRE_CHECK_2,
		trans1_COMP_WIRE_2,
		trans1_SENSOR_CONNECTION_2,
		trans1_BIAS_2, 
		trans1_LOWER_SENSOR_LIMIT_2,
		trans1_UPPER_SENSOR_LIMIT_2,
		trans1_MIN_SENSOR_VALUE_2,
		trans1_MAX_SENSOR_VALUE_2,
		Table4_s_calibration2
	}
	VALIDITY	VALID_SENSOR_2
}

/**** INPUT|SENSOR2|CALIBRATION ****/
MENU Table4_s_calibration2
{
	LABEL	"Sensor 2 Calibration";
	ITEMS
	{
		trans1_CAL_POINT_LO_2 (READ_ONLY),
		trans1_CAL_ACTUAL_LO_2 (READ_ONLY),
		trans1_CAL_POINT_HI_2 (READ_ONLY),
		trans1_CAL_ACTUAL_HI_2 (READ_ONLY),
		trans1_SENSOR_CAL_METHOD_2 (READ_ONLY),
		trans1_SENSOR_CAL_LOC_2 (READ_ONLY),
		trans1_SENSOR_CAL_WHO_2 (READ_ONLY),
		Table5_s_Cal_Date_2 (READ_ONLY) 
	}
}

/**** INPUT|SENSOR1|CALIBRATION|CALIBRATION DATE2 ****/
MENU Table5_s_Cal_Date_2
{
	LABEL	"Sensor 2 Calibration Date";
	ITEMS
	{
		trans1_SENSOR_CAL_DATE_2[1] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_2[2] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_2[3] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_2[4] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_2[5] (READ_ONLY),
		trans1_SENSOR_CAL_DATE_2[6] (READ_ONLY)
	}
}

/**** INPUT|RJ ***/
MENU Table3_s_RJ
{
	LABEL	"Refrence Junction";
	ITEMS
	{
		trans1_RJ_TYPE,
		trans1_EXTERNAL_RJ_VALUE,
		trans1_RJ_COMP_WIRE,
		trans1_SENSOR_WIRE_CHECK_RJ
	}
	VALIDITY	VALID_RJ_TYPE
}


/**** OUTPUT ****/
MENU Table2_s_Output
{
	LABEL	[menu_output];
	ITEMS
	{
		Table3_s_Measurement_1,
		Table3_s_Measurement_2
	}
}

MENU Table3_s_Measurement_1
{
	LABEL	"Analog Input 1 (AI1)";
	ITEMS
	{
		func1_STATIC_REVISION,
		func1_CHANNEL,
		func1_PV_FTIME,
		func1_LIN_TYPE,
		Table4_s_pv_scale_1,
		Table4_s_output_scale_1,
		Table4_s_output_limits_1,
		Table4_s_simulation_1
	}
}

/**** OUTPUT|PV SCALE1 ****/
MENU Table4_s_pv_scale_1
{
	LABEL	"Process Scale Variable (AI1)";
	ITEMS
	{
		func1_PV_SCALE_LOWER,
		func1_PV_SCALE_UPPER
	}
}

/**** OUTPUT|SCALE1 ****/
MENU Table4_s_output_scale_1
{
	LABEL	"Output Scale (AI1)";
	ITEMS
	{
		func1_OUTPUT_SCALE_LOWER_VALUE,
		func1_OUTPUT_SCALE_UPPER_VALUE,
		func1_OUTPUT_SCALE_UNIT,
		func1_OUTPUT_UNIT_TEXT
	}
}

/**** OUTPUT|LIMITS1 ****/
MENU Table4_s_output_limits_1
{
	LABEL	"Output Limits (AI1)";
	ITEMS
	{
		func1_LIMIT_HYSTERESIS,
		func1_LIMIT_LO_LO,	
		func1_LIMIT_LO,	
		func1_LIMIT_HI,	
		func1_LIMIT_HI_HI
	}
}

/**** OUTPUT|SIMULATION1 ****/
MENU Table4_s_simulation_1
{
	LABEL	"Simulation (AI1)";
	ITEMS
	{
		func1_SIMULATION_ENABLED	(READ_ONLY),
		func1_SIMULATION_VALUE	(READ_ONLY),
		func1_SIMULATION_STATUS	(READ_ONLY)
	}
}

MENU Table3_s_Measurement_2
{
	LABEL	"Analog Input 2 (AI2)";
	ITEMS
	{
		func2_STATIC_REVISION,
		func2_CHANNEL,
		func2_PV_FTIME,
		func2_LIN_TYPE,
		Table4_s_pv_scale_2,
		Table4_s_output_scale_2,
		Table4_s_output_limits_2,
		Table4_s_simulation_2
	}
}

/**** OUTPUT|PV SCALE2 ****/
MENU Table4_s_pv_scale_2
{
	LABEL	"Process Scale Variable (AI2)";
	ITEMS
	{
		func2_PV_SCALE_LOWER,
		func2_PV_SCALE_UPPER
	}
}

/**** OUTPUT|SCALE2 ****/
MENU Table4_s_output_scale_2
{
	LABEL	"Output Scale (AI2)";
	ITEMS
	{
		func2_OUTPUT_SCALE_LOWER_VALUE,
		func2_OUTPUT_SCALE_UPPER_VALUE,
		func2_OUTPUT_SCALE_UNIT,
		func2_OUTPUT_UNIT_TEXT
	}
}

/**** OUTPUT|LIMITS2 ****/
MENU Table4_s_output_limits_2
{
	LABEL	"Output Limits (AI2)";
	ITEMS
	{
		func2_LIMIT_HYSTERESIS,
		func2_LIMIT_LO_LO,	
		func2_LIMIT_LO,	
		func2_LIMIT_HI,	
		func2_LIMIT_HI_HI	
	}
}

/**** OUTPUT|SIMULATION1 ****/
MENU Table4_s_simulation_2
{
	LABEL	"Simulation (AI2)";
	ITEMS
	{
		func2_SIMULATION_ENABLED	(READ_ONLY),
		func2_SIMULATION_VALUE	(READ_ONLY),
		func2_SIMULATION_STATUS	(READ_ONLY)
	}
}

/**** CUSTOM ****/
MENU Table2_s_Custom
{
	LABEL	"Custom Sensor";
	ITEMS
	{
		Table3_s_RTD,
		Table3_s_TC
	}
	VALIDITY	VALID_POLY
}

/**** CUSTOM|TC ****/
MENU Table3_s_TC
{
	LABEL	"Custom TC Polynomial";
	ITEMS
	{
		trans2_CUSTOM_TC_NAME,
		trans2_CUSTOM_TC_POLY_COUNT,
		trans2_CUSTOM_TC_MIN_IN,
		trans2_CUSTOM_TC_MIN_OUT,
		trans2_CUSTOM_TC_MAX_OUT,
		Table4_s_TC_Poly1,
		Table4_s_TC_Poly2,
		Table4_s_TC_Poly3,
		Table4_s_TC_Poly4,
		Table4_s_TC_Poly5,
		Table4_s_TC_RJ_Poly
	}
	VALIDITY	VALID_TC_POLY(1)
}

/**** CUSTOM|TC|POLY1 ****/
MENU Table4_s_TC_Poly1
{
	LABEL	"Polynomial Part 1";
	ITEMS
	{
		trans2_CUSTOM_TC_POLY_1.Ohm,
		trans2_CUSTOM_TC_POLY_1.a4,
		trans2_CUSTOM_TC_POLY_1.a3,
		trans2_CUSTOM_TC_POLY_1.a2,
		trans2_CUSTOM_TC_POLY_1.a1,
		trans2_CUSTOM_TC_POLY_1.a0
	}
	VALIDITY	VALID_TC_POLY(1)
}

/**** CUSTOM|TC|POLY2 ****/
MENU Table4_s_TC_Poly2
{
	LABEL	"Polynomial Part 2";
	ITEMS
	{
		trans2_CUSTOM_TC_POLY_2.Ohm,
		trans2_CUSTOM_TC_POLY_2.a4,
		trans2_CUSTOM_TC_POLY_2.a3,
		trans2_CUSTOM_TC_POLY_2.a2,
		trans2_CUSTOM_TC_POLY_2.a1,
		trans2_CUSTOM_TC_POLY_2.a0
	}
	VALIDITY	VALID_TC_POLY(2)
}

/**** CUSTOM|TC|POLY3 ****/
MENU Table4_s_TC_Poly3
{
	LABEL	"Polynomial Part 3";
	ITEMS
	{
		trans2_CUSTOM_TC_POLY_3.Ohm,
		trans2_CUSTOM_TC_POLY_3.a4,
		trans2_CUSTOM_TC_POLY_3.a3,
		trans2_CUSTOM_TC_POLY_3.a2,
		trans2_CUSTOM_TC_POLY_3.a1,
		trans2_CUSTOM_TC_POLY_3.a0
	}
	VALIDITY	VALID_TC_POLY(3)
}

/**** CUSTOM|TC|POLY1 ****/
MENU Table4_s_TC_Poly4
{
	LABEL	"Polynomial Part 4";
	ITEMS
	{
		trans2_CUSTOM_TC_POLY_4.Ohm,
		trans2_CUSTOM_TC_POLY_4.a4,
		trans2_CUSTOM_TC_POLY_4.a3,
		trans2_CUSTOM_TC_POLY_4.a2,
		trans2_CUSTOM_TC_POLY_4.a1,
		trans2_CUSTOM_TC_POLY_4.a0
	}
	VALIDITY	VALID_TC_POLY(4)
}

/**** CUSTOM|TC|POLY1 ****/
MENU Table4_s_TC_Poly5
{
	LABEL	"Polynomial Part 5";
	ITEMS
	{
		trans2_CUSTOM_TC_POLY_5.Ohm,
		trans2_CUSTOM_TC_POLY_5.a4,
		trans2_CUSTOM_TC_POLY_5.a3,
		trans2_CUSTOM_TC_POLY_5.a2,
		trans2_CUSTOM_TC_POLY_5.a1,
		trans2_CUSTOM_TC_POLY_5.a0
	}
	VALIDITY	VALID_TC_POLY(5)
}

/**** CUSTOM|TC|POLY1 ****/
MENU Table4_s_TC_RJ_Poly
{
	LABEL	"Polynomial Part RJ";
	ITEMS
	{
		trans2_CUSTOM_TC_RJ_POLY.a3,
		trans2_CUSTOM_TC_RJ_POLY.a2,
		trans2_CUSTOM_TC_RJ_POLY.a1,
		trans2_CUSTOM_TC_RJ_POLY.a0
	}
	VALIDITY	VALID_TC_POLY(1)
}

/**** CUSTOM|RTD ****/
MENU Table3_s_RTD
{
	LABEL	"Custom RTD Polynomial";
	ITEMS
	{
		trans2_CUSTOM_RTD_NAME,
		trans2_CUSTOM_RTD_POLY_COUNT,
		trans2_CUSTOM_RTD_MIN_IN,
		trans2_CUSTOM_RTD_MIN_OUT,
		trans2_CUSTOM_RTD_MAX_OUT,
		Table4_s_RTD_Poly1,
		Table4_s_RTD_Poly2,
		Table4_s_RTD_Poly3,
		Table4_s_RTD_Poly4,
		Table4_s_RTD_Poly5
	}
	VALIDITY	VALID_RTD_POLY(1)
}

/**** CUSTOM|RTD|POLY1 ****/
MENU Table4_s_RTD_Poly1
{
	LABEL	"Polynomial Part 1";
	ITEMS
	{
		trans2_CUSTOM_RTD_POLY_1.Ohm,
		trans2_CUSTOM_RTD_POLY_1.a4,
		trans2_CUSTOM_RTD_POLY_1.a3,
		trans2_CUSTOM_RTD_POLY_1.a2,
		trans2_CUSTOM_RTD_POLY_1.a1,
		trans2_CUSTOM_RTD_POLY_1.a0
	}
	VALIDITY	VALID_RTD_POLY(1)
}

/**** CUSTOM|RTD|POLY2 ****/
MENU Table4_s_RTD_Poly2
{
	LABEL	"Polynomial Part 2";
	ITEMS
	{
		trans2_CUSTOM_RTD_POLY_2.Ohm,
		trans2_CUSTOM_RTD_POLY_2.a4,
		trans2_CUSTOM_RTD_POLY_2.a3,
		trans2_CUSTOM_RTD_POLY_2.a2,
		trans2_CUSTOM_RTD_POLY_2.a1,
		trans2_CUSTOM_RTD_POLY_2.a0
	}
	VALIDITY	VALID_RTD_POLY(2)
}

/**** CUSTOM|RTD|POLY3 ****/
MENU Table4_s_RTD_Poly3
{
	LABEL	"Polynomial Part 3";
	ITEMS
	{
		trans2_CUSTOM_RTD_POLY_3.Ohm,
		trans2_CUSTOM_RTD_POLY_3.a4,
		trans2_CUSTOM_RTD_POLY_3.a3,
		trans2_CUSTOM_RTD_POLY_3.a2,
		trans2_CUSTOM_RTD_POLY_3.a1,
		trans2_CUSTOM_RTD_POLY_3.a0
	}
	VALIDITY	VALID_RTD_POLY(3)
}

/**** CUSTOM|RTD|POLY4 ****/
MENU Table4_s_RTD_Poly4
{
	LABEL	"Polynomial Part 4";
	ITEMS
	{
		trans2_CUSTOM_RTD_POLY_4.Ohm,
		trans2_CUSTOM_RTD_POLY_4.a4,
		trans2_CUSTOM_RTD_POLY_4.a3,
		trans2_CUSTOM_RTD_POLY_4.a2,
		trans2_CUSTOM_RTD_POLY_4.a1,
		trans2_CUSTOM_RTD_POLY_4.a0
	}
	VALIDITY	VALID_RTD_POLY(4)
}

/**** CUSTOM|RTD|POLY1 ****/
MENU Table4_s_RTD_Poly5
{
	LABEL	"Polynomial Part 5";
	ITEMS
	{
		trans2_CUSTOM_RTD_POLY_5.Ohm,
		trans2_CUSTOM_RTD_POLY_5.a4,
		trans2_CUSTOM_RTD_POLY_5.a3,
		trans2_CUSTOM_RTD_POLY_5.a2,
		trans2_CUSTOM_RTD_POLY_5.a1,
		trans2_CUSTOM_RTD_POLY_5.a0
	}
	VALIDITY	VALID_RTD_POLY(5)
}

/**** CERTIFICATION ****/
MENU Table2_s_Certification
{
	LABEL	[menu_certificates];
	ITEMS
	{
		phys_CERTIFICATION	(READ_ONLY)
	}
}

/**** LINEAR INTERPOLATION ****/
MENU Table2_s_Linear
{
	LABEL	"Linear Interpolation";
	ITEMS
	{
		trans2_TAB_MIN_NUMBER,
		trans2_TAB_MAX_NUMBER,
		trans2_TAB_ACTUAL_NUMBER,
		Table2_s_Points
	}
	VALIDITY	VALID_TABLE
}

/**** LINEAR INTERPOLATION|POINTS ****/
MENU Table2_s_Points
{
	LABEL	"Points";
	ITEMS
	{
		trans2_TAB_X_Y_VALUE1,
		trans2_TAB_X_Y_VALUE2,
		trans2_TAB_X_Y_VALUE3,
		trans2_TAB_X_Y_VALUE4,
		trans2_TAB_X_Y_VALUE5,
		trans2_TAB_X_Y_VALUE6,
		trans2_TAB_X_Y_VALUE7,
		trans2_TAB_X_Y_VALUE8,
		trans2_TAB_X_Y_VALUE9,
		trans2_TAB_X_Y_VALUE10,
		trans2_TAB_X_Y_VALUE11,
		trans2_TAB_X_Y_VALUE12,
		trans2_TAB_X_Y_VALUE13,
		trans2_TAB_X_Y_VALUE14,
		trans2_TAB_X_Y_VALUE15,
		trans2_TAB_X_Y_VALUE16,
		trans2_TAB_X_Y_VALUE17,
		trans2_TAB_X_Y_VALUE18,
		trans2_TAB_X_Y_VALUE19,
		trans2_TAB_X_Y_VALUE20,
		trans2_TAB_X_Y_VALUE21,
		trans2_TAB_X_Y_VALUE22,
		trans2_TAB_X_Y_VALUE23,
		trans2_TAB_X_Y_VALUE24,
		trans2_TAB_X_Y_VALUE25,
		trans2_TAB_X_Y_VALUE26,
		trans2_TAB_X_Y_VALUE27,
		trans2_TAB_X_Y_VALUE28,
		trans2_TAB_X_Y_VALUE29,
		trans2_TAB_X_Y_VALUE30,
		trans2_TAB_X_Y_VALUE31,
		trans2_TAB_X_Y_VALUE32,
		trans2_TAB_X_Y_VALUE33,
		trans2_TAB_X_Y_VALUE34,
		trans2_TAB_X_Y_VALUE35,
		trans2_TAB_X_Y_VALUE36,
		trans2_TAB_X_Y_VALUE37,
		trans2_TAB_X_Y_VALUE38,
		trans2_TAB_X_Y_VALUE39,
		trans2_TAB_X_Y_VALUE40,
		trans2_TAB_X_Y_VALUE41,
		trans2_TAB_X_Y_VALUE42,
		trans2_TAB_X_Y_VALUE43,
		trans2_TAB_X_Y_VALUE44,
		trans2_TAB_X_Y_VALUE45,
		trans2_TAB_X_Y_VALUE46,
		trans2_TAB_X_Y_VALUE47,
		trans2_TAB_X_Y_VALUE48,
		trans2_TAB_X_Y_VALUE49,
		trans2_TAB_X_Y_VALUE50
	}
	VALIDITY	VALID_TABLE
}

/*******************************************************************************/
/*****	Table: Maintenance  ****************************************************/
/*******************************************************************************/

MENU Table_Main_Maintenance
{
	LABEL	MAIN_LABEL;
	ITEMS
	{
		Table2_m_Identification
	}
}

MENU Table2_m_Identification
{
	LABEL		[menu_ident];
	ITEMS
	{
		Tab3_m_id_operation_unit,
		Tab3_m_id_device
	}
}

MENU Tab3_m_id_operation_unit
{
	LABEL		[menu_ident_opunit];
	ITEMS
	{
		phys_TAG_DESCRIPTION (READ_ONLY),
		phys_DESCRIPTION,	
		phys_DEVICE_MESSAGE	
	}
}

MENU Tab3_m_id_device
{
	LABEL		[menu_ident_device];
	ITEMS
	{
		phys_DEVICE_MAN_ID,
		phys_DEVICE_ID,
		phys_SERIAL_NUMBER,
		phys_SOFTWARE_REVISION,
		phys_HARDWARE_REVISION,
		phys_BLK_PROFILE_REV,
		phys_IDENT_NUMBER (READ_ONLY),
		phys_INSTALL_DATE (READ_ONLY)
	}
}





/***********************************************************************/
/*    Download/Upload                                                  */
/***********************************************************************/

/* Get from device */

MENU download_variables
{
	LABEL		[menu_load_to_PC];
	ITEMS
	{
		phys_TARGET_MODE,
		trans1_TARGET_MODE,
		trans2_TARGET_MODE,
		func1_TARGET_MODE,
		func2_TARGET_MODE,

// physical block
		phys_BLK_RESERVE,
		phys_BLK_OBJECT,
		phys_BLK_PARENT_CLASS,
		phys_BLK_CLASS,
		phys_BLK_DD_REFRENCE,
		phys_BLK_DD_REV,
		phys_BLK_PROFILE,
		phys_BLK_PROFILE_REV,
		phys_BLK_EXECUTION_TIME,
		phys_BLK_NUM_PARAMETERS,
		phys_BLK_INDEX_VIEW_1,
		phys_BLK_NUM_VIEW_LISTS,
		phys_STATIC_REVISION,
		phys_TAG_DESCRIPTION,
		phys_STRATEGY,
		phys_ALERT_KEY,
		phys_ACTUAL_MODE,
		phys_PERMITTED_MODE,
		phys_NORMAL_MODE,
		phys_CURRENT_STATE_ALARM_SUM,
		phys_UNACKNOWLEDGED_STATE_ALARM_SUM,
		phys_UNREPORTED_STATE_ALARM_SUM,
		phys_DISABLED_STATE_ALARM_SUM,
		phys_SOFTWARE_REVISION,
		phys_HARDWARE_REVISION,
		phys_DEVICE_MAN_ID,
		phys_DEVICE_ID,
		phys_SERIAL_NUMBER,
		phys_DIAGNOSIS,
		phys_DIAGNOSIS_EXT_01,
		phys_DIAGNOSIS_EXT_02,
		phys_DIAGNOSIS_MASK,
		phys_DIAGNOSIS_MASK_EXT_01,
		phys_DIAGNOSIS_MASK_EXT_02,
		phys_CERTIFICATION,
		phys_WRITE_LOCKING,
		phys_FACTORY_RESET,
		phys_DESCRIPTION,
		phys_DEVICE_MESSAGE,
		phys_INSTALL_DATE,
		phys_LOCAL_OP_ENABLED,
		phys_IDENT_NUMBER,

// transducer 1
		trans1_BLK_RESERVE,
		trans1_BLK_OBJECT,
		trans1_BLK_PARENT_CLASS,
		trans1_BLK_CLASS,
		trans1_BLK_DD_REFRENCE,
		trans1_BLK_DD_REV,
		trans1_BLK_PROFILE,
		trans1_BLK_PROFILE_REV,
		trans1_BLK_EXECUTION_TIME,
		trans1_BLK_NUM_PARAMETERS,
		trans1_BLK_INDEX_VIEW_1,
		trans1_BLK_NUM_VIEW_LISTS,
		trans1_STATIC_REVISION,
		trans1_TAG_DESCRIPTION,
		trans1_STRATEGY,
		trans1_ALERT_KEY,
		trans1_ACTUAL_MODE,
		trans1_PERMITTED_MODE,
		trans1_NORMAL_MODE,
		trans1_CURRENT_STATE_ALARM_SUM,
		trans1_UNACKNOWLEDGED_STATE_ALARM_SUM,
		trans1_UNREPORTED_STATE_ALARM_SUM,
		trans1_DISABLED_STATE_ALARM_SUM,
		trans1_PRIMARY_VALUE,
		trans1_PRIMARY_VALUE_STATUS,
		trans1_PRIMARY_VALUE_UNIT,
		trans1_SECONDARY_VALUE_1,
		trans1_SECONDARY_VALUE_STATUS_1, 
		trans1_SECONDARY_VALUE_2,
		trans1_SECONDARY_VALUE_STATUS_2,
		trans1_SENSOR_MEAS_TYPE,
		trans1_LIN_TYPE_1,
		trans1_BIAS_1,
		trans1_BIAS_2,
		trans1_UPPER_SENSOR_LIMIT_1,
		trans1_LOWER_SENSOR_LIMIT_1,
		trans1_INPUT_FAULT_GEN,
		trans1_INPUT_FAULT_1,
		trans1_INPUT_FAULT_2,
		trans1_SENSOR_WIRE_CHECK_1,
		trans1_SENSOR_WIRE_CHECK_2,
		trans1_MAX_SENSOR_VALUE_1,
		trans1_MIN_SENSOR_VALUE_1,
		trans1_MAX_SENSOR_VALUE_2,
		trans1_MIN_SENSOR_VALUE_2,
		trans1_RJ_TEMP,
		trans1_RJ_TYPE,
		trans1_EXTERNAL_RJ_VALUE,
		trans1_SENSOR_CONNECTION_1,
		trans1_COMP_WIRE_1,
		trans1_COMP_WIRE_2,
		trans1_SENSOR_CONNECTION_2,
		trans1_LOWER_SENSOR_LIMIT_2,
		trans1_UPPER_SENSOR_LIMIT_2,
		trans1_LIN_TYPE_2,
		trans1_RJ_COMP_WIRE,
		trans1_RJ_FAULT,
		trans1_SENSOR_WIRE_CHECK_RJ,
		trans1_INTERN_TEMP,
		trans1_INTERN_TEMP_STATUS,
		trans1_CAL_POINT_LO_1,
		trans1_CAL_ACTUAL_LO_1,
		trans1_CAL_POINT_HI_1,
		trans1_CAL_ACTUAL_HI_1,
		trans1_SENSOR_CAL_METHOD_1,
		trans1_SENSOR_CAL_LOC_1,
		trans1_SENSOR_CAL_DATE_1,
		trans1_SENSOR_CAL_WHO_1,
		trans1_CAL_POINT_LO_2,
		trans1_CAL_ACTUAL_LO_2,
		trans1_CAL_POINT_HI_2,
		trans1_CAL_ACTUAL_HI_2,
		trans1_SENSOR_CAL_METHOD_2,
		trans1_SENSOR_CAL_LOC_2,
		trans1_SENSOR_CAL_DATE_2,
		trans1_SENSOR_CAL_WHO_2,
		trans1_HW_ERROR,
		trans1_CABLE_RES1,
		trans1_CABLE_RES2,
		trans1_RTDX_FACTOR_1,
		trans1_RTDX_FACTOR_2,

// transducer 2
		trans2_BLK_RESERVE,
		trans2_BLK_OBJECT,
		trans2_BLK_PARENT_CLASS,
		trans2_BLK_CLASS,
		trans2_BLK_DD_REFRENCE,
		trans2_BLK_DD_REV,
		trans2_BLK_PROFILE,
		trans2_BLK_PROFILE_REV,
		trans2_BLK_EXECUTION_TIME,
		trans2_BLK_NUM_PARAMETERS,
		trans2_BLK_INDEX_VIEW_1,
		trans2_BLK_NUM_VIEW_LISTS,
		trans2_STATIC_REVISION,
		trans2_TAG_DESCRIPTION,
		trans2_STRATEGY,
		trans2_ALERT_KEY,
		trans2_ACTUAL_MODE,
		trans2_PERMITTED_MODE,
		trans2_NORMAL_MODE,
		trans2_CURRENT_STATE_ALARM_SUM,
		trans2_UNACKNOWLEDGED_STATE_ALARM_SUM,
		trans2_UNREPORTED_STATE_ALARM_SUM,
		trans2_DISABLED_STATE_ALARM_SUM,
		trans2_CUSTOM_TC_POLY_COUNT,
		trans2_CUSTOM_TC_MIN_IN,
		trans2_CUSTOM_TC_MIN_OUT,
		trans2_CUSTOM_TC_MAX_OUT,
		trans2_CUSTOM_TC_POLY_1.Ohm,
		trans2_CUSTOM_TC_POLY_1.a4,
		trans2_CUSTOM_TC_POLY_1.a3,
		trans2_CUSTOM_TC_POLY_1.a2,
		trans2_CUSTOM_TC_POLY_1.a1,
		trans2_CUSTOM_TC_POLY_1.a0,
		trans2_CUSTOM_TC_POLY_2.Ohm,
		trans2_CUSTOM_TC_POLY_2.a4,
		trans2_CUSTOM_TC_POLY_2.a3,
		trans2_CUSTOM_TC_POLY_2.a2,
		trans2_CUSTOM_TC_POLY_2.a1,
		trans2_CUSTOM_TC_POLY_2.a0,
		trans2_CUSTOM_TC_POLY_3.Ohm,
		trans2_CUSTOM_TC_POLY_3.a4,
		trans2_CUSTOM_TC_POLY_3.a3,
		trans2_CUSTOM_TC_POLY_3.a2,
		trans2_CUSTOM_TC_POLY_3.a1,
		trans2_CUSTOM_TC_POLY_3.a0,
		trans2_CUSTOM_TC_POLY_4.Ohm,
		trans2_CUSTOM_TC_POLY_4.a4,
		trans2_CUSTOM_TC_POLY_4.a3,
		trans2_CUSTOM_TC_POLY_4.a2,
		trans2_CUSTOM_TC_POLY_4.a1,
		trans2_CUSTOM_TC_POLY_4.a0,
		trans2_CUSTOM_TC_POLY_5.Ohm,
		trans2_CUSTOM_TC_POLY_5.a4,
		trans2_CUSTOM_TC_POLY_5.a3,
		trans2_CUSTOM_TC_POLY_5.a2,
		trans2_CUSTOM_TC_POLY_5.a1,
		trans2_CUSTOM_TC_POLY_5.a0,
		trans2_CUSTOM_TC_RJ_POLY.a3,
		trans2_CUSTOM_TC_RJ_POLY.a2,
		trans2_CUSTOM_TC_RJ_POLY.a1,
		trans2_CUSTOM_TC_RJ_POLY.a0,
		trans2_CUSTOM_RTD_NAME,
		trans2_CUSTOM_RTD_POLY_COUNT,
		trans2_CUSTOM_RTD_MIN_IN,
		trans2_CUSTOM_RTD_MIN_OUT,
		trans2_CUSTOM_RTD_MAX_OUT,
		trans2_CUSTOM_RTD_POLY_1.Ohm,
		trans2_CUSTOM_RTD_POLY_1.a4,
		trans2_CUSTOM_RTD_POLY_1.a3,
		trans2_CUSTOM_RTD_POLY_1.a2,
		trans2_CUSTOM_RTD_POLY_1.a1,
		trans2_CUSTOM_RTD_POLY_1.a0,
		trans2_CUSTOM_RTD_POLY_2.Ohm,
		trans2_CUSTOM_RTD_POLY_2.a4,
		trans2_CUSTOM_RTD_POLY_2.a3,
		trans2_CUSTOM_RTD_POLY_2.a2,
		trans2_CUSTOM_RTD_POLY_2.a1,
		trans2_CUSTOM_RTD_POLY_2.a0,
		trans2_CUSTOM_RTD_POLY_3.Ohm,
		trans2_CUSTOM_RTD_POLY_3.a4,
		trans2_CUSTOM_RTD_POLY_3.a3,
		trans2_CUSTOM_RTD_POLY_3.a2,
		trans2_CUSTOM_RTD_POLY_3.a1,
		trans2_CUSTOM_RTD_POLY_3.a0,
		trans2_CUSTOM_RTD_POLY_4.Ohm,
		trans2_CUSTOM_RTD_POLY_4.a4,
		trans2_CUSTOM_RTD_POLY_4.a3,
		trans2_CUSTOM_RTD_POLY_4.a2,
		trans2_CUSTOM_RTD_POLY_4.a1,
		trans2_CUSTOM_RTD_POLY_4.a0,
		trans2_CUSTOM_RTD_POLY_5.Ohm,
		trans2_CUSTOM_RTD_POLY_5.a4,
		trans2_CUSTOM_RTD_POLY_5.a3,
		trans2_CUSTOM_RTD_POLY_5.a2,
		trans2_CUSTOM_RTD_POLY_5.a1,
		trans2_CUSTOM_RTD_POLY_5.a0,
		trans2_TAB_MIN_NUMBER,
		trans2_TAB_MAX_NUMBER,
		trans2_TAB_ACTUAL_NUMBER,
		trans2_TAB_X_Y_VALUE1 ,
		trans2_TAB_X_Y_VALUE2 ,
		trans2_TAB_X_Y_VALUE3 ,
		trans2_TAB_X_Y_VALUE4 ,
		trans2_TAB_X_Y_VALUE5 ,
		trans2_TAB_X_Y_VALUE6 ,
		trans2_TAB_X_Y_VALUE7 ,
		trans2_TAB_X_Y_VALUE8 ,
		trans2_TAB_X_Y_VALUE9 ,
		trans2_TAB_X_Y_VALUE10,
		trans2_TAB_X_Y_VALUE11,
		IF (trans2_TAB_ACTUAL_NUMBER >= 12) {trans2_TAB_X_Y_VALUE12}
		IF (trans2_TAB_ACTUAL_NUMBER >= 13) {trans2_TAB_X_Y_VALUE13}
		IF (trans2_TAB_ACTUAL_NUMBER >= 14) {trans2_TAB_X_Y_VALUE14}
		IF (trans2_TAB_ACTUAL_NUMBER >= 15) {trans2_TAB_X_Y_VALUE15}
		IF (trans2_TAB_ACTUAL_NUMBER >= 16) {trans2_TAB_X_Y_VALUE16}
		IF (trans2_TAB_ACTUAL_NUMBER >= 17) {trans2_TAB_X_Y_VALUE17}
		IF (trans2_TAB_ACTUAL_NUMBER >= 18) {trans2_TAB_X_Y_VALUE18}
		IF (trans2_TAB_ACTUAL_NUMBER >= 19) {trans2_TAB_X_Y_VALUE19}
		IF (trans2_TAB_ACTUAL_NUMBER >= 20) {trans2_TAB_X_Y_VALUE20}
		IF (trans2_TAB_ACTUAL_NUMBER >= 21) {trans2_TAB_X_Y_VALUE21}
		IF (trans2_TAB_ACTUAL_NUMBER >= 22) {trans2_TAB_X_Y_VALUE22}
		IF (trans2_TAB_ACTUAL_NUMBER >= 23) {trans2_TAB_X_Y_VALUE23}
		IF (trans2_TAB_ACTUAL_NUMBER >= 24) {trans2_TAB_X_Y_VALUE24}
		IF (trans2_TAB_ACTUAL_NUMBER >= 25) {trans2_TAB_X_Y_VALUE25}
		IF (trans2_TAB_ACTUAL_NUMBER >= 26) {trans2_TAB_X_Y_VALUE26}
		IF (trans2_TAB_ACTUAL_NUMBER >= 27) {trans2_TAB_X_Y_VALUE27}
		IF (trans2_TAB_ACTUAL_NUMBER >= 28) {trans2_TAB_X_Y_VALUE28}
		IF (trans2_TAB_ACTUAL_NUMBER >= 29) {trans2_TAB_X_Y_VALUE29}
		IF (trans2_TAB_ACTUAL_NUMBER >= 30) {trans2_TAB_X_Y_VALUE30}
		IF (trans2_TAB_ACTUAL_NUMBER >= 31) {trans2_TAB_X_Y_VALUE31}
		IF (trans2_TAB_ACTUAL_NUMBER >= 32) {trans2_TAB_X_Y_VALUE32}
		IF (trans2_TAB_ACTUAL_NUMBER >= 33) {trans2_TAB_X_Y_VALUE33}
		IF (trans2_TAB_ACTUAL_NUMBER >= 34) {trans2_TAB_X_Y_VALUE34}
		IF (trans2_TAB_ACTUAL_NUMBER >= 35) {trans2_TAB_X_Y_VALUE35}
		IF (trans2_TAB_ACTUAL_NUMBER >= 36) {trans2_TAB_X_Y_VALUE36}
		IF (trans2_TAB_ACTUAL_NUMBER >= 37) {trans2_TAB_X_Y_VALUE37}
		IF (trans2_TAB_ACTUAL_NUMBER >= 38) {trans2_TAB_X_Y_VALUE38}
		IF (trans2_TAB_ACTUAL_NUMBER >= 39) {trans2_TAB_X_Y_VALUE39}
		IF (trans2_TAB_ACTUAL_NUMBER >= 40) {trans2_TAB_X_Y_VALUE40}
		IF (trans2_TAB_ACTUAL_NUMBER >= 41) {trans2_TAB_X_Y_VALUE41}
		IF (trans2_TAB_ACTUAL_NUMBER >= 42) {trans2_TAB_X_Y_VALUE42}
		IF (trans2_TAB_ACTUAL_NUMBER >= 43) {trans2_TAB_X_Y_VALUE43}
		IF (trans2_TAB_ACTUAL_NUMBER >= 44) {trans2_TAB_X_Y_VALUE44}
		IF (trans2_TAB_ACTUAL_NUMBER >= 45) {trans2_TAB_X_Y_VALUE45}
		IF (trans2_TAB_ACTUAL_NUMBER >= 46) {trans2_TAB_X_Y_VALUE46}
		IF (trans2_TAB_ACTUAL_NUMBER >= 47) {trans2_TAB_X_Y_VALUE47}
		IF (trans2_TAB_ACTUAL_NUMBER >= 48) {trans2_TAB_X_Y_VALUE48}
		IF (trans2_TAB_ACTUAL_NUMBER >= 49) {trans2_TAB_X_Y_VALUE49}
		IF (trans2_TAB_ACTUAL_NUMBER == 50) {trans2_TAB_X_Y_VALUE50}

/* Function block 1 */
		func1_BLK_RESERVE,
		func1_BLK_OBJECT,
		func1_BLK_PARENT_CLASS,
		func1_BLK_CLASS,
		func1_BLK_DD_REFRENCE,
		func1_BLK_DD_REV,
		func1_BLK_PROFILE,
		func1_BLK_PROFILE_REV,
		func1_BLK_EXECUTION_TIME,
		func1_BLK_NUM_PARAMETERS,
		func1_BLK_INDEX_VIEW_1,
		func1_BLK_NUM_VIEW_LISTS,
		func1_STATIC_REVISION,
		func1_TAG_DESCRIPTION,
		func1_STRATEGY,
		func1_ALERT_KEY,
		func1_TARGET_MODE,
		func1_ACTUAL_MODE,
		func1_PERMITTED_MODE,
		func1_NORMAL_MODE,
		func1_CURRENT_STATE_ALARM_SUM,
		func1_UNACKNOWLEDGED_STATE_ALARM_SUM,
		func1_UNREPORTED_STATE_ALARM_SUM,
		func1_DISABLED_STATE_ALARM_SUM,
		func1_BATCH_ID,
		func1_BATCH_UNIT, 
		func1_BATCH_OPERATION, 
		func1_BATCH_PHASE,
		func1_OUT_VALUE,
		func1_OUT_STATUS,
		func1_PV_SCALE_UPPER,
		func1_PV_SCALE_LOWER,
		func1_OUTPUT_SCALE_UPPER_VALUE,
		func1_OUTPUT_SCALE_LOWER_VALUE,
		func1_OUTPUT_SCALE_UNIT,
		func1_OUTPUT_SCALE_DECIMAL_POINT,
		func1_LIN_TYPE,
		func1_CHANNEL,
		func1_PV_FTIME,
		func1_FSAFE_TYPE,
		func1_FSAFE_VALUE,
		func1_LIMIT_HYSTERESIS,
		func1_LIMIT_HI_HI,
		func1_LIMIT_HI,
		func1_LIMIT_LO,
		func1_LIMIT_LO_LO,
		func1_HI_HI_ALM_UNACKNOWLEDGED, 
		func1_HI_HI_ALM_STATE,
		func1_HI_HI_ALM_TIMESTAMP_HIGH, 
		func1_HI_HI_ALM_TIMESTAMP_LOW, 
		func1_HI_HI_ALM_SUBCODE,
		func1_HI_HI_ALM_VALUE,
		func1_HI_ALM_UNACKNOWLEDGED, 
		func1_HI_ALM_STATE,
		func1_HI_ALM_TIMESTAMP_HIGH,
		func1_HI_ALM_TIMESTAMP_LOW,
		func1_HI_ALM_SUBCODE,
		func1_HI_ALM_VALUE,
		func1_LO_ALM_UNACKNOWLEDGED, 
		func1_LO_ALM_STATE,
		func1_LO_ALM_TIMESTAMP_HIGH, 
		func1_LO_ALM_TIMESTAMP_LOW,
		func1_LO_ALM_SUBCODE,
		func1_LO_ALM_VALUE,
		func1_LO_LO_ALM_UNACKNOWLEDGED, 
		func1_LO_LO_ALM_STATE,
		func1_LO_LO_ALM_TIMESTAMP_HIGH,
		func1_LO_LO_ALM_TIMESTAMP_LOW,
		func1_LO_LO_ALM_SUBCODE,
		func1_LO_LO_ALM_VALUE,
		func1_SIMULATION_STATUS,
		func1_SIMULATION_VALUE, 
		func1_SIMULATION_ENABLED,
		func1_OUTPUT_UNIT_TEXT,

/* Function block 2 */
		func2_BLK_RESERVE,
		func2_BLK_OBJECT,
		func2_BLK_PARENT_CLASS,
		func2_BLK_CLASS,
		func2_BLK_DD_REFRENCE,
		func2_BLK_DD_REV,
		func2_BLK_PROFILE,
		func2_BLK_PROFILE_REV,
		func2_BLK_EXECUTION_TIME,
		func2_BLK_NUM_PARAMETERS,
		func2_BLK_INDEX_VIEW_1,
		func2_BLK_NUM_VIEW_LISTS,
		func2_STATIC_REVISION,
		func2_TAG_DESCRIPTION,
		func2_STRATEGY,
		func2_ALERT_KEY,
		func2_TARGET_MODE,
		func2_ACTUAL_MODE,
		func2_PERMITTED_MODE,
		func2_NORMAL_MODE,
		func2_CURRENT_STATE_ALARM_SUM,
		func2_UNACKNOWLEDGED_STATE_ALARM_SUM,
		func2_UNREPORTED_STATE_ALARM_SUM,
		func2_DISABLED_STATE_ALARM_SUM,
		func2_BATCH_ID,
		func2_BATCH_UNIT, 
		func2_BATCH_OPERATION, 
		func2_BATCH_PHASE,
		func2_OUT_VALUE,
		func2_OUT_STATUS,
		func2_PV_SCALE_UPPER,
		func2_PV_SCALE_LOWER,
		func2_OUTPUT_SCALE_UPPER_VALUE,
		func2_OUTPUT_SCALE_LOWER_VALUE,
		func2_OUTPUT_SCALE_UNIT,
		func2_OUTPUT_SCALE_DECIMAL_POINT,
		func2_LIN_TYPE,
		func2_CHANNEL,
		func2_PV_FTIME,
		func2_FSAFE_TYPE,
		func2_FSAFE_VALUE,
		func2_LIMIT_HYSTERESIS,
		func2_LIMIT_HI_HI,
		func2_LIMIT_HI,
		func2_LIMIT_LO,
		func2_LIMIT_LO_LO,
		func2_HI_HI_ALM_UNACKNOWLEDGED, 
		func2_HI_HI_ALM_STATE,
		func2_HI_HI_ALM_TIMESTAMP_HIGH,
		func2_HI_HI_ALM_TIMESTAMP_LOW,
		func2_HI_HI_ALM_SUBCODE,
		func2_HI_HI_ALM_VALUE,
		func2_HI_ALM_UNACKNOWLEDGED, 
		func2_HI_ALM_STATE,
		func2_HI_ALM_TIMESTAMP_HIGH,
		func2_HI_ALM_TIMESTAMP_LOW,
		func2_HI_ALM_SUBCODE,
		func2_HI_ALM_VALUE,
		func2_LO_ALM_UNACKNOWLEDGED, 
		func2_LO_ALM_STATE,
		func2_LO_ALM_TIMESTAMP_HIGH,
		func2_LO_ALM_TIMESTAMP_LOW,
		func2_LO_ALM_SUBCODE,
		func2_LO_ALM_VALUE,
		func2_LO_LO_ALM_UNACKNOWLEDGED, 
		func2_LO_LO_ALM_STATE,
		func2_LO_LO_ALM_TIMESTAMP_HIGH, 
		func2_LO_LO_ALM_TIMESTAMP_LOW,
		func2_LO_LO_ALM_SUBCODE,
		func2_LO_LO_ALM_VALUE,
		func2_SIMULATION_STATUS,
		func2_SIMULATION_VALUE, 
		func2_SIMULATION_ENABLED,
		func2_OUTPUT_UNIT_TEXT
   	}
}


/* Send to device */
MENU upload_variables
{
	LABEL		[menu_load_to_device];
	ITEMS
	{
// general
		trans1_TARGET_MODE,
		trans2_TARGET_MODE,
		func1_TARGET_MODE,
		func2_TARGET_MODE,
		
// physical block
		phys_TAG_DESCRIPTION,
		phys_DESCRIPTION,
		phys_DEVICE_MESSAGE,
		phys_INSTALL_DATE,
		phys_LOCAL_OP_ENABLED,		//fbi
		phys_IDENT_NUMBER,			//fbi

// transmitter block
		trans1_PRIMARY_VALUE_UNIT,
		trans1_SENSOR_MEAS_TYPE,
		trans1_LIN_TYPE_1,
		trans1_BIAS_1,
		trans1_BIAS_2,
		trans1_SENSOR_WIRE_CHECK_1,
		trans1_SENSOR_WIRE_CHECK_2,
		trans1_RJ_TYPE,
		trans1_EXTERNAL_RJ_VALUE,
		trans1_SENSOR_CONNECTION_1,
		trans1_COMP_WIRE_1,
		trans1_COMP_WIRE_2,
		trans1_SENSOR_CONNECTION_2,
		trans1_LIN_TYPE_2,
		trans1_RJ_COMP_WIRE,
		trans1_SENSOR_WIRE_CHECK_RJ,
		trans1_RTDX_FACTOR_1,
		trans1_RTDX_FACTOR_2,

/* Transducer Block 2*/
		trans2_CUSTOM_TC_NAME,
		trans2_CUSTOM_TC_POLY_COUNT,
		trans2_CUSTOM_TC_MIN_IN,
		trans2_CUSTOM_TC_MIN_OUT,
		trans2_CUSTOM_TC_MAX_OUT,
		trans2_CUSTOM_TC_POLY_1.Ohm,
		trans2_CUSTOM_TC_POLY_1.a4,
		trans2_CUSTOM_TC_POLY_1.a3,
		trans2_CUSTOM_TC_POLY_1.a2,
		trans2_CUSTOM_TC_POLY_1.a1,
		trans2_CUSTOM_TC_POLY_1.a0,
		trans2_CUSTOM_TC_POLY_2.Ohm,
		trans2_CUSTOM_TC_POLY_2.a4,
		trans2_CUSTOM_TC_POLY_2.a3,
		trans2_CUSTOM_TC_POLY_2.a2,
		trans2_CUSTOM_TC_POLY_2.a1,
		trans2_CUSTOM_TC_POLY_2.a0,
		trans2_CUSTOM_TC_POLY_3.Ohm,
		trans2_CUSTOM_TC_POLY_3.a4,
		trans2_CUSTOM_TC_POLY_3.a3,
		trans2_CUSTOM_TC_POLY_3.a2,
		trans2_CUSTOM_TC_POLY_3.a1,
		trans2_CUSTOM_TC_POLY_3.a0,
		trans2_CUSTOM_TC_POLY_4.Ohm,
		trans2_CUSTOM_TC_POLY_4.a4,
		trans2_CUSTOM_TC_POLY_4.a3,
		trans2_CUSTOM_TC_POLY_4.a2,
		trans2_CUSTOM_TC_POLY_4.a1,
		trans2_CUSTOM_TC_POLY_4.a0,
		trans2_CUSTOM_TC_POLY_5.Ohm,
		trans2_CUSTOM_TC_POLY_5.a4,
		trans2_CUSTOM_TC_POLY_5.a3,
		trans2_CUSTOM_TC_POLY_5.a2,
		trans2_CUSTOM_TC_POLY_5.a1,
		trans2_CUSTOM_TC_POLY_5.a0,
		trans2_CUSTOM_TC_RJ_POLY.a3,
		trans2_CUSTOM_TC_RJ_POLY.a2,
		trans2_CUSTOM_TC_RJ_POLY.a1,
		trans2_CUSTOM_TC_RJ_POLY.a0,
		trans2_CUSTOM_RTD_NAME,
		trans2_CUSTOM_RTD_POLY_COUNT,
		trans2_CUSTOM_RTD_MIN_IN,
		trans2_CUSTOM_RTD_MIN_OUT,
		trans2_CUSTOM_RTD_MAX_OUT,
		trans2_CUSTOM_RTD_POLY_1.Ohm,
		trans2_CUSTOM_RTD_POLY_1.a4,
		trans2_CUSTOM_RTD_POLY_1.a3,
		trans2_CUSTOM_RTD_POLY_1.a2,
		trans2_CUSTOM_RTD_POLY_1.a1,
		trans2_CUSTOM_RTD_POLY_1.a0,
		trans2_CUSTOM_RTD_POLY_2.Ohm,
		trans2_CUSTOM_RTD_POLY_2.a4,
		trans2_CUSTOM_RTD_POLY_2.a3,
		trans2_CUSTOM_RTD_POLY_2.a2,
		trans2_CUSTOM_RTD_POLY_2.a1,
		trans2_CUSTOM_RTD_POLY_2.a0,
		trans2_CUSTOM_RTD_POLY_3.Ohm,
		trans2_CUSTOM_RTD_POLY_3.a4,
		trans2_CUSTOM_RTD_POLY_3.a3,
		trans2_CUSTOM_RTD_POLY_3.a2,
		trans2_CUSTOM_RTD_POLY_3.a1,
		trans2_CUSTOM_RTD_POLY_3.a0,
		trans2_CUSTOM_RTD_POLY_4.Ohm,
		trans2_CUSTOM_RTD_POLY_4.a4,
		trans2_CUSTOM_RTD_POLY_4.a3,
		trans2_CUSTOM_RTD_POLY_4.a2,
		trans2_CUSTOM_RTD_POLY_4.a1,
		trans2_CUSTOM_RTD_POLY_4.a0,
		trans2_CUSTOM_RTD_POLY_5.Ohm,
		trans2_CUSTOM_RTD_POLY_5.a4,
		trans2_CUSTOM_RTD_POLY_5.a3,
		trans2_CUSTOM_RTD_POLY_5.a2,
		trans2_CUSTOM_RTD_POLY_5.a1,
		trans2_CUSTOM_RTD_POLY_5.a0,
		trans2_TAB_ACTUAL_NUMBER,
		trans2_TAB_X_Y_VALUE1 ,
		trans2_TAB_X_Y_VALUE2 ,
		trans2_TAB_X_Y_VALUE3 ,
		trans2_TAB_X_Y_VALUE4 ,
		trans2_TAB_X_Y_VALUE5 ,
		trans2_TAB_X_Y_VALUE6 ,
		trans2_TAB_X_Y_VALUE7 ,
		trans2_TAB_X_Y_VALUE8 ,
		trans2_TAB_X_Y_VALUE9 ,
		trans2_TAB_X_Y_VALUE10,
		trans2_TAB_X_Y_VALUE11,
		IF (trans2_TAB_ACTUAL_NUMBER >= 12) {trans2_TAB_X_Y_VALUE12}
		IF (trans2_TAB_ACTUAL_NUMBER >= 13) {trans2_TAB_X_Y_VALUE13}
		IF (trans2_TAB_ACTUAL_NUMBER >= 14) {trans2_TAB_X_Y_VALUE14}
		IF (trans2_TAB_ACTUAL_NUMBER >= 15) {trans2_TAB_X_Y_VALUE15}
		IF (trans2_TAB_ACTUAL_NUMBER >= 16) {trans2_TAB_X_Y_VALUE16}
		IF (trans2_TAB_ACTUAL_NUMBER >= 17) {trans2_TAB_X_Y_VALUE17}
		IF (trans2_TAB_ACTUAL_NUMBER >= 18) {trans2_TAB_X_Y_VALUE18}
		IF (trans2_TAB_ACTUAL_NUMBER >= 19) {trans2_TAB_X_Y_VALUE19}
		IF (trans2_TAB_ACTUAL_NUMBER >= 20) {trans2_TAB_X_Y_VALUE20}
		IF (trans2_TAB_ACTUAL_NUMBER >= 21) {trans2_TAB_X_Y_VALUE21}
		IF (trans2_TAB_ACTUAL_NUMBER >= 22) {trans2_TAB_X_Y_VALUE22}
		IF (trans2_TAB_ACTUAL_NUMBER >= 23) {trans2_TAB_X_Y_VALUE23}
		IF (trans2_TAB_ACTUAL_NUMBER >= 24) {trans2_TAB_X_Y_VALUE24}
		IF (trans2_TAB_ACTUAL_NUMBER >= 25) {trans2_TAB_X_Y_VALUE25}
		IF (trans2_TAB_ACTUAL_NUMBER >= 26) {trans2_TAB_X_Y_VALUE26}
		IF (trans2_TAB_ACTUAL_NUMBER >= 27) {trans2_TAB_X_Y_VALUE27}
		IF (trans2_TAB_ACTUAL_NUMBER >= 28) {trans2_TAB_X_Y_VALUE28}
		IF (trans2_TAB_ACTUAL_NUMBER >= 29) {trans2_TAB_X_Y_VALUE29}
		IF (trans2_TAB_ACTUAL_NUMBER >= 30) {trans2_TAB_X_Y_VALUE30}
		IF (trans2_TAB_ACTUAL_NUMBER >= 31) {trans2_TAB_X_Y_VALUE31}
		IF (trans2_TAB_ACTUAL_NUMBER >= 32) {trans2_TAB_X_Y_VALUE32}
		IF (trans2_TAB_ACTUAL_NUMBER >= 33) {trans2_TAB_X_Y_VALUE33}
		IF (trans2_TAB_ACTUAL_NUMBER >= 34) {trans2_TAB_X_Y_VALUE34}
		IF (trans2_TAB_ACTUAL_NUMBER >= 35) {trans2_TAB_X_Y_VALUE35}
		IF (trans2_TAB_ACTUAL_NUMBER >= 36) {trans2_TAB_X_Y_VALUE36}
		IF (trans2_TAB_ACTUAL_NUMBER >= 37) {trans2_TAB_X_Y_VALUE37}
		IF (trans2_TAB_ACTUAL_NUMBER >= 38) {trans2_TAB_X_Y_VALUE38}
		IF (trans2_TAB_ACTUAL_NUMBER >= 39) {trans2_TAB_X_Y_VALUE39}
		IF (trans2_TAB_ACTUAL_NUMBER >= 40) {trans2_TAB_X_Y_VALUE40}
		IF (trans2_TAB_ACTUAL_NUMBER >= 41) {trans2_TAB_X_Y_VALUE41}
		IF (trans2_TAB_ACTUAL_NUMBER >= 42) {trans2_TAB_X_Y_VALUE42}
		IF (trans2_TAB_ACTUAL_NUMBER >= 43) {trans2_TAB_X_Y_VALUE43}
		IF (trans2_TAB_ACTUAL_NUMBER >= 44) {trans2_TAB_X_Y_VALUE44}
		IF (trans2_TAB_ACTUAL_NUMBER >= 45) {trans2_TAB_X_Y_VALUE45}
		IF (trans2_TAB_ACTUAL_NUMBER >= 46) {trans2_TAB_X_Y_VALUE46}
		IF (trans2_TAB_ACTUAL_NUMBER >= 47) {trans2_TAB_X_Y_VALUE47}
		IF (trans2_TAB_ACTUAL_NUMBER >= 48) {trans2_TAB_X_Y_VALUE48}
		IF (trans2_TAB_ACTUAL_NUMBER >= 49) {trans2_TAB_X_Y_VALUE49}
		IF (trans2_TAB_ACTUAL_NUMBER == 50) {trans2_TAB_X_Y_VALUE50}

// function block 1
		func1_TAG_DESCRIPTION,
		func1_STRATEGY,
		func1_ALERT_KEY,
		func1_FSAFE_TYPE,
		func1_FSAFE_VALUE,
		IF(func1_TARGET_MODE == BLOCK_MODE_OOS)
   		{
			func1_CHANNEL,
			func1_LIN_TYPE
		}
		func1_OUTPUT_UNIT_TEXT,
		func1_PV_FTIME,
		IF(func1_TARGET_MODE == BLOCK_MODE_OOS || func1_TARGET_MODE == BLOCK_MODE_MAN)
   		{
			func1_PV_SCALE_UPPER,
			func1_PV_SCALE_LOWER,
			func1_OUTPUT_SCALE_LOWER_VALUE,
			func1_OUTPUT_SCALE_UPPER_VALUE,
			func1_OUTPUT_SCALE_UNIT,
			func1_OUTPUT_SCALE_DECIMAL_POINT
		}
		func1_LIMIT_HYSTERESIS,
		func1_LIMIT_LO_LO,
		func1_LIMIT_LO,
		func1_LIMIT_HI,
		func1_LIMIT_HI_HI,

// function block 2
		func2_TAG_DESCRIPTION,
		func2_STRATEGY,
		func2_ALERT_KEY,
		func2_FSAFE_TYPE,
		func2_FSAFE_VALUE,
		IF(func2_TARGET_MODE == BLOCK_MODE_OOS)
		{
			func2_CHANNEL,
			func2_LIN_TYPE
		}
		func2_OUTPUT_UNIT_TEXT,
		func2_PV_FTIME,
		IF(func2_TARGET_MODE == BLOCK_MODE_OOS || func2_TARGET_MODE == BLOCK_MODE_MAN)
		{
			func2_PV_SCALE_UPPER,
			func2_PV_SCALE_LOWER,
			func2_OUTPUT_SCALE_LOWER_VALUE,
			func2_OUTPUT_SCALE_UPPER_VALUE,
			func2_OUTPUT_SCALE_UNIT,
			func2_OUTPUT_SCALE_DECIMAL_POINT
		}
		func2_LIMIT_HYSTERESIS,
		func2_LIMIT_LO_LO,
		func2_LIMIT_LO,
		func2_LIMIT_HI,
		func2_LIMIT_HI_HI
	}
}

